from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.Storage.FileSystem
import win32more.Windows.Win32.Storage.Vhd
import win32more.Windows.Win32.System.Ioctl
class ASYNC_DUPLICATE_EXTENTS_STATUS(Structure):
    Version: UInt32
    State: win32more.Windows.Win32.System.Ioctl.DUPLICATE_EXTENTS_STATE
    SourceFileOffset: UInt64
    TargetFileOffset: UInt64
    ByteCount: UInt64
    BytesDuplicated: UInt64
IOCTL_STORAGE_BASE: UInt32 = 45
IOCTL_SCMBUS_BASE: UInt32 = 89
IOCTL_DISK_BASE: UInt32 = 7
IOCTL_CHANGER_BASE: UInt32 = 48
FILE_SPECIAL_ACCESS: UInt32 = 0
FILE_DEVICE_UNKNOWN: UInt32 = 34
GUID_DEVINTERFACE_DISK: Guid = Guid('{53f56307-b6bf-11d0-94f2-00a0c91efb8b}')
GUID_DEVINTERFACE_CDROM: Guid = Guid('{53f56308-b6bf-11d0-94f2-00a0c91efb8b}')
GUID_DEVINTERFACE_PARTITION: Guid = Guid('{53f5630a-b6bf-11d0-94f2-00a0c91efb8b}')
GUID_DEVINTERFACE_TAPE: Guid = Guid('{53f5630b-b6bf-11d0-94f2-00a0c91efb8b}')
GUID_DEVINTERFACE_WRITEONCEDISK: Guid = Guid('{53f5630c-b6bf-11d0-94f2-00a0c91efb8b}')
GUID_DEVINTERFACE_VOLUME: Guid = Guid('{53f5630d-b6bf-11d0-94f2-00a0c91efb8b}')
GUID_DEVINTERFACE_MEDIUMCHANGER: Guid = Guid('{53f56310-b6bf-11d0-94f2-00a0c91efb8b}')
GUID_DEVINTERFACE_FLOPPY: Guid = Guid('{53f56311-b6bf-11d0-94f2-00a0c91efb8b}')
GUID_DEVINTERFACE_CDCHANGER: Guid = Guid('{53f56312-b6bf-11d0-94f2-00a0c91efb8b}')
GUID_DEVINTERFACE_STORAGEPORT: Guid = Guid('{2accfe60-c130-11d2-b082-00a0c91efb8b}')
GUID_DEVINTERFACE_VMLUN: Guid = Guid('{6f416619-9f29-42a5-b20b-37e219ca02b0}')
GUID_DEVINTERFACE_SES: Guid = Guid('{1790c9ec-47d5-4df3-b5af-9adf3cf23e48}')
GUID_DEVINTERFACE_ZNSDISK: Guid = Guid('{b87941c5-ffdb-43c7-b6b1-20b632f0b109}')
GUID_DEVINTERFACE_SERVICE_VOLUME: Guid = Guid('{6ead3d82-25ec-46bc-b7fd-c1f0df8f5037}')
GUID_DEVINTERFACE_HIDDEN_VOLUME: Guid = Guid('{7f108a28-9833-4b3b-b780-2c6b5fa5c062}')
GUID_DEVINTERFACE_UNIFIED_ACCESS_RPMB: Guid = Guid('{27447c21-bcc3-4d07-a05b-a3395bb4eee7}')
GUID_DEVICEDUMP_STORAGE_DEVICE: Guid = Guid('{d8e2592f-1aab-4d56-a746-1f7585df40f4}')
GUID_DEVICEDUMP_DRIVER_STORAGE_PORT: Guid = Guid('{da82441d-7142-4bc1-b844-0807c5a4b67f}')
DEVPKEY_Storage_Portable: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4d1ebee8-0803-4774-9842-b77db50265e9}'), pid=2)
DEVPKEY_Storage_Removable_Media: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4d1ebee8-0803-4774-9842-b77db50265e9}'), pid=3)
DEVPKEY_Storage_System_Critical: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4d1ebee8-0803-4774-9842-b77db50265e9}'), pid=4)
DEVPKEY_Storage_Disk_Number: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4d1ebee8-0803-4774-9842-b77db50265e9}'), pid=5)
DEVPKEY_Storage_Partition_Number: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4d1ebee8-0803-4774-9842-b77db50265e9}'), pid=6)
DEVPKEY_Storage_Mbr_Type: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4d1ebee8-0803-4774-9842-b77db50265e9}'), pid=7)
DEVPKEY_Storage_Gpt_Type: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4d1ebee8-0803-4774-9842-b77db50265e9}'), pid=8)
DEVPKEY_Storage_Gpt_Name: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4d1ebee8-0803-4774-9842-b77db50265e9}'), pid=9)
IOCTL_STORAGE_CHECK_VERIFY: UInt32 = 2967552
IOCTL_STORAGE_CHECK_VERIFY2: UInt32 = 2951168
IOCTL_STORAGE_MEDIA_REMOVAL: UInt32 = 2967556
IOCTL_STORAGE_EJECT_MEDIA: UInt32 = 2967560
IOCTL_STORAGE_LOAD_MEDIA: UInt32 = 2967564
IOCTL_STORAGE_LOAD_MEDIA2: UInt32 = 2951180
IOCTL_STORAGE_RESERVE: UInt32 = 2967568
IOCTL_STORAGE_RELEASE: UInt32 = 2967572
IOCTL_STORAGE_FIND_NEW_DEVICES: UInt32 = 2967576
IOCTL_STORAGE_MANAGE_BYPASS_IO: UInt32 = 2951360
IOCTL_STORAGE_EJECTION_CONTROL: UInt32 = 2951488
IOCTL_STORAGE_MCN_CONTROL: UInt32 = 2951492
IOCTL_STORAGE_GET_MEDIA_TYPES: UInt32 = 2952192
IOCTL_STORAGE_GET_MEDIA_TYPES_EX: UInt32 = 2952196
IOCTL_STORAGE_GET_MEDIA_SERIAL_NUMBER: UInt32 = 2952208
IOCTL_STORAGE_GET_HOTPLUG_INFO: UInt32 = 2952212
IOCTL_STORAGE_SET_HOTPLUG_INFO: UInt32 = 3001368
IOCTL_STORAGE_RESET_BUS: UInt32 = 2969600
IOCTL_STORAGE_RESET_DEVICE: UInt32 = 2969604
IOCTL_STORAGE_BREAK_RESERVATION: UInt32 = 2969620
IOCTL_STORAGE_PERSISTENT_RESERVE_IN: UInt32 = 2969624
IOCTL_STORAGE_PERSISTENT_RESERVE_OUT: UInt32 = 3002396
IOCTL_STORAGE_GET_DEVICE_NUMBER: UInt32 = 2953344
IOCTL_STORAGE_GET_DEVICE_NUMBER_EX: UInt32 = 2953348
IOCTL_STORAGE_PREDICT_FAILURE: UInt32 = 2953472
IOCTL_STORAGE_FAILURE_PREDICTION_CONFIG: UInt32 = 2953476
IOCTL_STORAGE_GET_COUNTERS: UInt32 = 2953480
IOCTL_STORAGE_READ_CAPACITY: UInt32 = 2969920
IOCTL_STORAGE_GET_DEVICE_TELEMETRY: UInt32 = 3002816
IOCTL_STORAGE_DEVICE_TELEMETRY_NOTIFY: UInt32 = 3002820
IOCTL_STORAGE_DEVICE_TELEMETRY_QUERY_CAPS: UInt32 = 3002824
IOCTL_STORAGE_GET_DEVICE_TELEMETRY_RAW: UInt32 = 3002828
IOCTL_STORAGE_SET_TEMPERATURE_THRESHOLD: UInt32 = 3002880
IOCTL_STORAGE_PROTOCOL_COMMAND: UInt32 = 3003328
IOCTL_STORAGE_SET_PROPERTY: UInt32 = 2987004
IOCTL_STORAGE_QUERY_PROPERTY: UInt32 = 2954240
IOCTL_STORAGE_MANAGE_DATA_SET_ATTRIBUTES: UInt32 = 2987012
IOCTL_STORAGE_GET_LB_PROVISIONING_MAP_RESOURCES: UInt32 = 2970632
IOCTL_STORAGE_REINITIALIZE_MEDIA: UInt32 = 2987584
IOCTL_STORAGE_GET_BC_PROPERTIES: UInt32 = 2971648
IOCTL_STORAGE_ALLOCATE_BC_STREAM: UInt32 = 3004420
IOCTL_STORAGE_FREE_BC_STREAM: UInt32 = 3004424
IOCTL_STORAGE_CHECK_PRIORITY_HINT_SUPPORT: UInt32 = 2955392
IOCTL_STORAGE_START_DATA_INTEGRITY_CHECK: UInt32 = 3004548
IOCTL_STORAGE_STOP_DATA_INTEGRITY_CHECK: UInt32 = 3004552
OBSOLETE_IOCTL_STORAGE_RESET_BUS: UInt32 = 3002368
OBSOLETE_IOCTL_STORAGE_RESET_DEVICE: UInt32 = 3002372
IOCTL_STORAGE_FIRMWARE_GET_INFO: UInt32 = 2956288
IOCTL_STORAGE_FIRMWARE_DOWNLOAD: UInt32 = 3005444
IOCTL_STORAGE_FIRMWARE_ACTIVATE: UInt32 = 3005448
IOCTL_STORAGE_ENABLE_IDLE_POWER: UInt32 = 2956416
IOCTL_STORAGE_GET_IDLE_POWERUP_REASON: UInt32 = 2956420
IOCTL_STORAGE_POWER_ACTIVE: UInt32 = 2956424
IOCTL_STORAGE_POWER_IDLE: UInt32 = 2956428
IOCTL_STORAGE_EVENT_NOTIFICATION: UInt32 = 2956432
IOCTL_STORAGE_DEVICE_POWER_CAP: UInt32 = 2956436
IOCTL_STORAGE_RPMB_COMMAND: UInt32 = 2956440
IOCTL_STORAGE_ATTRIBUTE_MANAGEMENT: UInt32 = 3005596
IOCTL_STORAGE_DIAGNOSTIC: UInt32 = 2956448
IOCTL_STORAGE_GET_PHYSICAL_ELEMENT_STATUS: UInt32 = 2956452
IOCTL_STORAGE_REMOVE_ELEMENT_AND_TRUNCATE: UInt32 = 2956480
IOCTL_STORAGE_GET_DEVICE_INTERNAL_LOG: UInt32 = 2956484
STORAGE_DEVICE_FLAGS_RANDOM_DEVICEGUID_REASON_CONFLICT: UInt32 = 1
STORAGE_DEVICE_FLAGS_RANDOM_DEVICEGUID_REASON_NOHWID: UInt32 = 2
STORAGE_DEVICE_FLAGS_PAGE_83_DEVICEGUID: UInt32 = 4
RECOVERED_WRITES_VALID: UInt32 = 1
UNRECOVERED_WRITES_VALID: UInt32 = 2
RECOVERED_READS_VALID: UInt32 = 4
UNRECOVERED_READS_VALID: UInt32 = 8
WRITE_COMPRESSION_INFO_VALID: UInt32 = 16
READ_COMPRESSION_INFO_VALID: UInt32 = 32
TAPE_RETURN_STATISTICS: Int32 = 0
TAPE_RETURN_ENV_INFO: Int32 = 1
TAPE_RESET_STATISTICS: Int32 = 2
MEDIA_ERASEABLE: UInt32 = 1
MEDIA_WRITE_ONCE: UInt32 = 2
MEDIA_READ_ONLY: UInt32 = 4
MEDIA_READ_WRITE: UInt32 = 8
MEDIA_WRITE_PROTECTED: UInt32 = 256
MEDIA_CURRENTLY_MOUNTED: UInt32 = 2147483648
STORAGE_FAILURE_PREDICTION_CONFIG_V1: UInt32 = 1
SRB_TYPE_SCSI_REQUEST_BLOCK: UInt32 = 0
SRB_TYPE_STORAGE_REQUEST_BLOCK: UInt32 = 1
STORAGE_ADDRESS_TYPE_BTL8: UInt32 = 0
STORAGE_RPMB_DESCRIPTOR_VERSION_1: UInt32 = 1
STORAGE_RPMB_MINIMUM_RELIABLE_WRITE_SIZE: UInt32 = 512
STORAGE_CRYPTO_CAPABILITY_VERSION_1: UInt32 = 1
STORAGE_CRYPTO_DESCRIPTOR_VERSION_1: UInt32 = 1
STORAGE_TIER_NAME_LENGTH: UInt32 = 256
STORAGE_TIER_DESCRIPTION_LENGTH: UInt32 = 512
STORAGE_TIER_FLAG_NO_SEEK_PENALTY: UInt32 = 131072
STORAGE_TIER_FLAG_WRITE_BACK_CACHE: UInt32 = 2097152
STORAGE_TIER_FLAG_READ_CACHE: UInt32 = 4194304
STORAGE_TIER_FLAG_PARITY: UInt32 = 8388608
STORAGE_TIER_FLAG_SMR: UInt32 = 16777216
STORAGE_TEMPERATURE_VALUE_NOT_REPORTED: UInt32 = 32768
STORAGE_TEMPERATURE_THRESHOLD_FLAG_ADAPTER_REQUEST: UInt32 = 1
STORAGE_COMPONENT_ROLE_CACHE: UInt32 = 1
STORAGE_COMPONENT_ROLE_TIERING: UInt32 = 2
STORAGE_COMPONENT_ROLE_DATA: UInt32 = 4
STORAGE_ATTRIBUTE_BYTE_ADDRESSABLE_IO: UInt32 = 1
STORAGE_ATTRIBUTE_BLOCK_IO: UInt32 = 2
STORAGE_ATTRIBUTE_DYNAMIC_PERSISTENCE: UInt32 = 4
STORAGE_ATTRIBUTE_VOLATILE: UInt32 = 8
STORAGE_ATTRIBUTE_ASYNC_EVENT_NOTIFICATION: UInt32 = 16
STORAGE_ATTRIBUTE_PERF_SIZE_INDEPENDENT: UInt32 = 32
STORAGE_DEVICE_MAX_OPERATIONAL_STATUS: UInt32 = 16
STORAGE_ADAPTER_SERIAL_NUMBER_V1_MAX_LENGTH: UInt32 = 128
DeviceDsmActionFlag_NonDestructive: UInt32 = 2147483648
DEVICE_DSM_FLAG_ENTIRE_DATA_SET_RANGE: UInt32 = 1
DEVICE_DSM_FLAG_TRIM_NOT_FS_ALLOCATED: UInt32 = 2147483648
DEVICE_DSM_FLAG_TRIM_BYPASS_RZAT: UInt32 = 1073741824
DEVICE_DSM_NOTIFY_FLAG_BEGIN: UInt32 = 1
DEVICE_DSM_NOTIFY_FLAG_END: UInt32 = 2
STORAGE_OFFLOAD_MAX_TOKEN_LENGTH: UInt32 = 512
STORAGE_OFFLOAD_TOKEN_ID_LENGTH: UInt32 = 504
STORAGE_OFFLOAD_TOKEN_TYPE_ZERO_DATA: UInt32 = 4294901761
STORAGE_OFFLOAD_READ_RANGE_TRUNCATED: UInt32 = 1
STORAGE_OFFLOAD_WRITE_RANGE_TRUNCATED: UInt32 = 1
STORAGE_OFFLOAD_TOKEN_INVALID: UInt32 = 2
DEVICE_DSM_FLAG_ALLOCATION_CONSOLIDATEABLE_ONLY: UInt32 = 1073741824
DEVICE_DSM_PARAMETERS_V1: UInt32 = 1
DEVICE_DATA_SET_LBP_STATE_PARAMETERS_VERSION_V1: UInt32 = 1
DEVICE_DSM_FLAG_REPAIR_INPUT_TOPOLOGY_ID_PRESENT: UInt32 = 1073741824
DEVICE_DSM_FLAG_REPAIR_OUTPUT_PARITY_EXTENT: UInt32 = 536870912
DEVICE_DSM_FLAG_SCRUB_SKIP_IN_SYNC: UInt32 = 268435456
DEVICE_DSM_FLAG_SCRUB_OUTPUT_PARITY_EXTENT: UInt32 = 536870912
DEVICE_DSM_FLAG_PHYSICAL_ADDRESSES_OMIT_TOTAL_RANGES: UInt32 = 268435456
DEVICE_DSM_PHYSICAL_ADDRESSES_OUTPUT_V1: UInt32 = 1
DEVICE_DSM_PHYSICAL_ADDRESSES_OUTPUT_VERSION_V1: UInt32 = 1
DEVICE_STORAGE_NO_ERRORS: UInt32 = 1
DEVICE_DSM_RANGE_ERROR_OUTPUT_V1: UInt32 = 1
DEVICE_DSM_RANGE_ERROR_INFO_VERSION_V1: UInt32 = 1
IOCTL_STORAGE_BC_VERSION: UInt32 = 1
STORAGE_PRIORITY_HINT_SUPPORTED: UInt32 = 1
STORAGE_DIAGNOSTIC_FLAG_ADAPTER_REQUEST: UInt32 = 1
ERROR_HISTORY_DIRECTORY_ENTRY_DEFAULT_COUNT: UInt32 = 8
DEVICEDUMP_STRUCTURE_VERSION_V1: UInt32 = 1
DEVICEDUMP_MAX_IDSTRING: UInt32 = 32
MAX_FW_BUCKET_ID_LENGTH: UInt32 = 132
STORAGE_CRASH_TELEMETRY_REGKEY: String = '\\Registry\\Machine\\System\\CurrentControlSet\\Control\\CrashControl\\StorageTelemetry'
STORAGE_DEVICE_TELEMETRY_REGKEY: String = '\\Registry\\Machine\\System\\CurrentControlSet\\Control\\Storage\\StorageTelemetry'
DDUMP_FLAG_DATA_READ_FROM_DEVICE: UInt32 = 1
FW_ISSUEID_NO_ISSUE: UInt32 = 0
FW_ISSUEID_UNKNOWN: UInt32 = 4294967295
TC_PUBLIC_DEVICEDUMP_CONTENT_SMART: UInt32 = 1
TC_PUBLIC_DEVICEDUMP_CONTENT_GPLOG: UInt32 = 2
TC_PUBLIC_DEVICEDUMP_CONTENT_GPLOG_MAX: UInt32 = 16
TC_DEVICEDUMP_SUBSECTION_DESC_LENGTH: UInt32 = 16
TC_PUBLIC_DATA_TYPE_ATAGP: String = 'ATAGPLogPages'
TC_PUBLIC_DATA_TYPE_ATASMART: String = 'ATASMARTPages'
CDB_SIZE: UInt32 = 16
TELEMETRY_COMMAND_SIZE: UInt32 = 16
DEVICEDUMP_CAP_PRIVATE_SECTION: UInt32 = 1
DEVICEDUMP_CAP_RESTRICTED_SECTION: UInt32 = 2
STORAGE_IDLE_POWERUP_REASON_VERSION_V1: UInt32 = 1
STORAGE_DEVICE_POWER_CAP_VERSION_V1: UInt32 = 1
STORAGE_EVENT_NOTIFICATION_VERSION_V1: UInt32 = 1
STORAGE_EVENT_MEDIA_STATUS: UInt64 = 1
STORAGE_EVENT_DEVICE_STATUS: UInt64 = 2
STORAGE_EVENT_DEVICE_OPERATION: UInt64 = 4
READ_COPY_NUMBER_KEY: UInt32 = 1380142592
READ_COPY_NUMBER_BYPASS_CACHE_FLAG: UInt32 = 256
STORAGE_HW_FIRMWARE_REQUEST_FLAG_CONTROLLER: UInt32 = 1
STORAGE_HW_FIRMWARE_REQUEST_FLAG_LAST_SEGMENT: UInt32 = 2
STORAGE_HW_FIRMWARE_REQUEST_FLAG_FIRST_SEGMENT: UInt32 = 4
STORAGE_HW_FIRMWARE_REQUEST_FLAG_REPLACE_EXISTING_IMAGE: UInt32 = 1073741824
STORAGE_HW_FIRMWARE_REQUEST_FLAG_SWITCH_TO_EXISTING_FIRMWARE: UInt32 = 2147483648
STORAGE_HW_FIRMWARE_INVALID_SLOT: UInt32 = 255
STORAGE_HW_FIRMWARE_REVISION_LENGTH: UInt32 = 16
STORAGE_PROTOCOL_STRUCTURE_VERSION: UInt32 = 1
STORAGE_PROTOCOL_COMMAND_FLAG_ADAPTER_REQUEST: UInt32 = 2147483648
STORAGE_PROTOCOL_STATUS_PENDING: UInt32 = 0
STORAGE_PROTOCOL_STATUS_SUCCESS: UInt32 = 1
STORAGE_PROTOCOL_STATUS_ERROR: UInt32 = 2
STORAGE_PROTOCOL_STATUS_INVALID_REQUEST: UInt32 = 3
STORAGE_PROTOCOL_STATUS_NO_DEVICE: UInt32 = 4
STORAGE_PROTOCOL_STATUS_BUSY: UInt32 = 5
STORAGE_PROTOCOL_STATUS_DATA_OVERRUN: UInt32 = 6
STORAGE_PROTOCOL_STATUS_INSUFFICIENT_RESOURCES: UInt32 = 7
STORAGE_PROTOCOL_STATUS_THROTTLED_REQUEST: UInt32 = 8
STORAGE_PROTOCOL_STATUS_NOT_SUPPORTED: UInt32 = 255
STORAGE_PROTOCOL_COMMAND_LENGTH_NVME: UInt32 = 64
STORAGE_PROTOCOL_SPECIFIC_NVME_ADMIN_COMMAND: UInt32 = 1
STORAGE_PROTOCOL_SPECIFIC_NVME_NVM_COMMAND: UInt32 = 2
STORATTRIBUTE_NONE: UInt32 = 0
STORATTRIBUTE_MANAGEMENT_STATE: UInt32 = 1
STORAGE_SUPPORTED_FEATURES_BYPASS_IO: UInt32 = 1
STORAGE_SUPPORTED_FEATURES_MASK: UInt32 = 1
GUID_DEVINTERFACE_SCM_PHYSICAL_DEVICE: Guid = Guid('{4283609d-4dc2-43be-bbb4-4f15dfce2c61}')
GUID_SCM_PD_HEALTH_NOTIFICATION: Guid = Guid('{9da2d386-72f5-4ee3-8155-eca0678e3b06}')
GUID_SCM_PD_PASSTHROUGH_INVDIMM: Guid = Guid('{4309ac30-0d11-11e4-9191-0800200c9a66}')
GUID_DEVINTERFACE_COMPORT: Guid = Guid('{86e0d1e0-8089-11d0-9ce4-08003e301f73}')
GUID_DEVINTERFACE_SERENUM_BUS_ENUMERATOR: Guid = Guid('{4d36e978-e325-11ce-bfc1-08002be10318}')
FILE_DEVICE_BEEP: UInt32 = 1
FILE_DEVICE_CD_ROM_FILE_SYSTEM: UInt32 = 3
FILE_DEVICE_CONTROLLER: UInt32 = 4
FILE_DEVICE_DATALINK: UInt32 = 5
FILE_DEVICE_DFS: UInt32 = 6
FILE_DEVICE_DISK_FILE_SYSTEM: UInt32 = 8
FILE_DEVICE_FILE_SYSTEM: UInt32 = 9
FILE_DEVICE_INPORT_PORT: UInt32 = 10
FILE_DEVICE_KEYBOARD: UInt32 = 11
FILE_DEVICE_MAILSLOT: UInt32 = 12
FILE_DEVICE_MIDI_IN: UInt32 = 13
FILE_DEVICE_MIDI_OUT: UInt32 = 14
FILE_DEVICE_MOUSE: UInt32 = 15
FILE_DEVICE_MULTI_UNC_PROVIDER: UInt32 = 16
FILE_DEVICE_NAMED_PIPE: UInt32 = 17
FILE_DEVICE_NETWORK: UInt32 = 18
FILE_DEVICE_NETWORK_BROWSER: UInt32 = 19
FILE_DEVICE_NETWORK_FILE_SYSTEM: UInt32 = 20
FILE_DEVICE_NULL: UInt32 = 21
FILE_DEVICE_PARALLEL_PORT: UInt32 = 22
FILE_DEVICE_PHYSICAL_NETCARD: UInt32 = 23
FILE_DEVICE_PRINTER: UInt32 = 24
FILE_DEVICE_SCANNER: UInt32 = 25
FILE_DEVICE_SERIAL_MOUSE_PORT: UInt32 = 26
FILE_DEVICE_SERIAL_PORT: UInt32 = 27
FILE_DEVICE_SCREEN: UInt32 = 28
FILE_DEVICE_SOUND: UInt32 = 29
FILE_DEVICE_STREAMS: UInt32 = 30
FILE_DEVICE_TAPE_FILE_SYSTEM: UInt32 = 32
FILE_DEVICE_TRANSPORT: UInt32 = 33
FILE_DEVICE_VIDEO: UInt32 = 35
FILE_DEVICE_VIRTUAL_DISK: UInt32 = 36
FILE_DEVICE_WAVE_IN: UInt32 = 37
FILE_DEVICE_WAVE_OUT: UInt32 = 38
FILE_DEVICE_8042_PORT: UInt32 = 39
FILE_DEVICE_NETWORK_REDIRECTOR: UInt32 = 40
FILE_DEVICE_BATTERY: UInt32 = 41
FILE_DEVICE_BUS_EXTENDER: UInt32 = 42
FILE_DEVICE_MODEM: UInt32 = 43
FILE_DEVICE_VDM: UInt32 = 44
FILE_DEVICE_MASS_STORAGE: UInt32 = 45
FILE_DEVICE_SMB: UInt32 = 46
FILE_DEVICE_KS: UInt32 = 47
FILE_DEVICE_CHANGER: UInt32 = 48
FILE_DEVICE_ACPI: UInt32 = 50
FILE_DEVICE_FULLSCREEN_VIDEO: UInt32 = 52
FILE_DEVICE_DFS_FILE_SYSTEM: UInt32 = 53
FILE_DEVICE_DFS_VOLUME: UInt32 = 54
FILE_DEVICE_SERENUM: UInt32 = 55
FILE_DEVICE_TERMSRV: UInt32 = 56
FILE_DEVICE_KSEC: UInt32 = 57
FILE_DEVICE_FIPS: UInt32 = 58
FILE_DEVICE_INFINIBAND: UInt32 = 59
FILE_DEVICE_VMBUS: UInt32 = 62
FILE_DEVICE_CRYPT_PROVIDER: UInt32 = 63
FILE_DEVICE_WPD: UInt32 = 64
FILE_DEVICE_BLUETOOTH: UInt32 = 65
FILE_DEVICE_MT_COMPOSITE: UInt32 = 66
FILE_DEVICE_MT_TRANSPORT: UInt32 = 67
FILE_DEVICE_BIOMETRIC: UInt32 = 68
FILE_DEVICE_PMI: UInt32 = 69
FILE_DEVICE_EHSTOR: UInt32 = 70
FILE_DEVICE_DEVAPI: UInt32 = 71
FILE_DEVICE_GPIO: UInt32 = 72
FILE_DEVICE_USBEX: UInt32 = 73
FILE_DEVICE_CONSOLE: UInt32 = 80
FILE_DEVICE_NFP: UInt32 = 81
FILE_DEVICE_SYSENV: UInt32 = 82
FILE_DEVICE_VIRTUAL_BLOCK: UInt32 = 83
FILE_DEVICE_POINT_OF_SERVICE: UInt32 = 84
FILE_DEVICE_STORAGE_REPLICATION: UInt32 = 85
FILE_DEVICE_TRUST_ENV: UInt32 = 86
FILE_DEVICE_UCM: UInt32 = 87
FILE_DEVICE_UCMTCPCI: UInt32 = 88
FILE_DEVICE_PERSISTENT_MEMORY: UInt32 = 89
FILE_DEVICE_NVDIMM: UInt32 = 90
FILE_DEVICE_HOLOGRAPHIC: UInt32 = 91
FILE_DEVICE_SDFXHCI: UInt32 = 92
FILE_DEVICE_UCMUCSI: UInt32 = 93
FILE_DEVICE_PRM: UInt32 = 94
FILE_DEVICE_EVENT_COLLECTOR: UInt32 = 95
FILE_DEVICE_USB4: UInt32 = 96
FILE_DEVICE_SOUNDWIRE: UInt32 = 97
METHOD_BUFFERED: UInt32 = 0
METHOD_IN_DIRECT: UInt32 = 1
METHOD_OUT_DIRECT: UInt32 = 2
METHOD_NEITHER: UInt32 = 3
METHOD_DIRECT_TO_HARDWARE: UInt32 = 1
METHOD_DIRECT_FROM_HARDWARE: UInt32 = 2
FILE_ANY_ACCESS: UInt32 = 0
FILE_READ_ACCESS: UInt32 = 1
FILE_WRITE_ACCESS: UInt32 = 2
STORAGE_DEVICE_NUMA_NODE_UNKNOWN: UInt32 = 4294967295
IOCTL_SCMBUS_DEVICE_FUNCTION_BASE: UInt32 = 0
IOCTL_SCM_LOGICAL_DEVICE_FUNCTION_BASE: UInt32 = 768
IOCTL_SCM_PHYSICAL_DEVICE_FUNCTION_BASE: UInt32 = 1536
IOCTL_SCM_BUS_GET_LOGICAL_DEVICES: UInt32 = 5832704
IOCTL_SCM_BUS_GET_PHYSICAL_DEVICES: UInt32 = 5832708
IOCTL_SCM_BUS_GET_REGIONS: UInt32 = 5832712
IOCTL_SCM_BUS_QUERY_PROPERTY: UInt32 = 5832716
IOCTL_SCM_BUS_SET_PROPERTY: UInt32 = 5865492
IOCTL_SCM_BUS_RUNTIME_FW_ACTIVATE: UInt32 = 5865488
IOCTL_SCM_BUS_REFRESH_NAMESPACE: UInt32 = 5832728
IOCTL_SCM_LD_GET_INTERLEAVE_SET: UInt32 = 5835776
IOCTL_SCM_PD_QUERY_PROPERTY: UInt32 = 5838848
IOCTL_SCM_PD_FIRMWARE_DOWNLOAD: UInt32 = 5871620
IOCTL_SCM_PD_FIRMWARE_ACTIVATE: UInt32 = 5871624
IOCTL_SCM_PD_PASSTHROUGH: UInt32 = 5888012
IOCTL_SCM_PD_UPDATE_MANAGEMENT_STATUS: UInt32 = 5838864
IOCTL_SCM_PD_REINITIALIZE_MEDIA: UInt32 = 5871636
IOCTL_SCM_PD_SET_PROPERTY: UInt32 = 5871640
SCM_MAX_SYMLINK_LEN_IN_CHARS: UInt32 = 256
MAX_INTERFACE_CODES: UInt32 = 8
SCM_PD_FIRMWARE_REVISION_LENGTH_BYTES: UInt32 = 32
SCM_PD_PROPERTY_NAME_LENGTH_IN_CHARS: UInt32 = 128
SCM_PD_MAX_OPERATIONAL_STATUS: UInt32 = 16
SCM_PD_FIRMWARE_LAST_DOWNLOAD: UInt32 = 1
IOCTL_DISK_GET_DRIVE_GEOMETRY: UInt32 = 458752
IOCTL_DISK_GET_PARTITION_INFO: UInt32 = 475140
IOCTL_DISK_SET_PARTITION_INFO: UInt32 = 507912
IOCTL_DISK_GET_DRIVE_LAYOUT: UInt32 = 475148
IOCTL_DISK_SET_DRIVE_LAYOUT: UInt32 = 507920
IOCTL_DISK_VERIFY: UInt32 = 458772
IOCTL_DISK_FORMAT_TRACKS: UInt32 = 507928
IOCTL_DISK_REASSIGN_BLOCKS: UInt32 = 507932
IOCTL_DISK_PERFORMANCE: UInt32 = 458784
IOCTL_DISK_IS_WRITABLE: UInt32 = 458788
IOCTL_DISK_LOGGING: UInt32 = 458792
IOCTL_DISK_FORMAT_TRACKS_EX: UInt32 = 507948
IOCTL_DISK_HISTOGRAM_STRUCTURE: UInt32 = 458800
IOCTL_DISK_HISTOGRAM_DATA: UInt32 = 458804
IOCTL_DISK_HISTOGRAM_RESET: UInt32 = 458808
IOCTL_DISK_REQUEST_STRUCTURE: UInt32 = 458812
IOCTL_DISK_REQUEST_DATA: UInt32 = 458816
IOCTL_DISK_PERFORMANCE_OFF: UInt32 = 458848
IOCTL_DISK_CONTROLLER_NUMBER: UInt32 = 458820
SMART_GET_VERSION: UInt32 = 475264
SMART_SEND_DRIVE_COMMAND: UInt32 = 508036
SMART_RCV_DRIVE_DATA: UInt32 = 508040
SMART_RCV_DRIVE_DATA_EX: UInt32 = 458892
IOCTL_DISK_GET_PARTITION_INFO_EX: UInt32 = 458824
IOCTL_DISK_SET_PARTITION_INFO_EX: UInt32 = 507980
IOCTL_DISK_GET_DRIVE_LAYOUT_EX: UInt32 = 458832
IOCTL_DISK_SET_DRIVE_LAYOUT_EX: UInt32 = 507988
IOCTL_DISK_CREATE_DISK: UInt32 = 507992
IOCTL_DISK_GET_LENGTH_INFO: UInt32 = 475228
IOCTL_DISK_GET_DRIVE_GEOMETRY_EX: UInt32 = 458912
IOCTL_DISK_REASSIGN_BLOCKS_EX: UInt32 = 508068
IOCTL_DISK_UPDATE_DRIVE_SIZE: UInt32 = 508104
IOCTL_DISK_GROW_PARTITION: UInt32 = 508112
IOCTL_DISK_GET_CACHE_INFORMATION: UInt32 = 475348
IOCTL_DISK_SET_CACHE_INFORMATION: UInt32 = 508120
IOCTL_DISK_GET_WRITE_CACHE_STATE: UInt32 = 475356
OBSOLETE_DISK_GET_WRITE_CACHE_STATE: UInt32 = 475356
IOCTL_DISK_DELETE_DRIVE_LAYOUT: UInt32 = 508160
IOCTL_DISK_UPDATE_PROPERTIES: UInt32 = 459072
IOCTL_DISK_FORMAT_DRIVE: UInt32 = 508876
IOCTL_DISK_SENSE_DEVICE: UInt32 = 459744
IOCTL_DISK_CHECK_VERIFY: UInt32 = 477184
IOCTL_DISK_MEDIA_REMOVAL: UInt32 = 477188
IOCTL_DISK_EJECT_MEDIA: UInt32 = 477192
IOCTL_DISK_LOAD_MEDIA: UInt32 = 477196
IOCTL_DISK_RESERVE: UInt32 = 477200
IOCTL_DISK_RELEASE: UInt32 = 477204
IOCTL_DISK_FIND_NEW_DEVICES: UInt32 = 477208
IOCTL_DISK_GET_MEDIA_TYPES: UInt32 = 461824
PARTITION_ENTRY_UNUSED: UInt32 = 0
PARTITION_FAT_12: UInt32 = 1
PARTITION_XENIX_1: UInt32 = 2
PARTITION_XENIX_2: UInt32 = 3
PARTITION_FAT_16: UInt32 = 4
PARTITION_EXTENDED: UInt32 = 5
PARTITION_HUGE: UInt32 = 6
PARTITION_IFS: UInt32 = 7
PARTITION_OS2BOOTMGR: UInt32 = 10
PARTITION_FAT32: UInt32 = 11
PARTITION_FAT32_XINT13: UInt32 = 12
PARTITION_XINT13: UInt32 = 14
PARTITION_XINT13_EXTENDED: UInt32 = 15
PARTITION_MSFT_RECOVERY: UInt32 = 39
PARTITION_MAIN_OS: UInt32 = 40
PARTIITON_OS_DATA: UInt32 = 41
PARTITION_PRE_INSTALLED: UInt32 = 42
PARTITION_BSP: UInt32 = 43
PARTITION_DPP: UInt32 = 44
PARTITION_WINDOWS_SYSTEM: UInt32 = 45
PARTITION_PREP: UInt32 = 65
PARTITION_LDM: UInt32 = 66
PARTITION_DM: UInt32 = 84
PARTITION_EZDRIVE: UInt32 = 85
PARTITION_UNIX: UInt32 = 99
PARTITION_SPACES_DATA: UInt32 = 215
PARTITION_SPACES: UInt32 = 231
PARTITION_GPT: UInt32 = 238
PARTITION_SYSTEM: UInt32 = 239
VALID_NTFT: UInt32 = 192
PARTITION_NTFT: UInt32 = 128
WMI_DISK_GEOMETRY_GUID: Guid = Guid('{25007f51-57c2-11d1-a528-00a0c9062910}')
GPT_ATTRIBUTE_NO_BLOCK_IO_PROTOCOL: UInt64 = 2
GPT_ATTRIBUTE_LEGACY_BIOS_BOOTABLE: UInt64 = 4
GPT_BASIC_DATA_ATTRIBUTE_OFFLINE: UInt64 = 576460752303423488
GPT_BASIC_DATA_ATTRIBUTE_DAX: UInt64 = 288230376151711744
GPT_BASIC_DATA_ATTRIBUTE_SERVICE: UInt64 = 144115188075855872
GPT_SPACES_ATTRIBUTE_NO_METADATA: UInt64 = 9223372036854775808
HIST_NO_OF_BUCKETS: UInt32 = 24
DISK_LOGGING_START: UInt32 = 0
DISK_LOGGING_STOP: UInt32 = 1
DISK_LOGGING_DUMP: UInt32 = 2
DISK_BINNING: UInt32 = 3
CAP_ATA_ID_CMD: UInt32 = 1
CAP_ATAPI_ID_CMD: UInt32 = 2
CAP_SMART_CMD: UInt32 = 4
ATAPI_ID_CMD: UInt32 = 161
ID_CMD: UInt32 = 236
SMART_CMD: UInt32 = 176
SMART_CYL_LOW: UInt32 = 79
SMART_CYL_HI: UInt32 = 194
SMART_NO_ERROR: UInt32 = 0
SMART_IDE_ERROR: UInt32 = 1
SMART_INVALID_FLAG: UInt32 = 2
SMART_INVALID_COMMAND: UInt32 = 3
SMART_INVALID_BUFFER: UInt32 = 4
SMART_INVALID_DRIVE: UInt32 = 5
SMART_INVALID_IOCTL: UInt32 = 6
SMART_ERROR_NO_MEM: UInt32 = 7
SMART_INVALID_REGISTER: UInt32 = 8
SMART_NOT_SUPPORTED: UInt32 = 9
SMART_NO_IDE_DEVICE: UInt32 = 10
SMART_OFFLINE_ROUTINE_OFFLINE: UInt32 = 0
SMART_SHORT_SELFTEST_OFFLINE: UInt32 = 1
SMART_EXTENDED_SELFTEST_OFFLINE: UInt32 = 2
SMART_ABORT_OFFLINE_SELFTEST: UInt32 = 127
SMART_SHORT_SELFTEST_CAPTIVE: UInt32 = 129
SMART_EXTENDED_SELFTEST_CAPTIVE: UInt32 = 130
READ_ATTRIBUTE_BUFFER_SIZE: UInt32 = 512
IDENTIFY_BUFFER_SIZE: UInt32 = 512
READ_THRESHOLD_BUFFER_SIZE: UInt32 = 512
SMART_LOG_SECTOR_SIZE: UInt32 = 512
READ_ATTRIBUTES: UInt32 = 208
READ_THRESHOLDS: UInt32 = 209
ENABLE_DISABLE_AUTOSAVE: UInt32 = 210
SAVE_ATTRIBUTE_VALUES: UInt32 = 211
EXECUTE_OFFLINE_DIAGS: UInt32 = 212
SMART_READ_LOG: UInt32 = 213
SMART_WRITE_LOG: UInt32 = 214
ENABLE_SMART: UInt32 = 216
DISABLE_SMART: UInt32 = 217
RETURN_SMART_STATUS: UInt32 = 218
ENABLE_DISABLE_AUTO_OFFLINE: UInt32 = 219
IOCTL_DISK_GET_DISK_ATTRIBUTES: UInt32 = 458992
IOCTL_DISK_SET_DISK_ATTRIBUTES: UInt32 = 508148
DISK_ATTRIBUTE_OFFLINE: UInt64 = 1
DISK_ATTRIBUTE_READ_ONLY: UInt64 = 2
IOCTL_DISK_RESET_SNAPSHOT_INFO: UInt32 = 508432
IOCTL_CHANGER_GET_PARAMETERS: UInt32 = 3162112
IOCTL_CHANGER_GET_STATUS: UInt32 = 3162116
IOCTL_CHANGER_GET_PRODUCT_DATA: UInt32 = 3162120
IOCTL_CHANGER_SET_ACCESS: UInt32 = 3194896
IOCTL_CHANGER_GET_ELEMENT_STATUS: UInt32 = 3194900
IOCTL_CHANGER_INITIALIZE_ELEMENT_STATUS: UInt32 = 3162136
IOCTL_CHANGER_SET_POSITION: UInt32 = 3162140
IOCTL_CHANGER_EXCHANGE_MEDIUM: UInt32 = 3162144
IOCTL_CHANGER_MOVE_MEDIUM: UInt32 = 3162148
IOCTL_CHANGER_REINITIALIZE_TRANSPORT: UInt32 = 3162152
IOCTL_CHANGER_QUERY_VOLUME_TAGS: UInt32 = 3194924
MAX_VOLUME_ID_SIZE: UInt32 = 36
MAX_VOLUME_TEMPLATE_SIZE: UInt32 = 40
VENDOR_ID_LENGTH: UInt32 = 8
PRODUCT_ID_LENGTH: UInt32 = 16
REVISION_LENGTH: UInt32 = 4
SERIAL_NUMBER_LENGTH: UInt32 = 32
CHANGER_RESERVED_BIT: UInt32 = 2147483648
CHANGER_TO_TRANSPORT: UInt32 = 1
CHANGER_TO_SLOT: UInt32 = 2
CHANGER_TO_IEPORT: UInt32 = 4
CHANGER_TO_DRIVE: UInt32 = 8
LOCK_UNLOCK_IEPORT: UInt32 = 1
LOCK_UNLOCK_DOOR: UInt32 = 2
LOCK_UNLOCK_KEYPAD: UInt32 = 4
LOCK_ELEMENT: UInt32 = 0
UNLOCK_ELEMENT: UInt32 = 1
EXTEND_IEPORT: UInt32 = 2
RETRACT_IEPORT: UInt32 = 3
ERROR_LABEL_UNREADABLE: UInt32 = 1
ERROR_LABEL_QUESTIONABLE: UInt32 = 2
ERROR_SLOT_NOT_PRESENT: UInt32 = 4
ERROR_DRIVE_NOT_INSTALLED: UInt32 = 8
ERROR_TRAY_MALFUNCTION: UInt32 = 16
ERROR_INIT_STATUS_NEEDED: UInt32 = 17
ERROR_UNHANDLED_ERROR: UInt32 = 4294967295
SEARCH_ALL: UInt32 = 0
SEARCH_PRIMARY: UInt32 = 1
SEARCH_ALTERNATE: UInt32 = 2
SEARCH_ALL_NO_SEQ: UInt32 = 4
SEARCH_PRI_NO_SEQ: UInt32 = 5
SEARCH_ALT_NO_SEQ: UInt32 = 6
ASSERT_PRIMARY: UInt32 = 8
ASSERT_ALTERNATE: UInt32 = 9
REPLACE_PRIMARY: UInt32 = 10
REPLACE_ALTERNATE: UInt32 = 11
UNDEFINE_PRIMARY: UInt32 = 12
UNDEFINE_ALTERNATE: UInt32 = 13
IOCTL_SERIAL_LSRMST_INSERT: UInt32 = 1769596
IOCTL_SERENUM_EXPOSE_HARDWARE: UInt32 = 3604992
IOCTL_SERENUM_REMOVE_HARDWARE: UInt32 = 3604996
IOCTL_SERENUM_PORT_DESC: UInt32 = 3605000
IOCTL_SERENUM_GET_PORT_NAME: UInt32 = 3605004
SERIAL_IOC_FCR_FIFO_ENABLE: UInt32 = 1
SERIAL_IOC_FCR_RCVR_RESET: UInt32 = 2
SERIAL_IOC_FCR_XMIT_RESET: UInt32 = 4
SERIAL_IOC_FCR_DMA_MODE: UInt32 = 8
SERIAL_IOC_FCR_RES1: UInt32 = 16
SERIAL_IOC_FCR_RES2: UInt32 = 32
SERIAL_IOC_FCR_RCVR_TRIGGER_LSB: UInt32 = 64
SERIAL_IOC_FCR_RCVR_TRIGGER_MSB: UInt32 = 128
SERIAL_IOC_MCR_DTR: UInt32 = 1
SERIAL_IOC_MCR_RTS: UInt32 = 2
SERIAL_IOC_MCR_OUT1: UInt32 = 4
SERIAL_IOC_MCR_OUT2: UInt32 = 8
SERIAL_IOC_MCR_LOOP: UInt32 = 16
FSCTL_REQUEST_OPLOCK_LEVEL_1: UInt32 = 589824
FSCTL_REQUEST_OPLOCK_LEVEL_2: UInt32 = 589828
FSCTL_REQUEST_BATCH_OPLOCK: UInt32 = 589832
FSCTL_OPLOCK_BREAK_ACKNOWLEDGE: UInt32 = 589836
FSCTL_OPBATCH_ACK_CLOSE_PENDING: UInt32 = 589840
FSCTL_OPLOCK_BREAK_NOTIFY: UInt32 = 589844
FSCTL_LOCK_VOLUME: UInt32 = 589848
FSCTL_UNLOCK_VOLUME: UInt32 = 589852
FSCTL_DISMOUNT_VOLUME: UInt32 = 589856
FSCTL_IS_VOLUME_MOUNTED: UInt32 = 589864
FSCTL_IS_PATHNAME_VALID: UInt32 = 589868
FSCTL_MARK_VOLUME_DIRTY: UInt32 = 589872
FSCTL_QUERY_RETRIEVAL_POINTERS: UInt32 = 589883
FSCTL_GET_COMPRESSION: UInt32 = 589884
FSCTL_SET_COMPRESSION: UInt32 = 639040
FSCTL_SET_BOOTLOADER_ACCESSED: UInt32 = 589903
FSCTL_MARK_AS_SYSTEM_HIVE: UInt32 = 589903
FSCTL_OPLOCK_BREAK_ACK_NO_2: UInt32 = 589904
FSCTL_INVALIDATE_VOLUMES: UInt32 = 589908
FSCTL_QUERY_FAT_BPB: UInt32 = 589912
FSCTL_REQUEST_FILTER_OPLOCK: UInt32 = 589916
FSCTL_FILESYSTEM_GET_STATISTICS: UInt32 = 589920
FSCTL_GET_NTFS_VOLUME_DATA: UInt32 = 589924
FSCTL_GET_NTFS_FILE_RECORD: UInt32 = 589928
FSCTL_GET_VOLUME_BITMAP: UInt32 = 589935
FSCTL_GET_RETRIEVAL_POINTERS: UInt32 = 589939
FSCTL_MOVE_FILE: UInt32 = 589940
FSCTL_IS_VOLUME_DIRTY: UInt32 = 589944
FSCTL_ALLOW_EXTENDED_DASD_IO: UInt32 = 589955
FSCTL_FIND_FILES_BY_SID: UInt32 = 589967
FSCTL_SET_OBJECT_ID: UInt32 = 589976
FSCTL_GET_OBJECT_ID: UInt32 = 589980
FSCTL_DELETE_OBJECT_ID: UInt32 = 589984
FSCTL_SET_REPARSE_POINT: UInt32 = 589988
FSCTL_GET_REPARSE_POINT: UInt32 = 589992
FSCTL_DELETE_REPARSE_POINT: UInt32 = 589996
FSCTL_ENUM_USN_DATA: UInt32 = 590003
FSCTL_SECURITY_ID_CHECK: UInt32 = 606391
FSCTL_READ_USN_JOURNAL: UInt32 = 590011
FSCTL_SET_OBJECT_ID_EXTENDED: UInt32 = 590012
FSCTL_CREATE_OR_GET_OBJECT_ID: UInt32 = 590016
FSCTL_SET_SPARSE: UInt32 = 590020
FSCTL_SET_ZERO_DATA: UInt32 = 622792
FSCTL_QUERY_ALLOCATED_RANGES: UInt32 = 606415
FSCTL_ENABLE_UPGRADE: UInt32 = 622800
FSCTL_SET_ENCRYPTION: UInt32 = 590039
FSCTL_ENCRYPTION_FSCTL_IO: UInt32 = 590043
FSCTL_WRITE_RAW_ENCRYPTED: UInt32 = 590047
FSCTL_READ_RAW_ENCRYPTED: UInt32 = 590051
FSCTL_CREATE_USN_JOURNAL: UInt32 = 590055
FSCTL_READ_FILE_USN_DATA: UInt32 = 590059
FSCTL_WRITE_USN_CLOSE_RECORD: UInt32 = 590063
FSCTL_EXTEND_VOLUME: UInt32 = 590064
FSCTL_QUERY_USN_JOURNAL: UInt32 = 590068
FSCTL_DELETE_USN_JOURNAL: UInt32 = 590072
FSCTL_MARK_HANDLE: UInt32 = 590076
FSCTL_SIS_COPYFILE: UInt32 = 590080
FSCTL_SIS_LINK_FILES: UInt32 = 639236
FSCTL_RECALL_FILE: UInt32 = 590103
FSCTL_READ_FROM_PLEX: UInt32 = 606494
FSCTL_FILE_PREFETCH: UInt32 = 590112
FSCTL_MAKE_MEDIA_COMPATIBLE: UInt32 = 622896
FSCTL_SET_DEFECT_MANAGEMENT: UInt32 = 622900
FSCTL_QUERY_SPARING_INFO: UInt32 = 590136
FSCTL_QUERY_ON_DISK_VOLUME_INFO: UInt32 = 590140
FSCTL_SET_VOLUME_COMPRESSION_STATE: UInt32 = 590144
FSCTL_TXFS_MODIFY_RM: UInt32 = 622916
FSCTL_TXFS_QUERY_RM_INFORMATION: UInt32 = 606536
FSCTL_TXFS_ROLLFORWARD_REDO: UInt32 = 622928
FSCTL_TXFS_ROLLFORWARD_UNDO: UInt32 = 622932
FSCTL_TXFS_START_RM: UInt32 = 622936
FSCTL_TXFS_SHUTDOWN_RM: UInt32 = 622940
FSCTL_TXFS_READ_BACKUP_INFORMATION: UInt32 = 606560
FSCTL_TXFS_WRITE_BACKUP_INFORMATION: UInt32 = 622948
FSCTL_TXFS_CREATE_SECONDARY_RM: UInt32 = 622952
FSCTL_TXFS_GET_METADATA_INFO: UInt32 = 606572
FSCTL_TXFS_GET_TRANSACTED_VERSION: UInt32 = 606576
FSCTL_TXFS_SAVEPOINT_INFORMATION: UInt32 = 622968
FSCTL_TXFS_CREATE_MINIVERSION: UInt32 = 622972
FSCTL_TXFS_TRANSACTION_ACTIVE: UInt32 = 606604
FSCTL_SET_ZERO_ON_DEALLOCATION: UInt32 = 590228
FSCTL_SET_REPAIR: UInt32 = 590232
FSCTL_GET_REPAIR: UInt32 = 590236
FSCTL_WAIT_FOR_REPAIR: UInt32 = 590240
FSCTL_INITIATE_REPAIR: UInt32 = 590248
FSCTL_CSC_INTERNAL: UInt32 = 590255
FSCTL_SHRINK_VOLUME: UInt32 = 590256
FSCTL_SET_SHORT_NAME_BEHAVIOR: UInt32 = 590260
FSCTL_DFSR_SET_GHOST_HANDLE_STATE: UInt32 = 590264
FSCTL_TXFS_LIST_TRANSACTION_LOCKED_FILES: UInt32 = 606688
FSCTL_TXFS_LIST_TRANSACTIONS: UInt32 = 606692
FSCTL_QUERY_PAGEFILE_ENCRYPTION: UInt32 = 590312
FSCTL_RESET_VOLUME_ALLOCATION_HINTS: UInt32 = 590316
FSCTL_QUERY_DEPENDENT_VOLUME: UInt32 = 590320
FSCTL_SD_GLOBAL_CHANGE: UInt32 = 590324
FSCTL_TXFS_READ_BACKUP_INFORMATION2: UInt32 = 590328
FSCTL_LOOKUP_STREAM_FROM_CLUSTER: UInt32 = 590332
FSCTL_TXFS_WRITE_BACKUP_INFORMATION2: UInt32 = 590336
FSCTL_FILE_TYPE_NOTIFICATION: UInt32 = 590340
FSCTL_FILE_LEVEL_TRIM: UInt32 = 623112
FSCTL_GET_BOOT_AREA_INFO: UInt32 = 590384
FSCTL_GET_RETRIEVAL_POINTER_BASE: UInt32 = 590388
FSCTL_SET_PERSISTENT_VOLUME_STATE: UInt32 = 590392
FSCTL_QUERY_PERSISTENT_VOLUME_STATE: UInt32 = 590396
FSCTL_REQUEST_OPLOCK: UInt32 = 590400
FSCTL_CSV_TUNNEL_REQUEST: UInt32 = 590404
FSCTL_IS_CSV_FILE: UInt32 = 590408
FSCTL_QUERY_FILE_SYSTEM_RECOGNITION: UInt32 = 590412
FSCTL_CSV_GET_VOLUME_PATH_NAME: UInt32 = 590416
FSCTL_CSV_GET_VOLUME_NAME_FOR_VOLUME_MOUNT_POINT: UInt32 = 590420
FSCTL_CSV_GET_VOLUME_PATH_NAMES_FOR_VOLUME_NAME: UInt32 = 590424
FSCTL_IS_FILE_ON_CSV_VOLUME: UInt32 = 590428
FSCTL_CORRUPTION_HANDLING: UInt32 = 590432
FSCTL_OFFLOAD_READ: UInt32 = 606820
FSCTL_OFFLOAD_WRITE: UInt32 = 623208
FSCTL_CSV_INTERNAL: UInt32 = 590444
FSCTL_SET_PURGE_FAILURE_MODE: UInt32 = 590448
FSCTL_QUERY_FILE_LAYOUT: UInt32 = 590455
FSCTL_IS_VOLUME_OWNED_BYCSVFS: UInt32 = 590456
FSCTL_GET_INTEGRITY_INFORMATION: UInt32 = 590460
FSCTL_SET_INTEGRITY_INFORMATION: UInt32 = 639616
FSCTL_QUERY_FILE_REGIONS: UInt32 = 590468
FSCTL_RKF_INTERNAL: UInt32 = 590511
FSCTL_SCRUB_DATA: UInt32 = 590512
FSCTL_REPAIR_COPIES: UInt32 = 639668
FSCTL_DISABLE_LOCAL_BUFFERING: UInt32 = 590520
FSCTL_CSV_MGMT_LOCK: UInt32 = 590524
FSCTL_CSV_QUERY_DOWN_LEVEL_FILE_SYSTEM_CHARACTERISTICS: UInt32 = 590528
FSCTL_ADVANCE_FILE_ID: UInt32 = 590532
FSCTL_CSV_SYNC_TUNNEL_REQUEST: UInt32 = 590536
FSCTL_CSV_QUERY_VETO_FILE_DIRECT_IO: UInt32 = 590540
FSCTL_WRITE_USN_REASON: UInt32 = 590544
FSCTL_CSV_CONTROL: UInt32 = 590548
FSCTL_GET_REFS_VOLUME_DATA: UInt32 = 590552
FSCTL_CSV_H_BREAKING_SYNC_TUNNEL_REQUEST: UInt32 = 590564
FSCTL_QUERY_STORAGE_CLASSES: UInt32 = 590572
FSCTL_QUERY_REGION_INFO: UInt32 = 590576
FSCTL_USN_TRACK_MODIFIED_RANGES: UInt32 = 590580
FSCTL_QUERY_SHARED_VIRTUAL_DISK_SUPPORT: UInt32 = 590592
FSCTL_SVHDX_SYNC_TUNNEL_REQUEST: UInt32 = 590596
FSCTL_SVHDX_SET_INITIATOR_INFORMATION: UInt32 = 590600
FSCTL_SET_EXTERNAL_BACKING: UInt32 = 590604
FSCTL_GET_EXTERNAL_BACKING: UInt32 = 590608
FSCTL_DELETE_EXTERNAL_BACKING: UInt32 = 590612
FSCTL_ENUM_EXTERNAL_BACKING: UInt32 = 590616
FSCTL_ENUM_OVERLAY: UInt32 = 590623
FSCTL_ADD_OVERLAY: UInt32 = 623408
FSCTL_REMOVE_OVERLAY: UInt32 = 623412
FSCTL_UPDATE_OVERLAY: UInt32 = 623416
FSCTL_SHUFFLE_FILE: UInt32 = 639808
FSCTL_DUPLICATE_EXTENTS_TO_FILE: UInt32 = 623428
FSCTL_SPARSE_OVERALLOCATE: UInt32 = 590668
FSCTL_STORAGE_QOS_CONTROL: UInt32 = 590672
FSCTL_INITIATE_FILE_METADATA_OPTIMIZATION: UInt32 = 590684
FSCTL_QUERY_FILE_METADATA_OPTIMIZATION: UInt32 = 590688
FSCTL_SVHDX_ASYNC_TUNNEL_REQUEST: UInt32 = 590692
FSCTL_GET_WOF_VERSION: UInt32 = 590696
FSCTL_HCS_SYNC_TUNNEL_REQUEST: UInt32 = 590700
FSCTL_HCS_ASYNC_TUNNEL_REQUEST: UInt32 = 590704
FSCTL_QUERY_EXTENT_READ_CACHE_INFO: UInt32 = 590711
FSCTL_QUERY_REFS_VOLUME_COUNTER_INFO: UInt32 = 590715
FSCTL_CLEAN_VOLUME_METADATA: UInt32 = 590716
FSCTL_SET_INTEGRITY_INFORMATION_EX: UInt32 = 590720
FSCTL_SUSPEND_OVERLAY: UInt32 = 590724
FSCTL_VIRTUAL_STORAGE_QUERY_PROPERTY: UInt32 = 590728
FSCTL_FILESYSTEM_GET_STATISTICS_EX: UInt32 = 590732
FSCTL_QUERY_VOLUME_CONTAINER_STATE: UInt32 = 590736
FSCTL_SET_LAYER_ROOT: UInt32 = 590740
FSCTL_QUERY_DIRECT_ACCESS_EXTENTS: UInt32 = 590747
FSCTL_NOTIFY_STORAGE_SPACE_ALLOCATION: UInt32 = 590748
FSCTL_SSDI_STORAGE_REQUEST: UInt32 = 590752
FSCTL_QUERY_DIRECT_IMAGE_ORIGINAL_BASE: UInt32 = 590756
FSCTL_READ_UNPRIVILEGED_USN_JOURNAL: UInt32 = 590763
FSCTL_GHOST_FILE_EXTENTS: UInt32 = 623532
FSCTL_QUERY_GHOSTED_FILE_EXTENTS: UInt32 = 590768
FSCTL_UNMAP_SPACE: UInt32 = 590772
FSCTL_HCS_SYNC_NO_WRITE_TUNNEL_REQUEST: UInt32 = 590776
FSCTL_START_VIRTUALIZATION_INSTANCE: UInt32 = 590784
FSCTL_GET_FILTER_FILE_IDENTIFIER: UInt32 = 590788
FSCTL_STREAMS_QUERY_PARAMETERS: UInt32 = 590788
FSCTL_STREAMS_ASSOCIATE_ID: UInt32 = 590792
FSCTL_STREAMS_QUERY_ID: UInt32 = 590796
FSCTL_GET_RETRIEVAL_POINTERS_AND_REFCOUNT: UInt32 = 590803
FSCTL_QUERY_VOLUME_NUMA_INFO: UInt32 = 590804
FSCTL_REFS_DEALLOCATE_RANGES: UInt32 = 590808
FSCTL_QUERY_REFS_SMR_VOLUME_INFO: UInt32 = 590812
FSCTL_SET_REFS_SMR_VOLUME_GC_PARAMETERS: UInt32 = 590816
FSCTL_SET_REFS_FILE_STRICTLY_SEQUENTIAL: UInt32 = 590820
FSCTL_DUPLICATE_EXTENTS_TO_FILE_EX: UInt32 = 623592
FSCTL_QUERY_BAD_RANGES: UInt32 = 590828
FSCTL_SET_DAX_ALLOC_ALIGNMENT_HINT: UInt32 = 590832
FSCTL_DELETE_CORRUPTED_REFS_CONTAINER: UInt32 = 590836
FSCTL_SCRUB_UNDISCOVERABLE_ID: UInt32 = 590840
FSCTL_NOTIFY_DATA_CHANGE: UInt32 = 590844
FSCTL_START_VIRTUALIZATION_INSTANCE_EX: UInt32 = 590848
FSCTL_ENCRYPTION_KEY_CONTROL: UInt32 = 590852
FSCTL_VIRTUAL_STORAGE_SET_BEHAVIOR: UInt32 = 590856
FSCTL_SET_REPARSE_POINT_EX: UInt32 = 590860
FSCTL_REARRANGE_FILE: UInt32 = 640032
FSCTL_VIRTUAL_STORAGE_PASSTHROUGH: UInt32 = 590884
FSCTL_GET_RETRIEVAL_POINTER_COUNT: UInt32 = 590891
FSCTL_ENABLE_PER_IO_FLAGS: UInt32 = 590892
FSCTL_QUERY_ASYNC_DUPLICATE_EXTENTS_STATUS: UInt32 = 590896
FSCTL_SMB_SHARE_FLUSH_AND_PURGE: UInt32 = 590908
FSCTL_REFS_STREAM_SNAPSHOT_MANAGEMENT: UInt32 = 590912
FSCTL_MANAGE_BYPASS_IO: UInt32 = 590920
FSCTL_REFS_DEALLOCATE_RANGES_EX: UInt32 = 590924
FSCTL_SET_CACHED_RUNS_STATE: UInt32 = 590928
FSCTL_REFS_SET_VOLUME_COMPRESSION_INFO: UInt32 = 590932
FSCTL_REFS_QUERY_VOLUME_COMPRESSION_INFO: UInt32 = 590936
FSCTL_DUPLICATE_CLUSTER: UInt32 = 590940
FSCTL_CREATE_LCN_WEAK_REFERENCE: UInt32 = 590944
FSCTL_CLEAR_LCN_WEAK_REFERENCE: UInt32 = 590948
FSCTL_QUERY_LCN_WEAK_REFERENCE: UInt32 = 590952
FSCTL_CLEAR_ALL_LCN_WEAK_REFERENCES: UInt32 = 590956
FSCTL_REFS_SET_VOLUME_DEDUP_INFO: UInt32 = 590960
FSCTL_REFS_QUERY_VOLUME_DEDUP_INFO: UInt32 = 590964
FSCTL_LMR_QUERY_INFO: UInt32 = 590968
FSCTL_REFS_CHECKPOINT_VOLUME: UInt32 = 590972
FSCTL_REFS_QUERY_VOLUME_TOTAL_SHARED_LCNS: UInt32 = 590976
FSCTL_UPGRADE_VOLUME: UInt32 = 590980
FSCTL_REFS_SET_VOLUME_IO_METRICS_INFO: UInt32 = 590984
FSCTL_REFS_QUERY_VOLUME_IO_METRICS_INFO: UInt32 = 590988
GET_VOLUME_BITMAP_FLAG_MASK_METADATA: UInt32 = 1
FLAG_USN_TRACK_MODIFIED_RANGES_ENABLE: UInt32 = 1
USN_PAGE_SIZE: UInt32 = 4096
USN_REASON_DATA_OVERWRITE: UInt32 = 1
USN_REASON_DATA_EXTEND: UInt32 = 2
USN_REASON_DATA_TRUNCATION: UInt32 = 4
USN_REASON_NAMED_DATA_OVERWRITE: UInt32 = 16
USN_REASON_NAMED_DATA_EXTEND: UInt32 = 32
USN_REASON_NAMED_DATA_TRUNCATION: UInt32 = 64
USN_REASON_FILE_CREATE: UInt32 = 256
USN_REASON_FILE_DELETE: UInt32 = 512
USN_REASON_EA_CHANGE: UInt32 = 1024
USN_REASON_SECURITY_CHANGE: UInt32 = 2048
USN_REASON_RENAME_OLD_NAME: UInt32 = 4096
USN_REASON_RENAME_NEW_NAME: UInt32 = 8192
USN_REASON_INDEXABLE_CHANGE: UInt32 = 16384
USN_REASON_BASIC_INFO_CHANGE: UInt32 = 32768
USN_REASON_HARD_LINK_CHANGE: UInt32 = 65536
USN_REASON_COMPRESSION_CHANGE: UInt32 = 131072
USN_REASON_ENCRYPTION_CHANGE: UInt32 = 262144
USN_REASON_OBJECT_ID_CHANGE: UInt32 = 524288
USN_REASON_REPARSE_POINT_CHANGE: UInt32 = 1048576
USN_REASON_STREAM_CHANGE: UInt32 = 2097152
USN_REASON_TRANSACTED_CHANGE: UInt32 = 4194304
USN_REASON_INTEGRITY_CHANGE: UInt32 = 8388608
USN_REASON_DESIRED_STORAGE_CLASS_CHANGE: UInt32 = 16777216
USN_REASON_CLOSE: UInt32 = 2147483648
USN_DELETE_VALID_FLAGS: UInt32 = 3
MARK_HANDLE_PROTECT_CLUSTERS: UInt32 = 1
MARK_HANDLE_TXF_SYSTEM_LOG: UInt32 = 4
MARK_HANDLE_NOT_TXF_SYSTEM_LOG: UInt32 = 8
MARK_HANDLE_REALTIME: UInt32 = 32
MARK_HANDLE_NOT_REALTIME: UInt32 = 64
MARK_HANDLE_CLOUD_SYNC: UInt32 = 2048
MARK_HANDLE_READ_COPY: UInt32 = 128
MARK_HANDLE_NOT_READ_COPY: UInt32 = 256
MARK_HANDLE_FILTER_METADATA: UInt32 = 512
MARK_HANDLE_RETURN_PURGE_FAILURE: UInt32 = 1024
MARK_HANDLE_DISABLE_FILE_METADATA_OPTIMIZATION: UInt32 = 4096
MARK_HANDLE_ENABLE_USN_SOURCE_ON_PAGING_IO: UInt32 = 8192
MARK_HANDLE_SKIP_COHERENCY_SYNC_DISALLOW_WRITES: UInt32 = 16384
MARK_HANDLE_SUPPRESS_VOLUME_OPEN_FLUSH: UInt32 = 32768
MARK_HANDLE_ENABLE_CPU_CACHE: UInt32 = 268435456
VOLUME_IS_DIRTY: UInt32 = 1
VOLUME_UPGRADE_SCHEDULED: UInt32 = 2
VOLUME_SESSION_OPEN: UInt32 = 4
FILE_PREFETCH_TYPE_FOR_CREATE: UInt32 = 1
FILE_PREFETCH_TYPE_FOR_DIRENUM: UInt32 = 2
FILE_PREFETCH_TYPE_FOR_CREATE_EX: UInt32 = 3
FILE_PREFETCH_TYPE_FOR_DIRENUM_EX: UInt32 = 4
FILE_PREFETCH_TYPE_MAX: UInt32 = 4
FILESYSTEM_STATISTICS_TYPE_REFS: UInt32 = 4
FILE_ZERO_DATA_INFORMATION_FLAG_PRESERVE_CACHED_DATA: UInt32 = 1
FILE_SET_ENCRYPTION: UInt32 = 1
FILE_CLEAR_ENCRYPTION: UInt32 = 2
STREAM_SET_ENCRYPTION: UInt32 = 3
STREAM_CLEAR_ENCRYPTION: UInt32 = 4
MAXIMUM_ENCRYPTION_VALUE: UInt32 = 4
ENCRYPTION_FORMAT_DEFAULT: UInt32 = 1
ENCRYPTED_DATA_INFO_SPARSE_FILE: UInt32 = 1
COPYFILE_SIS_LINK: UInt32 = 1
COPYFILE_SIS_REPLACE: UInt32 = 2
COPYFILE_SIS_FLAGS: UInt32 = 3
SET_REPAIR_ENABLED: UInt32 = 1
SET_REPAIR_WARN_ABOUT_DATA_LOSS: UInt32 = 8
SET_REPAIR_DISABLED_AND_BUGCHECK_ON_CORRUPT: UInt32 = 16
SET_REPAIR_VALID_MASK: UInt32 = 25
FILE_INITIATE_REPAIR_HINT1_FILE_RECORD_NOT_IN_USE: UInt64 = 1
FILE_INITIATE_REPAIR_HINT1_FILE_RECORD_REUSED: UInt64 = 2
FILE_INITIATE_REPAIR_HINT1_FILE_RECORD_NOT_EXIST: UInt64 = 4
FILE_INITIATE_REPAIR_HINT1_FILE_RECORD_NOT_BASE_RECORD: UInt64 = 8
FILE_INITIATE_REPAIR_HINT1_SYSTEM_FILE: UInt64 = 16
FILE_INITIATE_REPAIR_HINT1_NOT_IMPLEMENTED: UInt64 = 32
FILE_INITIATE_REPAIR_HINT1_UNABLE_TO_REPAIR: UInt64 = 64
FILE_INITIATE_REPAIR_HINT1_REPAIR_DISABLED: UInt64 = 128
FILE_INITIATE_REPAIR_HINT1_RECURSIVELY_CORRUPTED: UInt64 = 256
FILE_INITIATE_REPAIR_HINT1_ORPHAN_GENERATED: UInt64 = 512
FILE_INITIATE_REPAIR_HINT1_REPAIRED: UInt64 = 1024
FILE_INITIATE_REPAIR_HINT1_NOTHING_WRONG: UInt64 = 2048
FILE_INITIATE_REPAIR_HINT1_ATTRIBUTE_NOT_FOUND: UInt64 = 4096
FILE_INITIATE_REPAIR_HINT1_POTENTIAL_CROSSLINK: UInt64 = 8192
FILE_INITIATE_REPAIR_HINT1_STALE_INFORMATION: UInt64 = 16384
FILE_INITIATE_REPAIR_HINT1_CLUSTERS_ALREADY_IN_USE: UInt64 = 32768
FILE_INITIATE_REPAIR_HINT1_LCN_NOT_EXIST: UInt64 = 65536
FILE_INITIATE_REPAIR_HINT1_INVALID_RUN_LENGTH: UInt64 = 131072
FILE_INITIATE_REPAIR_HINT1_FILE_RECORD_NOT_ORPHAN: UInt64 = 262144
FILE_INITIATE_REPAIR_HINT1_FILE_RECORD_IS_BASE_RECORD: UInt64 = 524288
FILE_INITIATE_REPAIR_HINT1_INVALID_ARRAY_LENGTH_COUNT: UInt64 = 1048576
FILE_INITIATE_REPAIR_HINT1_SID_VALID: UInt64 = 2097152
FILE_INITIATE_REPAIR_HINT1_SID_MISMATCH: UInt64 = 4194304
FILE_INITIATE_REPAIR_HINT1_INVALID_PARENT: UInt64 = 8388608
FILE_INITIATE_REPAIR_HINT1_PARENT_FILE_RECORD_NOT_IN_USE: UInt64 = 16777216
FILE_INITIATE_REPAIR_HINT1_PARENT_FILE_RECORD_REUSED: UInt64 = 33554432
FILE_INITIATE_REPAIR_HINT1_PARENT_FILE_RECORD_NOT_EXIST: UInt64 = 67108864
FILE_INITIATE_REPAIR_HINT1_PARENT_FILE_RECORD_NOT_BASE_RECORD: UInt64 = 134217728
FILE_INITIATE_REPAIR_HINT1_PARENT_FILE_RECORD_NOT_INDEX: UInt64 = 268435456
FILE_INITIATE_REPAIR_HINT1_VALID_INDEX_ENTRY: UInt64 = 536870912
FILE_INITIATE_REPAIR_HINT1_OUT_OF_GENERIC_NAMES: UInt64 = 1073741824
FILE_INITIATE_REPAIR_HINT1_OUT_OF_RESOURCE: UInt64 = 2147483648
FILE_INITIATE_REPAIR_HINT1_INVALID_LCN: UInt64 = 4294967296
FILE_INITIATE_REPAIR_HINT1_INVALID_VCN: UInt64 = 8589934592
FILE_INITIATE_REPAIR_HINT1_NAME_CONFLICT: UInt64 = 17179869184
FILE_INITIATE_REPAIR_HINT1_ORPHAN: UInt64 = 34359738368
FILE_INITIATE_REPAIR_HINT1_ATTRIBUTE_TOO_SMALL: UInt64 = 68719476736
FILE_INITIATE_REPAIR_HINT1_ATTRIBUTE_NON_RESIDENT: UInt64 = 137438953472
FILE_INITIATE_REPAIR_HINT1_DENY_DEFRAG: UInt64 = 274877906944
FILE_INITIATE_REPAIR_HINT1_PREVIOUS_PARENT_STILL_VALID: UInt64 = 549755813888
FILE_INITIATE_REPAIR_HINT1_INDEX_ENTRY_MISMATCH: UInt64 = 1099511627776
FILE_INITIATE_REPAIR_HINT1_INVALID_ORPHAN_RECOVERY_NAME: UInt64 = 2199023255552
FILE_INITIATE_REPAIR_HINT1_MULTIPLE_FILE_NAME_ATTRIBUTES: UInt64 = 4398046511104
TXFS_LOGGING_MODE_SIMPLE: UInt32 = 1
TXFS_LOGGING_MODE_FULL: UInt32 = 2
TXFS_TRANSACTION_STATE_NONE: UInt32 = 0
TXFS_TRANSACTION_STATE_ACTIVE: UInt32 = 1
TXFS_TRANSACTION_STATE_PREPARED: UInt32 = 2
TXFS_TRANSACTION_STATE_NOTACTIVE: UInt32 = 3
TXFS_RM_STATE_NOT_STARTED: UInt32 = 0
TXFS_RM_STATE_STARTING: UInt32 = 1
TXFS_RM_STATE_ACTIVE: UInt32 = 2
TXFS_RM_STATE_SHUTTING_DOWN: UInt32 = 3
TXFS_ROLLFORWARD_REDO_FLAG_USE_LAST_REDO_LSN: UInt32 = 1
TXFS_ROLLFORWARD_REDO_FLAG_USE_LAST_VIRTUAL_CLOCK: UInt32 = 2
TXFS_START_RM_FLAG_LOG_CONTAINER_COUNT_MAX: UInt32 = 1
TXFS_START_RM_FLAG_LOG_CONTAINER_COUNT_MIN: UInt32 = 2
TXFS_START_RM_FLAG_LOG_CONTAINER_SIZE: UInt32 = 4
TXFS_START_RM_FLAG_LOG_GROWTH_INCREMENT_NUM_CONTAINERS: UInt32 = 8
TXFS_START_RM_FLAG_LOG_GROWTH_INCREMENT_PERCENT: UInt32 = 16
TXFS_START_RM_FLAG_LOG_AUTO_SHRINK_PERCENTAGE: UInt32 = 32
TXFS_START_RM_FLAG_LOG_NO_CONTAINER_COUNT_MAX: UInt32 = 64
TXFS_START_RM_FLAG_LOG_NO_CONTAINER_COUNT_MIN: UInt32 = 128
TXFS_START_RM_FLAG_RECOVER_BEST_EFFORT: UInt32 = 512
TXFS_START_RM_FLAG_LOGGING_MODE: UInt32 = 1024
TXFS_START_RM_FLAG_PRESERVE_CHANGES: UInt32 = 2048
TXFS_START_RM_FLAG_PREFER_CONSISTENCY: UInt32 = 4096
TXFS_START_RM_FLAG_PREFER_AVAILABILITY: UInt32 = 8192
TXFS_LIST_TRANSACTION_LOCKED_FILES_ENTRY_FLAG_CREATED: UInt32 = 1
TXFS_LIST_TRANSACTION_LOCKED_FILES_ENTRY_FLAG_DELETED: UInt32 = 2
TXFS_TRANSACTED_VERSION_NONTRANSACTED: UInt32 = 4294967294
TXFS_TRANSACTED_VERSION_UNCOMMITTED: UInt32 = 4294967295
TXFS_SAVEPOINT_SET: UInt32 = 1
TXFS_SAVEPOINT_ROLLBACK: UInt32 = 2
TXFS_SAVEPOINT_CLEAR: UInt32 = 4
TXFS_SAVEPOINT_CLEAR_ALL: UInt32 = 16
PERSISTENT_VOLUME_STATE_SHORT_NAME_CREATION_DISABLED: UInt32 = 1
PERSISTENT_VOLUME_STATE_VOLUME_SCRUB_DISABLED: UInt32 = 2
PERSISTENT_VOLUME_STATE_GLOBAL_METADATA_NO_SEEK_PENALTY: UInt32 = 4
PERSISTENT_VOLUME_STATE_LOCAL_METADATA_NO_SEEK_PENALTY: UInt32 = 8
PERSISTENT_VOLUME_STATE_NO_HEAT_GATHERING: UInt32 = 16
PERSISTENT_VOLUME_STATE_CONTAINS_BACKING_WIM: UInt32 = 32
PERSISTENT_VOLUME_STATE_BACKED_BY_WIM: UInt32 = 64
PERSISTENT_VOLUME_STATE_NO_WRITE_AUTO_TIERING: UInt32 = 128
PERSISTENT_VOLUME_STATE_TXF_DISABLED: UInt32 = 256
PERSISTENT_VOLUME_STATE_REALLOCATE_ALL_DATA_WRITES: UInt32 = 512
PERSISTENT_VOLUME_STATE_CHKDSK_RAN_ONCE: UInt32 = 1024
PERSISTENT_VOLUME_STATE_MODIFIED_BY_CHKDSK: UInt32 = 2048
PERSISTENT_VOLUME_STATE_DAX_FORMATTED: UInt32 = 4096
PERSISTENT_VOLUME_STATE_DEV_VOLUME: UInt32 = 8192
PERSISTENT_VOLUME_STATE_TRUSTED_VOLUME: UInt32 = 16384
OPLOCK_LEVEL_CACHE_READ: UInt32 = 1
OPLOCK_LEVEL_CACHE_HANDLE: UInt32 = 2
OPLOCK_LEVEL_CACHE_WRITE: UInt32 = 4
REQUEST_OPLOCK_INPUT_FLAG_REQUEST: UInt32 = 1
REQUEST_OPLOCK_INPUT_FLAG_ACK: UInt32 = 2
REQUEST_OPLOCK_INPUT_FLAG_COMPLETE_ACK_ON_CLOSE: UInt32 = 4
REQUEST_OPLOCK_CURRENT_VERSION: UInt32 = 1
REQUEST_OPLOCK_OUTPUT_FLAG_ACK_REQUIRED: UInt32 = 1
REQUEST_OPLOCK_OUTPUT_FLAG_MODES_PROVIDED: UInt32 = 2
REQUEST_OPLOCK_OUTPUT_FLAG_WRITABLE_SECTION_PRESENT: UInt32 = 4
QUERY_DEPENDENT_VOLUME_REQUEST_FLAG_HOST_VOLUMES: UInt32 = 1
QUERY_DEPENDENT_VOLUME_REQUEST_FLAG_GUEST_VOLUMES: UInt32 = 2
SD_GLOBAL_CHANGE_TYPE_MACHINE_SID: UInt32 = 1
SD_GLOBAL_CHANGE_TYPE_QUERY_STATS: UInt32 = 65536
SD_GLOBAL_CHANGE_TYPE_ENUM_SDS: UInt32 = 131072
LOOKUP_STREAM_FROM_CLUSTER_ENTRY_FLAG_PAGE_FILE: UInt32 = 1
LOOKUP_STREAM_FROM_CLUSTER_ENTRY_FLAG_DENY_DEFRAG_SET: UInt32 = 2
LOOKUP_STREAM_FROM_CLUSTER_ENTRY_FLAG_FS_SYSTEM_FILE: UInt32 = 4
LOOKUP_STREAM_FROM_CLUSTER_ENTRY_FLAG_TXF_SYSTEM_FILE: UInt32 = 8
LOOKUP_STREAM_FROM_CLUSTER_ENTRY_ATTRIBUTE_MASK: UInt32 = 4278190080
LOOKUP_STREAM_FROM_CLUSTER_ENTRY_ATTRIBUTE_DATA: UInt32 = 16777216
LOOKUP_STREAM_FROM_CLUSTER_ENTRY_ATTRIBUTE_INDEX: UInt32 = 33554432
LOOKUP_STREAM_FROM_CLUSTER_ENTRY_ATTRIBUTE_SYSTEM: UInt32 = 50331648
FILE_TYPE_NOTIFICATION_FLAG_USAGE_BEGIN: UInt32 = 1
FILE_TYPE_NOTIFICATION_FLAG_USAGE_END: UInt32 = 2
FILE_TYPE_NOTIFICATION_GUID_PAGE_FILE: Guid = Guid('{0d0a64a1-38fc-4db8-9fe7-3f4352cd7c5c}')
FILE_TYPE_NOTIFICATION_GUID_HIBERNATION_FILE: Guid = Guid('{b7624d64-b9a3-4cf8-8011-5b86c940e7b7}')
FILE_TYPE_NOTIFICATION_GUID_CRASHDUMP_FILE: Guid = Guid('{9d453eb7-d2a6-4dbd-a2e3-fbd0ed9109a9}')
CSV_MGMTLOCK_CHECK_VOLUME_REDIRECTED: UInt32 = 1
CSV_INVALID_DEVICE_NUMBER: UInt32 = 4294967295
CSV_QUERY_MDS_PATH_V2_VERSION_1: UInt32 = 1
CSV_QUERY_MDS_PATH_FLAG_STORAGE_ON_THIS_NODE_IS_CONNECTED: UInt32 = 1
CSV_QUERY_MDS_PATH_FLAG_CSV_DIRECT_IO_ENABLED: UInt32 = 2
CSV_QUERY_MDS_PATH_FLAG_SMB_BYPASS_CSV_ENABLED: UInt32 = 4
QUERY_FILE_LAYOUT_RESTART: UInt32 = 1
QUERY_FILE_LAYOUT_INCLUDE_NAMES: UInt32 = 2
QUERY_FILE_LAYOUT_INCLUDE_STREAMS: UInt32 = 4
QUERY_FILE_LAYOUT_INCLUDE_EXTENTS: UInt32 = 8
QUERY_FILE_LAYOUT_INCLUDE_EXTRA_INFO: UInt32 = 16
QUERY_FILE_LAYOUT_INCLUDE_STREAMS_WITH_NO_CLUSTERS_ALLOCATED: UInt32 = 32
QUERY_FILE_LAYOUT_INCLUDE_FULL_PATH_IN_NAMES: UInt32 = 64
QUERY_FILE_LAYOUT_INCLUDE_STREAM_INFORMATION: UInt32 = 128
QUERY_FILE_LAYOUT_INCLUDE_STREAM_INFORMATION_FOR_DSC_ATTRIBUTE: UInt32 = 256
QUERY_FILE_LAYOUT_INCLUDE_STREAM_INFORMATION_FOR_TXF_ATTRIBUTE: UInt32 = 512
QUERY_FILE_LAYOUT_INCLUDE_STREAM_INFORMATION_FOR_EFS_ATTRIBUTE: UInt32 = 1024
QUERY_FILE_LAYOUT_INCLUDE_ONLY_FILES_WITH_SPECIFIC_ATTRIBUTES: UInt32 = 2048
QUERY_FILE_LAYOUT_INCLUDE_FILES_WITH_DSC_ATTRIBUTE: UInt32 = 4096
QUERY_FILE_LAYOUT_INCLUDE_STREAM_INFORMATION_FOR_DATA_ATTRIBUTE: UInt32 = 8192
QUERY_FILE_LAYOUT_INCLUDE_STREAM_INFORMATION_FOR_REPARSE_ATTRIBUTE: UInt32 = 16384
QUERY_FILE_LAYOUT_INCLUDE_STREAM_INFORMATION_FOR_EA_ATTRIBUTE: UInt32 = 32768
QUERY_FILE_LAYOUT_SINGLE_INSTANCED: UInt32 = 1
FILE_LAYOUT_NAME_ENTRY_PRIMARY: UInt32 = 1
FILE_LAYOUT_NAME_ENTRY_DOS: UInt32 = 2
STREAM_LAYOUT_ENTRY_IMMOVABLE: UInt32 = 1
STREAM_LAYOUT_ENTRY_PINNED: UInt32 = 2
STREAM_LAYOUT_ENTRY_RESIDENT: UInt32 = 4
STREAM_LAYOUT_ENTRY_NO_CLUSTERS_ALLOCATED: UInt32 = 8
STREAM_LAYOUT_ENTRY_HAS_INFORMATION: UInt32 = 16
STREAM_EXTENT_ENTRY_AS_RETRIEVAL_POINTERS: UInt32 = 1
STREAM_EXTENT_ENTRY_ALL_EXTENTS: UInt32 = 2
CHECKSUM_TYPE_NONE: UInt32 = 0
CHECKSUM_TYPE_CRC32: UInt32 = 1
CHECKSUM_TYPE_CRC64: UInt32 = 2
CHECKSUM_TYPE_ECC: UInt32 = 3
CHECKSUM_TYPE_SHA256: UInt32 = 4
CHECKSUM_TYPE_FIRST_UNUSED_TYPE: UInt32 = 5
FSCTL_INTEGRITY_FLAG_CHECKSUM_ENFORCEMENT_OFF: UInt32 = 1
OFFLOAD_READ_FLAG_ALL_ZERO_BEYOND_CURRENT_RANGE: UInt32 = 1
SET_PURGE_FAILURE_MODE_ENABLED: UInt32 = 1
SET_PURGE_FAILURE_MODE_DISABLED: UInt32 = 2
FILE_REGION_USAGE_VALID_CACHED_DATA: UInt32 = 1
FILE_REGION_USAGE_VALID_NONCACHED_DATA: UInt32 = 2
FILE_REGION_USAGE_OTHER_PAGE_ALIGNMENT: UInt32 = 4
FILE_REGION_USAGE_LARGE_PAGE_ALIGNMENT: UInt32 = 8
FILE_REGION_USAGE_HUGE_PAGE_ALIGNMENT: UInt32 = 16
FILE_REGION_USAGE_QUERY_ALIGNMENT: UInt32 = 8
FILE_STORAGE_TIER_NAME_LENGTH: UInt32 = 256
FILE_STORAGE_TIER_DESCRIPTION_LENGTH: UInt32 = 512
FILE_STORAGE_TIER_FLAG_WRITE_BACK_CACHE: UInt32 = 2097152
FILE_STORAGE_TIER_FLAG_READ_CACHE: UInt32 = 4194304
FILE_STORAGE_TIER_FLAG_PARITY: UInt32 = 8388608
FILE_STORAGE_TIER_FLAG_SMR: UInt32 = 16777216
QUERY_STORAGE_CLASSES_FLAGS_MEASURE_WRITE: UInt32 = 2147483648
QUERY_STORAGE_CLASSES_FLAGS_MEASURE_READ: UInt32 = 1073741824
QUERY_STORAGE_CLASSES_FLAGS_NO_DEFRAG_VOLUME: UInt32 = 536870912
QUERY_FILE_LAYOUT_REPARSE_DATA_INVALID: UInt32 = 1
QUERY_FILE_LAYOUT_REPARSE_TAG_INVALID: UInt32 = 2
DUPLICATE_EXTENTS_DATA_EX_SOURCE_ATOMIC: UInt32 = 1
DUPLICATE_EXTENTS_DATA_EX_ASYNC: UInt32 = 2
REFS_SMR_VOLUME_INFO_OUTPUT_VERSION_V0: UInt32 = 0
REFS_SMR_VOLUME_INFO_OUTPUT_VERSION_V1: UInt32 = 1
REFS_SMR_VOLUME_GC_PARAMETERS_VERSION_V1: UInt32 = 1
STREAMS_INVALID_ID: UInt32 = 0
STREAMS_MAX_ID: UInt32 = 65535
STREAMS_ASSOCIATE_ID_CLEAR: UInt32 = 1
STREAMS_ASSOCIATE_ID_SET: UInt32 = 2
DAX_ALLOC_ALIGNMENT_FLAG_MANDATORY: UInt32 = 1
DAX_ALLOC_ALIGNMENT_FLAG_FALLBACK_SPECIFIED: UInt32 = 2
WOF_CURRENT_VERSION: UInt32 = 1
WOF_PROVIDER_CLOUD: UInt32 = 3
WIM_PROVIDER_CURRENT_VERSION: UInt32 = 1
WIM_PROVIDER_EXTERNAL_FLAG_NOT_ACTIVE: UInt32 = 1
WIM_PROVIDER_EXTERNAL_FLAG_SUSPENDED: UInt32 = 2
FILE_PROVIDER_CURRENT_VERSION: UInt32 = 1
FILE_PROVIDER_SINGLE_FILE: UInt32 = 1
FILE_PROVIDER_COMPRESSION_MAXIMUM: UInt32 = 4
FILE_PROVIDER_FLAG_COMPRESS_ON_WRITE: UInt32 = 1
CONTAINER_VOLUME_STATE_HOSTING_CONTAINER: UInt32 = 1
CONTAINER_ROOT_INFO_FLAG_SCRATCH_ROOT: UInt32 = 1
CONTAINER_ROOT_INFO_FLAG_LAYER_ROOT: UInt32 = 2
CONTAINER_ROOT_INFO_FLAG_VIRTUALIZATION_ROOT: UInt32 = 4
CONTAINER_ROOT_INFO_FLAG_VIRTUALIZATION_TARGET_ROOT: UInt32 = 8
CONTAINER_ROOT_INFO_FLAG_VIRTUALIZATION_EXCEPTION_ROOT: UInt32 = 16
CONTAINER_ROOT_INFO_FLAG_BIND_ROOT: UInt32 = 32
CONTAINER_ROOT_INFO_FLAG_BIND_TARGET_ROOT: UInt32 = 64
CONTAINER_ROOT_INFO_FLAG_BIND_EXCEPTION_ROOT: UInt32 = 128
CONTAINER_ROOT_INFO_FLAG_BIND_DO_NOT_MAP_NAME: UInt32 = 256
CONTAINER_ROOT_INFO_FLAG_UNION_LAYER_ROOT: UInt32 = 512
CONTAINER_ROOT_INFO_VALID_FLAGS: UInt32 = 1023
PROJFS_PROTOCOL_VERSION: UInt32 = 3
EFS_TRACKED_OFFSET_HEADER_FLAG: UInt32 = 1
SPACES_TRACKED_OFFSET_HEADER_FLAG: UInt32 = 2
class BIN_COUNT(Structure):
    BinRange: win32more.Windows.Win32.System.Ioctl.BIN_RANGE
    BinCount: UInt32
class BIN_RANGE(Structure):
    StartValue: Int64
    Length: Int64
class BIN_RESULTS(Structure):
    NumberOfBins: UInt32
    BinCounts: win32more.Windows.Win32.System.Ioctl.BIN_COUNT * 1
BIN_TYPES = Int32
RequestSize: win32more.Windows.Win32.System.Ioctl.BIN_TYPES = 0
RequestLocation: win32more.Windows.Win32.System.Ioctl.BIN_TYPES = 1
class BOOT_AREA_INFO(Structure):
    BootSectorCount: UInt32
    BootSectors: _Anonymous_e__Struct * 2
    class _Anonymous_e__Struct(Structure):
        Offset: Int64
class BULK_SECURITY_TEST_DATA(Structure):
    DesiredAccess: UInt32
    SecurityIds: UInt32 * 1
CHANGER_DEVICE_PROBLEM_TYPE = Int32
DeviceProblemNone: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 0
DeviceProblemHardware: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 1
DeviceProblemCHMError: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 2
DeviceProblemDoorOpen: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 3
DeviceProblemCalibrationError: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 4
DeviceProblemTargetFailure: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 5
DeviceProblemCHMMoveError: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 6
DeviceProblemCHMZeroError: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 7
DeviceProblemCartridgeInsertError: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 8
DeviceProblemPositionError: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 9
DeviceProblemSensorError: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 10
DeviceProblemCartridgeEjectError: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 11
DeviceProblemGripperError: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 12
DeviceProblemDriveError: win32more.Windows.Win32.System.Ioctl.CHANGER_DEVICE_PROBLEM_TYPE = 13
class CHANGER_ELEMENT(Structure):
    ElementType: win32more.Windows.Win32.System.Ioctl.ELEMENT_TYPE
    ElementAddress: UInt32
class CHANGER_ELEMENT_LIST(Structure):
    Element: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    NumberOfElements: UInt32
class CHANGER_ELEMENT_STATUS(Structure):
    Element: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    SrcElementAddress: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    Flags: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS
    ExceptionCode: UInt32
    TargetId: Byte
    Lun: Byte
    Reserved: UInt16
    PrimaryVolumeID: Byte * 36
    AlternateVolumeID: Byte * 36
class CHANGER_ELEMENT_STATUS_EX(Structure):
    Element: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    SrcElementAddress: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    Flags: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS
    ExceptionCode: UInt32
    TargetId: Byte
    Lun: Byte
    Reserved: UInt16
    PrimaryVolumeID: Byte * 36
    AlternateVolumeID: Byte * 36
    VendorIdentification: Byte * 8
    ProductIdentification: Byte * 16
    SerialNumber: Byte * 32
CHANGER_ELEMENT_STATUS_FLAGS = UInt32
ELEMENT_STATUS_ACCESS: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 8
ELEMENT_STATUS_AVOLTAG: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 536870912
ELEMENT_STATUS_EXCEPT: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 4
ELEMENT_STATUS_EXENAB: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 16
ELEMENT_STATUS_FULL: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 1
ELEMENT_STATUS_ID_VALID: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 8192
ELEMENT_STATUS_IMPEXP: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 2
ELEMENT_STATUS_INENAB: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 32
ELEMENT_STATUS_INVERT: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 4194304
ELEMENT_STATUS_LUN_VALID: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 4096
ELEMENT_STATUS_NOT_BUS: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 32768
ELEMENT_STATUS_PVOLTAG: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 268435456
ELEMENT_STATUS_SVALID: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 8388608
ELEMENT_STATUS_PRODUCT_DATA: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS_FLAGS = 64
class CHANGER_EXCHANGE_MEDIUM(Structure):
    Transport: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    Source: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    Destination1: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    Destination2: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    Flip1: win32more.Windows.Win32.Foundation.BOOLEAN
    Flip2: win32more.Windows.Win32.Foundation.BOOLEAN
CHANGER_FEATURES = UInt32
CHANGER_BAR_CODE_SCANNER_INSTALLED: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 1
CHANGER_CARTRIDGE_MAGAZINE: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 256
CHANGER_CLEANER_ACCESS_NOT_VALID: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 262144
CHANGER_CLEANER_SLOT: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 64
CHANGER_CLOSE_IEPORT: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 4
CHANGER_DEVICE_REINITIALIZE_CAPABLE: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 134217728
CHANGER_DRIVE_CLEANING_REQUIRED: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 65536
CHANGER_DRIVE_EMPTY_ON_DOOR_ACCESS: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 536870912
CHANGER_EXCHANGE_MEDIA: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 32
CHANGER_INIT_ELEM_STAT_WITH_RANGE: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 2
CHANGER_KEYPAD_ENABLE_DISABLE: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 268435456
CHANGER_LOCK_UNLOCK: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 128
CHANGER_MEDIUM_FLIP: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 512
CHANGER_OPEN_IEPORT: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 8
CHANGER_POSITION_TO_ELEMENT: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 1024
CHANGER_PREDISMOUNT_EJECT_REQUIRED: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 131072
CHANGER_PREMOUNT_EJECT_REQUIRED: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 524288
CHANGER_REPORT_IEPORT_STATE: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 2048
CHANGER_SERIAL_NUMBER_VALID: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 67108864
CHANGER_STATUS_NON_VOLATILE: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 16
CHANGER_STORAGE_DRIVE: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 4096
CHANGER_STORAGE_IEPORT: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 8192
CHANGER_STORAGE_SLOT: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 16384
CHANGER_STORAGE_TRANSPORT: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 32768
CHANGER_VOLUME_ASSERT: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 4194304
CHANGER_VOLUME_IDENTIFICATION: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 1048576
CHANGER_VOLUME_REPLACE: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 8388608
CHANGER_VOLUME_SEARCH: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 2097152
CHANGER_VOLUME_UNDEFINE: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES = 16777216
class CHANGER_INITIALIZE_ELEMENT_STATUS(Structure):
    ElementList: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_LIST
    BarCodeScan: win32more.Windows.Win32.Foundation.BOOLEAN
class CHANGER_MOVE_MEDIUM(Structure):
    Transport: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    Source: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    Destination: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    Flip: win32more.Windows.Win32.Foundation.BOOLEAN
class CHANGER_PRODUCT_DATA(Structure):
    VendorId: Byte * 8
    ProductId: Byte * 16
    Revision: Byte * 4
    SerialNumber: Byte * 32
    DeviceType: Byte
class CHANGER_READ_ELEMENT_STATUS(Structure):
    ElementList: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_LIST
    VolumeTagInfo: win32more.Windows.Win32.Foundation.BOOLEAN
class CHANGER_SEND_VOLUME_TAG_INFORMATION(Structure):
    StartingElement: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    ActionCode: UInt32
    VolumeIDTemplate: Byte * 40
class CHANGER_SET_ACCESS(Structure):
    Element: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    Control: UInt32
class CHANGER_SET_POSITION(Structure):
    Transport: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    Destination: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT
    Flip: win32more.Windows.Win32.Foundation.BOOLEAN
class CLASS_MEDIA_CHANGE_CONTEXT(Structure):
    MediaChangeCount: UInt32
    NewState: UInt32
class CLUSTER_RANGE(Structure):
    StartingCluster: Int64
    ClusterCount: Int64
class CONTAINER_ROOT_INFO_INPUT(Structure):
    Flags: UInt32
class CONTAINER_ROOT_INFO_OUTPUT(Structure):
    ContainerRootIdLength: UInt16
    ContainerRootId: Byte * 1
class CONTAINER_VOLUME_STATE(Structure):
    Flags: UInt32
class CREATE_DISK(Structure):
    PartitionStyle: win32more.Windows.Win32.System.Ioctl.PARTITION_STYLE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Mbr: win32more.Windows.Win32.System.Ioctl.CREATE_DISK_MBR
        Gpt: win32more.Windows.Win32.System.Ioctl.CREATE_DISK_GPT
class CREATE_DISK_GPT(Structure):
    DiskId: Guid
    MaxPartitionCount: UInt32
class CREATE_DISK_MBR(Structure):
    Signature: UInt32
class CREATE_USN_JOURNAL_DATA(Structure):
    MaximumSize: UInt64
    AllocationDelta: UInt64
CSVFS_DISK_CONNECTIVITY = Int32
CsvFsDiskConnectivityNone: win32more.Windows.Win32.System.Ioctl.CSVFS_DISK_CONNECTIVITY = 0
CsvFsDiskConnectivityMdsNodeOnly: win32more.Windows.Win32.System.Ioctl.CSVFS_DISK_CONNECTIVITY = 1
CsvFsDiskConnectivitySubsetOfNodes: win32more.Windows.Win32.System.Ioctl.CSVFS_DISK_CONNECTIVITY = 2
CsvFsDiskConnectivityAllNodes: win32more.Windows.Win32.System.Ioctl.CSVFS_DISK_CONNECTIVITY = 3
CSV_CONTROL_OP = Int32
CsvControlStartRedirectFile: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 2
CsvControlStopRedirectFile: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 3
CsvControlQueryRedirectState: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 4
CsvControlQueryFileRevision: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 6
CsvControlQueryMdsPath: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 8
CsvControlQueryFileRevisionFileId128: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 9
CsvControlQueryVolumeRedirectState: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 10
CsvControlEnableUSNRangeModificationTracking: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 13
CsvControlMarkHandleLocalVolumeMount: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 14
CsvControlUnmarkHandleLocalVolumeMount: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 15
CsvControlGetCsvFsMdsPathV2: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 18
CsvControlDisableCaching: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 19
CsvControlEnableCaching: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 20
CsvControlStartForceDFO: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 21
CsvControlStopForceDFO: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 22
CsvControlQueryMdsPathNoPause: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 23
CsvControlSetVolumeId: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 24
CsvControlQueryVolumeId: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP = 25
class CSV_CONTROL_PARAM(Structure):
    Operation: win32more.Windows.Win32.System.Ioctl.CSV_CONTROL_OP
    Unused: Int64
class CSV_IS_OWNED_BY_CSVFS(Structure):
    OwnedByCSVFS: win32more.Windows.Win32.Foundation.BOOLEAN
class CSV_MGMT_LOCK(Structure):
    Flags: UInt32
class CSV_NAMESPACE_INFO(Structure):
    Version: UInt32
    DeviceNumber: UInt32
    StartingOffset: Int64
    SectorSize: UInt32
class CSV_QUERY_FILE_REVISION(Structure):
    FileId: Int64
    FileRevision: Int64 * 3
class CSV_QUERY_FILE_REVISION_FILE_ID_128(Structure):
    FileId: win32more.Windows.Win32.Storage.FileSystem.FILE_ID_128
    FileRevision: Int64 * 3
class CSV_QUERY_MDS_PATH(Structure):
    MdsNodeId: UInt32
    DsNodeId: UInt32
    PathLength: UInt32
    Path: Char * 1
class CSV_QUERY_MDS_PATH_V2(Structure):
    Version: Int64
    RequiredSize: UInt32
    MdsNodeId: UInt32
    DsNodeId: UInt32
    Flags: UInt32
    DiskConnectivity: win32more.Windows.Win32.System.Ioctl.CSVFS_DISK_CONNECTIVITY
    VolumeId: Guid
    IpAddressOffset: UInt32
    IpAddressLength: UInt32
    PathOffset: UInt32
    PathLength: UInt32
class CSV_QUERY_REDIRECT_STATE(Structure):
    MdsNodeId: UInt32
    DsNodeId: UInt32
    FileRedirected: win32more.Windows.Win32.Foundation.BOOLEAN
class CSV_QUERY_VETO_FILE_DIRECT_IO_OUTPUT(Structure):
    VetoedFromAltitudeIntegral: UInt64
    VetoedFromAltitudeDecimal: UInt64
    Reason: Char * 256
class CSV_QUERY_VOLUME_ID(Structure):
    VolumeId: Guid
class CSV_QUERY_VOLUME_REDIRECT_STATE(Structure):
    MdsNodeId: UInt32
    DsNodeId: UInt32
    IsDiskConnected: win32more.Windows.Win32.Foundation.BOOLEAN
    ClusterEnableDirectIo: win32more.Windows.Win32.Foundation.BOOLEAN
    DiskConnectivity: win32more.Windows.Win32.System.Ioctl.CSVFS_DISK_CONNECTIVITY
class CSV_SET_VOLUME_ID(Structure):
    VolumeId: Guid
class DECRYPTION_STATUS_BUFFER(Structure):
    NoEncryptedStreams: win32more.Windows.Win32.Foundation.BOOLEAN
class DELETE_USN_JOURNAL_DATA(Structure):
    UsnJournalID: UInt64
    DeleteFlags: win32more.Windows.Win32.System.Ioctl.USN_DELETE_FLAGS
DETECTION_TYPE = Int32
DetectNone: win32more.Windows.Win32.System.Ioctl.DETECTION_TYPE = 0
DetectInt13: win32more.Windows.Win32.System.Ioctl.DETECTION_TYPE = 1
DetectExInt13: win32more.Windows.Win32.System.Ioctl.DETECTION_TYPE = 2
DEVICEDUMP_COLLECTION_TYPEIDE_NOTIFICATION_TYPE = Int32
TCCollectionBugCheck: win32more.Windows.Win32.System.Ioctl.DEVICEDUMP_COLLECTION_TYPEIDE_NOTIFICATION_TYPE = 1
TCCollectionApplicationRequested: win32more.Windows.Win32.System.Ioctl.DEVICEDUMP_COLLECTION_TYPEIDE_NOTIFICATION_TYPE = 2
TCCollectionDeviceRequested: win32more.Windows.Win32.System.Ioctl.DEVICEDUMP_COLLECTION_TYPEIDE_NOTIFICATION_TYPE = 3
class DEVICEDUMP_PRIVATE_SUBSECTION(Structure):
    dwFlags: UInt32
    GPLogId: win32more.Windows.Win32.System.Ioctl.GP_LOG_PAGE_DESCRIPTOR
    bData: Byte * 1
    _pack_ = 1
class DEVICEDUMP_PUBLIC_SUBSECTION(Structure):
    dwFlags: UInt32
    GPLogTable: win32more.Windows.Win32.System.Ioctl.GP_LOG_PAGE_DESCRIPTOR * 16
    szDescription: win32more.Windows.Win32.Foundation.CHAR * 16
    bData: Byte * 1
    _pack_ = 1
class DEVICEDUMP_RESTRICTED_SUBSECTION(Structure):
    bData: Byte * 1
class DEVICEDUMP_SECTION_HEADER(Structure):
    guidDeviceDataId: Guid
    sOrganizationID: Byte * 16
    dwFirmwareRevision: UInt32
    sModelNumber: Byte * 32
    szDeviceManufacturingID: Byte * 32
    dwFlags: UInt32
    bRestrictedPrivateDataVersion: UInt32
    dwFirmwareIssueId: UInt32
    szIssueDescriptionString: Byte * 132
    _pack_ = 1
class DEVICEDUMP_STORAGEDEVICE_DATA(Structure):
    Descriptor: win32more.Windows.Win32.System.Ioctl.DEVICEDUMP_STRUCTURE_VERSION
    SectionHeader: win32more.Windows.Win32.System.Ioctl.DEVICEDUMP_SECTION_HEADER
    dwBufferSize: UInt32
    dwReasonForCollection: UInt32
    PublicData: win32more.Windows.Win32.System.Ioctl.DEVICEDUMP_SUBSECTION_POINTER
    RestrictedData: win32more.Windows.Win32.System.Ioctl.DEVICEDUMP_SUBSECTION_POINTER
    PrivateData: win32more.Windows.Win32.System.Ioctl.DEVICEDUMP_SUBSECTION_POINTER
    _pack_ = 1
class DEVICEDUMP_STORAGESTACK_PUBLIC_DUMP(Structure):
    Descriptor: win32more.Windows.Win32.System.Ioctl.DEVICEDUMP_STRUCTURE_VERSION
    dwReasonForCollection: UInt32
    cDriverName: Byte * 16
    uiNumRecords: UInt32
    RecordArray: win32more.Windows.Win32.System.Ioctl.DEVICEDUMP_STORAGESTACK_PUBLIC_STATE_RECORD * 1
    _pack_ = 1
class DEVICEDUMP_STORAGESTACK_PUBLIC_STATE_RECORD(Structure):
    Cdb: Byte * 16
    Command: Byte * 16
    StartTime: UInt64
    EndTime: UInt64
    OperationStatus: UInt32
    OperationError: UInt32
    StackSpecific: _StackSpecific_e__Union
    _pack_ = 1
    class _StackSpecific_e__Union(Union):
        ExternalStack: _ExternalStack_e__Struct
        AtaPort: _AtaPort_e__Struct
        StorPort: _StorPort_e__Struct
        class _ExternalStack_e__Struct(Structure):
            dwReserved: UInt32
            _pack_ = 1
        class _AtaPort_e__Struct(Structure):
            dwAtaPortSpecific: UInt32
            _pack_ = 1
        class _StorPort_e__Struct(Structure):
            SrbTag: UInt32
            _pack_ = 1
class DEVICEDUMP_STRUCTURE_VERSION(Structure):
    dwSignature: UInt32
    dwVersion: UInt32
    dwSize: UInt32
    _pack_ = 1
class DEVICEDUMP_SUBSECTION_POINTER(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    dwOffset: UInt32
    _pack_ = 1
class DEVICE_COPY_OFFLOAD_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    MaximumTokenLifetime: UInt32
    DefaultTokenLifetime: UInt32
    MaximumTransferSize: UInt64
    OptimalTransferCount: UInt64
    MaximumDataDescriptors: UInt32
    MaximumTransferLengthPerDescriptor: UInt32
    OptimalTransferLengthPerDescriptor: UInt32
    OptimalTransferLengthGranularity: UInt16
    Reserved: Byte * 2
class DEVICE_DATA_SET_LBP_STATE_PARAMETERS(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    OutputVersion: UInt32
class DEVICE_DATA_SET_LB_PROVISIONING_STATE(Structure):
    Size: UInt32
    Version: UInt32
    SlabSizeInBytes: UInt64
    SlabOffsetDeltaInBytes: UInt32
    SlabAllocationBitMapBitCount: UInt32
    SlabAllocationBitMapLength: UInt32
    SlabAllocationBitMap: UInt32 * 1
class DEVICE_DATA_SET_LB_PROVISIONING_STATE_V2(Structure):
    Size: UInt32
    Version: UInt32
    SlabSizeInBytes: UInt64
    SlabOffsetDeltaInBytes: UInt64
    SlabAllocationBitMapBitCount: UInt32
    SlabAllocationBitMapLength: UInt32
    SlabAllocationBitMap: UInt32 * 1
class DEVICE_DATA_SET_RANGE(Structure):
    StartingOffset: Int64
    LengthInBytes: UInt64
class DEVICE_DATA_SET_REPAIR_OUTPUT(Structure):
    ParityExtent: win32more.Windows.Win32.System.Ioctl.DEVICE_DATA_SET_RANGE
class DEVICE_DATA_SET_REPAIR_PARAMETERS(Structure):
    NumberOfRepairCopies: UInt32
    SourceCopy: UInt32
    RepairCopies: UInt32 * 1
class DEVICE_DATA_SET_SCRUB_EX_OUTPUT(Structure):
    BytesProcessed: UInt64
    BytesRepaired: UInt64
    BytesFailed: UInt64
    ParityExtent: win32more.Windows.Win32.System.Ioctl.DEVICE_DATA_SET_RANGE
    BytesScrubbed: UInt64
class DEVICE_DATA_SET_SCRUB_OUTPUT(Structure):
    BytesProcessed: UInt64
    BytesRepaired: UInt64
    BytesFailed: UInt64
class DEVICE_DATA_SET_TOPOLOGY_ID_QUERY_OUTPUT(Structure):
    TopologyRangeBytes: UInt64
    TopologyId: Byte * 16
class DEVICE_DSM_CONVERSION_OUTPUT(Structure):
    Version: UInt32
    Source: Guid
class DEVICE_DSM_DEFINITION(Structure):
    Action: UInt32
    SingleRange: win32more.Windows.Win32.Foundation.BOOLEAN
    ParameterBlockAlignment: UInt32
    ParameterBlockLength: UInt32
    HasOutput: win32more.Windows.Win32.Foundation.BOOLEAN
    OutputBlockAlignment: UInt32
    OutputBlockLength: UInt32
class DEVICE_DSM_FREE_SPACE_OUTPUT(Structure):
    Version: UInt32
    FreeSpace: UInt64
class DEVICE_DSM_LOST_QUERY_OUTPUT(Structure):
    Version: UInt32
    Size: UInt32
    Alignment: UInt64
    NumberOfBits: UInt32
    BitMap: UInt32 * 1
class DEVICE_DSM_LOST_QUERY_PARAMETERS(Structure):
    Version: UInt32
    Granularity: UInt64
class DEVICE_DSM_NOTIFICATION_PARAMETERS(Structure):
    Size: UInt32
    Flags: UInt32
    NumFileTypeIDs: UInt32
    FileTypeID: Guid * 1
class DEVICE_DSM_NVCACHE_CHANGE_PRIORITY_PARAMETERS(Structure):
    Size: UInt32
    TargetPriority: Byte
    Reserved: Byte * 3
class DEVICE_DSM_OFFLOAD_READ_PARAMETERS(Structure):
    Flags: UInt32
    TimeToLive: UInt32
    Reserved: UInt32 * 2
class DEVICE_DSM_OFFLOAD_WRITE_PARAMETERS(Structure):
    Flags: UInt32
    Reserved: UInt32
    TokenOffset: UInt64
    Token: win32more.Windows.Win32.System.Ioctl.STORAGE_OFFLOAD_TOKEN
class DEVICE_DSM_PHYSICAL_ADDRESSES_OUTPUT(Structure):
    Version: UInt32
    Flags: UInt32
    TotalNumberOfRanges: UInt32
    NumberOfRangesReturned: UInt32
    Ranges: win32more.Windows.Win32.System.Ioctl.DEVICE_STORAGE_ADDRESS_RANGE * 1
class DEVICE_DSM_RANGE_ERROR_INFO(Structure):
    Version: UInt32
    Flags: UInt32
    TotalNumberOfRanges: UInt32
    NumberOfRangesReturned: UInt32
    Ranges: win32more.Windows.Win32.System.Ioctl.DEVICE_STORAGE_RANGE_ATTRIBUTES * 1
class DEVICE_DSM_REPORT_ZONES_DATA(Structure):
    Size: UInt32
    ZoneCount: UInt32
    Attributes: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONES_ATTRIBUTES
    Reserved0: UInt32
    ZoneDescriptors: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_DESCRIPTOR * 1
class DEVICE_DSM_REPORT_ZONES_PARAMETERS(Structure):
    Size: UInt32
    ReportOption: Byte
    Partial: Byte
    Reserved: Byte * 2
class DEVICE_DSM_TIERING_QUERY_INPUT(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    NumberOfTierIds: UInt32
    TierIds: Guid * 1
class DEVICE_DSM_TIERING_QUERY_OUTPUT(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    Reserved: UInt32
    Alignment: UInt64
    TotalNumberOfRegions: UInt32
    NumberOfRegionsReturned: UInt32
    Regions: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER_REGION * 1
class DEVICE_INTERNAL_STATUS_DATA(Structure):
    Version: UInt32
    Size: UInt32
    T10VendorId: UInt64
    DataSet1Length: UInt32
    DataSet2Length: UInt32
    DataSet3Length: UInt32
    DataSet4Length: UInt32
    StatusDataVersion: Byte
    Reserved: Byte * 3
    ReasonIdentifier: Byte * 128
    StatusDataLength: UInt32
    StatusData: Byte * 1
DEVICE_INTERNAL_STATUS_DATA_REQUEST_TYPE = Int32
DeviceInternalStatusDataRequestTypeUndefined: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_REQUEST_TYPE = 0
DeviceCurrentInternalStatusDataHeader: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_REQUEST_TYPE = 1
DeviceCurrentInternalStatusData: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_REQUEST_TYPE = 2
DeviceSavedInternalStatusDataHeader: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_REQUEST_TYPE = 3
DeviceSavedInternalStatusData: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_REQUEST_TYPE = 4
DEVICE_INTERNAL_STATUS_DATA_SET = Int32
DeviceStatusDataSetUndefined: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_SET = 0
DeviceStatusDataSet1: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_SET = 1
DeviceStatusDataSet2: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_SET = 2
DeviceStatusDataSet3: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_SET = 3
DeviceStatusDataSet4: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_SET = 4
DeviceStatusDataSetMax: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_SET = 5
class DEVICE_LB_PROVISIONING_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    ThinProvisioningEnabled: Annotated[Byte, 1]
    ThinProvisioningReadZeros: Annotated[Byte, 1]
    AnchorSupported: Annotated[Byte, 3]
    UnmapGranularityAlignmentValid: Annotated[Byte, 1]
    GetFreeSpaceSupported: Annotated[Byte, 1]
    MapSupported: Annotated[Byte, 1]
    Reserved1: Byte * 7
    OptimalUnmapGranularity: UInt64
    UnmapGranularityAlignment: UInt64
    MaxUnmapLbaCount: UInt32
    MaxUnmapBlockDescriptorCount: UInt32
class DEVICE_LOCATION(Structure):
    Socket: UInt32
    Slot: UInt32
    Adapter: UInt32
    Port: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Anonymous1: _Anonymous1_e__Struct
        Anonymous2: _Anonymous2_e__Struct
        class _Anonymous1_e__Struct(Structure):
            Channel: UInt32
            Device: UInt32
        class _Anonymous2_e__Struct(Structure):
            Target: UInt32
            Lun: UInt32
class DEVICE_MANAGE_DATA_SET_ATTRIBUTES(Structure):
    Size: UInt32
    Action: UInt32
    Flags: UInt32
    ParameterBlockOffset: UInt32
    ParameterBlockLength: UInt32
    DataSetRangesOffset: UInt32
    DataSetRangesLength: UInt32
class DEVICE_MANAGE_DATA_SET_ATTRIBUTES_OUTPUT(Structure):
    Size: UInt32
    Action: UInt32
    Flags: UInt32
    OperationStatus: UInt32
    ExtendedError: UInt32
    TargetDetailedError: UInt32
    ReservedStatus: UInt32
    OutputBlockOffset: UInt32
    OutputBlockLength: UInt32
class DEVICE_MEDIA_INFO(Structure):
    DeviceSpecific: _DeviceSpecific_e__Union
    class _DeviceSpecific_e__Union(Union):
        DiskInfo: _DiskInfo_e__Struct
        RemovableDiskInfo: _RemovableDiskInfo_e__Struct
        TapeInfo: _TapeInfo_e__Struct
        class _DiskInfo_e__Struct(Structure):
            Cylinders: Int64
            MediaType: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE
            TracksPerCylinder: UInt32
            SectorsPerTrack: UInt32
            BytesPerSector: UInt32
            NumberMediaSides: UInt32
            MediaCharacteristics: UInt32
        class _RemovableDiskInfo_e__Struct(Structure):
            Cylinders: Int64
            MediaType: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE
            TracksPerCylinder: UInt32
            SectorsPerTrack: UInt32
            BytesPerSector: UInt32
            NumberMediaSides: UInt32
            MediaCharacteristics: UInt32
        class _TapeInfo_e__Struct(Structure):
            MediaType: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE
            MediaCharacteristics: UInt32
            CurrentBlockSize: UInt32
            BusType: win32more.Windows.Win32.Storage.FileSystem.STORAGE_BUS_TYPE
            BusSpecificData: _BusSpecificData_e__Union
            class _BusSpecificData_e__Union(Union):
                ScsiInformation: _ScsiInformation_e__Struct
                class _ScsiInformation_e__Struct(Structure):
                    MediumType: Byte
                    DensityCode: Byte
class DEVICE_POWER_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    DeviceAttentionSupported: win32more.Windows.Win32.Foundation.BOOLEAN
    AsynchronousNotificationSupported: win32more.Windows.Win32.Foundation.BOOLEAN
    IdlePowerManagementEnabled: win32more.Windows.Win32.Foundation.BOOLEAN
    D3ColdEnabled: win32more.Windows.Win32.Foundation.BOOLEAN
    D3ColdSupported: win32more.Windows.Win32.Foundation.BOOLEAN
    NoVerifyDuringIdlePower: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved: Byte * 2
    IdleTimeoutInMS: UInt32
class DEVICE_SEEK_PENALTY_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    IncursSeekPenalty: win32more.Windows.Win32.Foundation.BOOLEAN
class DEVICE_STORAGE_ADDRESS_RANGE(Structure):
    StartAddress: Int64
    LengthInBytes: UInt64
class DEVICE_STORAGE_RANGE_ATTRIBUTES(Structure):
    LengthInBytes: UInt64
    Anonymous: _Anonymous_e__Union
    Reserved: UInt32
    class _Anonymous_e__Union(Union):
        AllFlags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            IsRangeBad: Annotated[UInt32, 1]
class DEVICE_TRIM_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    TrimEnabled: win32more.Windows.Win32.Foundation.BOOLEAN
class DEVICE_WRITE_AGGREGATION_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    BenefitsFromWriteAggregation: win32more.Windows.Win32.Foundation.BOOLEAN
class DISK_CACHE_INFORMATION(Structure):
    ParametersSavable: win32more.Windows.Win32.Foundation.BOOLEAN
    ReadCacheEnabled: win32more.Windows.Win32.Foundation.BOOLEAN
    WriteCacheEnabled: win32more.Windows.Win32.Foundation.BOOLEAN
    ReadRetentionPriority: win32more.Windows.Win32.System.Ioctl.DISK_CACHE_RETENTION_PRIORITY
    WriteRetentionPriority: win32more.Windows.Win32.System.Ioctl.DISK_CACHE_RETENTION_PRIORITY
    DisablePrefetchTransferLength: UInt16
    PrefetchScalar: win32more.Windows.Win32.Foundation.BOOLEAN
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        ScalarPrefetch: _ScalarPrefetch_e__Struct
        BlockPrefetch: _BlockPrefetch_e__Struct
        class _ScalarPrefetch_e__Struct(Structure):
            Minimum: UInt16
            Maximum: UInt16
            MaximumBlocks: UInt16
        class _BlockPrefetch_e__Struct(Structure):
            Minimum: UInt16
            Maximum: UInt16
DISK_CACHE_RETENTION_PRIORITY = Int32
EqualPriority: win32more.Windows.Win32.System.Ioctl.DISK_CACHE_RETENTION_PRIORITY = 0
KeepPrefetchedData: win32more.Windows.Win32.System.Ioctl.DISK_CACHE_RETENTION_PRIORITY = 1
KeepReadData: win32more.Windows.Win32.System.Ioctl.DISK_CACHE_RETENTION_PRIORITY = 2
class DISK_CONTROLLER_NUMBER(Structure):
    ControllerNumber: UInt32
    DiskNumber: UInt32
class DISK_DETECTION_INFO(Structure):
    SizeOfDetectInfo: UInt32
    DetectionType: win32more.Windows.Win32.System.Ioctl.DETECTION_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            Int13: win32more.Windows.Win32.System.Ioctl.DISK_INT13_INFO
            ExInt13: win32more.Windows.Win32.System.Ioctl.DISK_EX_INT13_INFO
class DISK_EXTENT(Structure):
    DiskNumber: UInt32
    StartingOffset: Int64
    ExtentLength: Int64
class DISK_EX_INT13_INFO(Structure):
    ExBufferSize: UInt16
    ExFlags: UInt16
    ExCylinders: UInt32
    ExHeads: UInt32
    ExSectorsPerTrack: UInt32
    ExSectorsPerDrive: UInt64
    ExSectorSize: UInt16
    ExReserved: UInt16
class DISK_GEOMETRY(Structure):
    Cylinders: Int64
    MediaType: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE
    TracksPerCylinder: UInt32
    SectorsPerTrack: UInt32
    BytesPerSector: UInt32
class DISK_GEOMETRY_EX(Structure):
    Geometry: win32more.Windows.Win32.System.Ioctl.DISK_GEOMETRY
    DiskSize: Int64
    Data: Byte * 1
class DISK_GROW_PARTITION(Structure):
    PartitionNumber: UInt32
    BytesToGrow: Int64
class DISK_HISTOGRAM(Structure):
    DiskSize: Int64
    Start: Int64
    End: Int64
    Average: Int64
    AverageRead: Int64
    AverageWrite: Int64
    Granularity: UInt32
    Size: UInt32
    ReadCount: UInt32
    WriteCount: UInt32
    Histogram: POINTER(win32more.Windows.Win32.System.Ioctl.HISTOGRAM_BUCKET)
class DISK_INT13_INFO(Structure):
    DriveSelect: UInt16
    MaxCylinders: UInt32
    SectorsPerTrack: UInt16
    MaxHeads: UInt16
    NumberDrives: UInt16
class DISK_LOGGING(Structure):
    Function: Byte
    BufferAddress: VoidPtr
    BufferSize: UInt32
class DISK_PARTITION_INFO(Structure):
    SizeOfPartitionInfo: UInt32
    PartitionStyle: win32more.Windows.Win32.System.Ioctl.PARTITION_STYLE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Mbr: _Mbr_e__Struct
        Gpt: _Gpt_e__Struct
        class _Mbr_e__Struct(Structure):
            Signature: UInt32
            CheckSum: UInt32
        class _Gpt_e__Struct(Structure):
            DiskId: Guid
class DISK_PERFORMANCE(Structure):
    BytesRead: Int64
    BytesWritten: Int64
    ReadTime: Int64
    WriteTime: Int64
    IdleTime: Int64
    ReadCount: UInt32
    WriteCount: UInt32
    QueueDepth: UInt32
    SplitCount: UInt32
    QueryTime: Int64
    StorageDeviceNumber: UInt32
    StorageManagerName: Char * 8
class DISK_RECORD(Structure):
    ByteOffset: Int64
    StartTime: Int64
    EndTime: Int64
    VirtualAddress: VoidPtr
    NumberOfBytes: UInt32
    DeviceNumber: Byte
    ReadRequest: win32more.Windows.Win32.Foundation.BOOLEAN
class DRIVERSTATUS(Structure):
    bDriverError: Byte
    bIDEError: Byte
    bReserved: Byte * 2
    dwReserved: UInt32 * 2
    _pack_ = 1
class DRIVE_LAYOUT_INFORMATION(Structure):
    PartitionCount: UInt32
    Signature: UInt32
    PartitionEntry: win32more.Windows.Win32.System.Ioctl.PARTITION_INFORMATION * 1
class DRIVE_LAYOUT_INFORMATION_EX(Structure):
    PartitionStyle: UInt32
    PartitionCount: UInt32
    Anonymous: _Anonymous_e__Union
    PartitionEntry: win32more.Windows.Win32.System.Ioctl.PARTITION_INFORMATION_EX * 1
    class _Anonymous_e__Union(Union):
        Mbr: win32more.Windows.Win32.System.Ioctl.DRIVE_LAYOUT_INFORMATION_MBR
        Gpt: win32more.Windows.Win32.System.Ioctl.DRIVE_LAYOUT_INFORMATION_GPT
class DRIVE_LAYOUT_INFORMATION_GPT(Structure):
    DiskId: Guid
    StartingUsableOffset: Int64
    UsableLength: Int64
    MaxPartitionCount: UInt32
class DRIVE_LAYOUT_INFORMATION_MBR(Structure):
    Signature: UInt32
    CheckSum: UInt32
class DUPLICATE_EXTENTS_DATA(Structure):
    FileHandle: win32more.Windows.Win32.Foundation.HANDLE
    SourceFileOffset: Int64
    TargetFileOffset: Int64
    ByteCount: Int64
if ARCH in 'X64,ARM64':
    class DUPLICATE_EXTENTS_DATA32(Structure):
        FileHandle: UInt32
        SourceFileOffset: Int64
        TargetFileOffset: Int64
        ByteCount: Int64
class DUPLICATE_EXTENTS_DATA_EX(Structure):
    Size: UIntPtr
    FileHandle: win32more.Windows.Win32.Foundation.HANDLE
    SourceFileOffset: Int64
    TargetFileOffset: Int64
    ByteCount: Int64
    Flags: UInt32
if ARCH in 'X64,ARM64':
    class DUPLICATE_EXTENTS_DATA_EX32(Structure):
        Size: UInt32
        FileHandle: UInt32
        SourceFileOffset: Int64
        TargetFileOffset: Int64
        ByteCount: Int64
        Flags: UInt32
DUPLICATE_EXTENTS_STATE = Int32
FileSnapStateInactive: win32more.Windows.Win32.System.Ioctl.DUPLICATE_EXTENTS_STATE = 0
FileSnapStateSource: win32more.Windows.Win32.System.Ioctl.DUPLICATE_EXTENTS_STATE = 1
FileSnapStateTarget: win32more.Windows.Win32.System.Ioctl.DUPLICATE_EXTENTS_STATE = 2
ELEMENT_TYPE = Int32
AllElements: win32more.Windows.Win32.System.Ioctl.ELEMENT_TYPE = 0
ChangerTransport: win32more.Windows.Win32.System.Ioctl.ELEMENT_TYPE = 1
ChangerSlot: win32more.Windows.Win32.System.Ioctl.ELEMENT_TYPE = 2
ChangerIEPort: win32more.Windows.Win32.System.Ioctl.ELEMENT_TYPE = 3
ChangerDrive: win32more.Windows.Win32.System.Ioctl.ELEMENT_TYPE = 4
ChangerDoor: win32more.Windows.Win32.System.Ioctl.ELEMENT_TYPE = 5
ChangerKeypad: win32more.Windows.Win32.System.Ioctl.ELEMENT_TYPE = 6
ChangerMaxElement: win32more.Windows.Win32.System.Ioctl.ELEMENT_TYPE = 7
class ENCRYPTED_DATA_INFO(Structure):
    StartingFileOffset: UInt64
    OutputBufferOffset: UInt32
    BytesWithinFileSize: UInt32
    BytesWithinValidDataLength: UInt32
    CompressionFormat: UInt16
    DataUnitShift: Byte
    ChunkShift: Byte
    ClusterShift: Byte
    EncryptionFormat: Byte
    NumberOfDataBlocks: UInt16
    DataBlockSize: UInt32 * 1
class ENCRYPTION_BUFFER(Structure):
    EncryptionOperation: UInt32
    Private: Byte * 1
class ENCRYPTION_KEY_CTRL_INPUT(Structure):
    HeaderSize: UInt32
    StructureSize: UInt32
    KeyOffset: UInt16
    KeySize: UInt16
    DplLock: UInt32
    DplUserId: UInt64
    DplCredentialId: UInt64
class EXFAT_STATISTICS(Structure):
    CreateHits: UInt32
    SuccessfulCreates: UInt32
    FailedCreates: UInt32
    NonCachedReads: UInt32
    NonCachedReadBytes: UInt32
    NonCachedWrites: UInt32
    NonCachedWriteBytes: UInt32
    NonCachedDiskReads: UInt32
    NonCachedDiskWrites: UInt32
class EXTENDED_ENCRYPTED_DATA_INFO(Structure):
    ExtendedCode: UInt32
    Length: UInt32
    Flags: UInt32
    Reserved: UInt32
class FAT_STATISTICS(Structure):
    CreateHits: UInt32
    SuccessfulCreates: UInt32
    FailedCreates: UInt32
    NonCachedReads: UInt32
    NonCachedReadBytes: UInt32
    NonCachedWrites: UInt32
    NonCachedWriteBytes: UInt32
    NonCachedDiskReads: UInt32
    NonCachedDiskWrites: UInt32
class FILESYSTEM_STATISTICS(Structure):
    FileSystemType: win32more.Windows.Win32.System.Ioctl.FILESYSTEM_STATISTICS_TYPE
    Version: UInt16
    SizeOfCompleteStructure: UInt32
    UserFileReads: UInt32
    UserFileReadBytes: UInt32
    UserDiskReads: UInt32
    UserFileWrites: UInt32
    UserFileWriteBytes: UInt32
    UserDiskWrites: UInt32
    MetaDataReads: UInt32
    MetaDataReadBytes: UInt32
    MetaDataDiskReads: UInt32
    MetaDataWrites: UInt32
    MetaDataWriteBytes: UInt32
    MetaDataDiskWrites: UInt32
class FILESYSTEM_STATISTICS_EX(Structure):
    FileSystemType: win32more.Windows.Win32.System.Ioctl.FILESYSTEM_STATISTICS_TYPE
    Version: UInt16
    SizeOfCompleteStructure: UInt32
    UserFileReads: UInt64
    UserFileReadBytes: UInt64
    UserDiskReads: UInt64
    UserFileWrites: UInt64
    UserFileWriteBytes: UInt64
    UserDiskWrites: UInt64
    MetaDataReads: UInt64
    MetaDataReadBytes: UInt64
    MetaDataDiskReads: UInt64
    MetaDataWrites: UInt64
    MetaDataWriteBytes: UInt64
    MetaDataDiskWrites: UInt64
FILESYSTEM_STATISTICS_TYPE = UInt16
FILESYSTEM_STATISTICS_TYPE_EXFAT: win32more.Windows.Win32.System.Ioctl.FILESYSTEM_STATISTICS_TYPE = 3
FILESYSTEM_STATISTICS_TYPE_FAT: win32more.Windows.Win32.System.Ioctl.FILESYSTEM_STATISTICS_TYPE = 2
FILESYSTEM_STATISTICS_TYPE_NTFS: win32more.Windows.Win32.System.Ioctl.FILESYSTEM_STATISTICS_TYPE = 1
class FILE_ALLOCATED_RANGE_BUFFER(Structure):
    FileOffset: Int64
    Length: Int64
class FILE_DESIRED_STORAGE_CLASS_INFORMATION(Structure):
    Class: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_CLASS
    Flags: UInt32
class FILE_FS_PERSISTENT_VOLUME_INFORMATION(Structure):
    VolumeFlags: UInt32
    FlagMask: UInt32
    Version: UInt32
    Reserved: UInt32
class FILE_INITIATE_REPAIR_OUTPUT_BUFFER(Structure):
    Hint1: UInt64
    Hint2: UInt64
    Clsn: UInt64
    Status: UInt32
class FILE_LAYOUT_ENTRY(Structure):
    Version: UInt32
    NextFileOffset: UInt32
    Flags: UInt32
    FileAttributes: UInt32
    FileReferenceNumber: UInt64
    FirstNameOffset: UInt32
    FirstStreamOffset: UInt32
    ExtraInfoOffset: UInt32
    ExtraInfoLength: UInt32
class FILE_LAYOUT_INFO_ENTRY(Structure):
    BasicInformation: _BasicInformation_e__Struct
    OwnerId: UInt32
    SecurityId: UInt32
    Usn: Int64
    StorageReserveId: win32more.Windows.Win32.System.Ioctl.STORAGE_RESERVE_ID
    class _BasicInformation_e__Struct(Structure):
        CreationTime: Int64
        LastAccessTime: Int64
        LastWriteTime: Int64
        ChangeTime: Int64
        FileAttributes: UInt32
class FILE_LAYOUT_NAME_ENTRY(Structure):
    NextNameOffset: UInt32
    Flags: UInt32
    ParentFileReferenceNumber: UInt64
    FileNameLength: UInt32
    Reserved: UInt32
    FileName: Char * 1
class FILE_LEVEL_TRIM(Structure):
    Key: UInt32
    NumRanges: UInt32
    Ranges: win32more.Windows.Win32.System.Ioctl.FILE_LEVEL_TRIM_RANGE * 1
class FILE_LEVEL_TRIM_OUTPUT(Structure):
    NumRangesProcessed: UInt32
class FILE_LEVEL_TRIM_RANGE(Structure):
    Offset: UInt64
    Length: UInt64
class FILE_MAKE_COMPATIBLE_BUFFER(Structure):
    CloseDisc: win32more.Windows.Win32.Foundation.BOOLEAN
class FILE_OBJECTID_BUFFER(Structure):
    ObjectId: Byte * 16
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        ExtendedInfo: Byte * 48
        class _Anonymous_e__Struct(Structure):
            BirthVolumeId: Byte * 16
            BirthObjectId: Byte * 16
            DomainId: Byte * 16
class FILE_PREFETCH(Structure):
    Type: UInt32
    Count: UInt32
    Prefetch: UInt64 * 1
class FILE_PREFETCH_EX(Structure):
    Type: UInt32
    Count: UInt32
    Context: VoidPtr
    Prefetch: UInt64 * 1
class FILE_PROVIDER_EXTERNAL_INFO_V0(Structure):
    Version: UInt32
    Algorithm: UInt32
class FILE_PROVIDER_EXTERNAL_INFO_V1(Structure):
    Version: UInt32
    Algorithm: UInt32
    Flags: UInt32
class FILE_QUERY_ON_DISK_VOL_INFO_BUFFER(Structure):
    DirectoryCount: Int64
    FileCount: Int64
    FsFormatMajVersion: UInt16
    FsFormatMinVersion: UInt16
    FsFormatName: Char * 12
    FormatTime: Int64
    LastUpdateTime: Int64
    CopyrightInfo: Char * 34
    AbstractInfo: Char * 34
    FormattingImplementationInfo: Char * 34
    LastModifyingImplementationInfo: Char * 34
class FILE_QUERY_SPARING_BUFFER(Structure):
    SparingUnitBytes: UInt32
    SoftwareSparing: win32more.Windows.Win32.Foundation.BOOLEAN
    TotalSpareBlocks: UInt32
    FreeSpareBlocks: UInt32
class FILE_REFERENCE_RANGE(Structure):
    StartingFileReferenceNumber: UInt64
    EndingFileReferenceNumber: UInt64
class FILE_REGION_INFO(Structure):
    FileOffset: Int64
    Length: Int64
    Usage: UInt32
    Reserved: UInt32
class FILE_REGION_INPUT(Structure):
    FileOffset: Int64
    Length: Int64
    DesiredUsage: UInt32
class FILE_REGION_OUTPUT(Structure):
    Flags: UInt32
    TotalRegionEntryCount: UInt32
    RegionEntryCount: UInt32
    Reserved: UInt32
    Region: win32more.Windows.Win32.System.Ioctl.FILE_REGION_INFO * 1
class FILE_SET_DEFECT_MGMT_BUFFER(Structure):
    Disable: win32more.Windows.Win32.Foundation.BOOLEAN
class FILE_SET_SPARSE_BUFFER(Structure):
    SetSparse: win32more.Windows.Win32.Foundation.BOOLEAN
class FILE_STORAGE_TIER(Structure):
    Id: Guid
    Name: Char * 256
    Description: Char * 256
    Flags: UInt64
    ProvisionedCapacity: UInt64
    MediaType: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_MEDIA_TYPE
    Class: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_CLASS
FILE_STORAGE_TIER_CLASS = Int32
FileStorageTierClassUnspecified: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_CLASS = 0
FileStorageTierClassCapacity: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_CLASS = 1
FileStorageTierClassPerformance: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_CLASS = 2
FileStorageTierClassMax: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_CLASS = 3
FILE_STORAGE_TIER_FLAGS = UInt32
FILE_STORAGE_TIER_FLAG_NO_SEEK_PENALTY: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_FLAGS = 131072
FILE_STORAGE_TIER_MEDIA_TYPE = Int32
FileStorageTierMediaTypeUnspecified: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_MEDIA_TYPE = 0
FileStorageTierMediaTypeDisk: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_MEDIA_TYPE = 1
FileStorageTierMediaTypeSsd: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_MEDIA_TYPE = 2
FileStorageTierMediaTypeScm: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_MEDIA_TYPE = 4
FileStorageTierMediaTypeMax: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_MEDIA_TYPE = 5
class FILE_STORAGE_TIER_REGION(Structure):
    TierId: Guid
    Offset: UInt64
    Length: UInt64
class FILE_SYSTEM_RECOGNITION_INFORMATION(Structure):
    FileSystem: win32more.Windows.Win32.Foundation.CHAR * 9
class FILE_TYPE_NOTIFICATION_INPUT(Structure):
    Flags: UInt32
    NumFileTypeIDs: UInt32
    FileTypeID: Guid * 1
class FILE_ZERO_DATA_INFORMATION(Structure):
    FileOffset: Int64
    BeyondFinalZero: Int64
class FILE_ZERO_DATA_INFORMATION_EX(Structure):
    FileOffset: Int64
    BeyondFinalZero: Int64
    Flags: UInt32
class FIND_BY_SID_DATA(Structure):
    Restart: UInt32
    Sid: win32more.Windows.Win32.Security.SID
class FIND_BY_SID_OUTPUT(Structure):
    NextEntryOffset: UInt32
    FileIndex: UInt32
    FileNameLength: UInt32
    FileName: Char * 1
class FORMAT_EX_PARAMETERS(Structure):
    MediaType: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE
    StartCylinderNumber: UInt32
    EndCylinderNumber: UInt32
    StartHeadNumber: UInt32
    EndHeadNumber: UInt32
    FormatGapLength: UInt16
    SectorsPerTrack: UInt16
    SectorNumber: UInt16 * 1
class FORMAT_PARAMETERS(Structure):
    MediaType: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE
    StartCylinderNumber: UInt32
    EndCylinderNumber: UInt32
    StartHeadNumber: UInt32
    EndHeadNumber: UInt32
class FSCTL_GET_INTEGRITY_INFORMATION_BUFFER(Structure):
    ChecksumAlgorithm: UInt16
    Reserved: UInt16
    Flags: UInt32
    ChecksumChunkSizeInBytes: UInt32
    ClusterSizeInBytes: UInt32
class FSCTL_OFFLOAD_READ_INPUT(Structure):
    Size: UInt32
    Flags: UInt32
    TokenTimeToLive: UInt32
    Reserved: UInt32
    FileOffset: UInt64
    CopyLength: UInt64
class FSCTL_OFFLOAD_READ_OUTPUT(Structure):
    Size: UInt32
    Flags: UInt32
    TransferLength: UInt64
    Token: Byte * 512
class FSCTL_OFFLOAD_WRITE_INPUT(Structure):
    Size: UInt32
    Flags: UInt32
    FileOffset: UInt64
    CopyLength: UInt64
    TransferOffset: UInt64
    Token: Byte * 512
class FSCTL_OFFLOAD_WRITE_OUTPUT(Structure):
    Size: UInt32
    Flags: UInt32
    LengthWritten: UInt64
class FSCTL_QUERY_FAT_BPB_BUFFER(Structure):
    First0x24BytesOfBootSector: Byte * 36
class FSCTL_QUERY_REGION_INFO_INPUT(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    NumberOfTierIds: UInt32
    TierIds: Guid * 1
class FSCTL_QUERY_REGION_INFO_OUTPUT(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    Reserved: UInt32
    Alignment: UInt64
    TotalNumberOfRegions: UInt32
    NumberOfRegionsReturned: UInt32
    Regions: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_REGION * 1
class FSCTL_QUERY_STORAGE_CLASSES_OUTPUT(Structure):
    Version: UInt32
    Size: UInt32
    Flags: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_FLAGS
    TotalNumberOfTiers: UInt32
    NumberOfTiersReturned: UInt32
    Tiers: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER * 1
class FSCTL_SET_INTEGRITY_INFORMATION_BUFFER(Structure):
    ChecksumAlgorithm: UInt16
    Reserved: UInt16
    Flags: UInt32
class FSCTL_SET_INTEGRITY_INFORMATION_BUFFER_EX(Structure):
    EnableIntegrity: Byte
    KeepIntegrityStateUnchanged: Byte
    Reserved: UInt16
    Flags: UInt32
    Version: Byte
    Reserved2: Byte * 7
FS_BPIO_INFLAGS = Int32
FSBPIO_INFL_None: win32more.Windows.Win32.System.Ioctl.FS_BPIO_INFLAGS = 0
FSBPIO_INFL_SKIP_STORAGE_STACK_QUERY: win32more.Windows.Win32.System.Ioctl.FS_BPIO_INFLAGS = 1
class FS_BPIO_INFO(Structure):
    ActiveBypassIoCount: UInt32
    StorageDriverNameLen: UInt16
    StorageDriverName: Char * 32
class FS_BPIO_INPUT(Structure):
    Operation: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OPERATIONS
    InFlags: win32more.Windows.Win32.System.Ioctl.FS_BPIO_INFLAGS
    Reserved1: UInt64
    Reserved2: UInt64
FS_BPIO_OPERATIONS = Int32
FS_BPIO_OP_ENABLE: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OPERATIONS = 1
FS_BPIO_OP_DISABLE: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OPERATIONS = 2
FS_BPIO_OP_QUERY: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OPERATIONS = 3
FS_BPIO_OP_VOLUME_STACK_PAUSE: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OPERATIONS = 4
FS_BPIO_OP_VOLUME_STACK_RESUME: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OPERATIONS = 5
FS_BPIO_OP_STREAM_PAUSE: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OPERATIONS = 6
FS_BPIO_OP_STREAM_RESUME: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OPERATIONS = 7
FS_BPIO_OP_GET_INFO: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OPERATIONS = 8
FS_BPIO_OP_MAX_OPERATION: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OPERATIONS = 9
FS_BPIO_OUTFLAGS = Int32
FSBPIO_OUTFL_None: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OUTFLAGS = 0
FSBPIO_OUTFL_VOLUME_STACK_BYPASS_PAUSED: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OUTFLAGS = 1
FSBPIO_OUTFL_STREAM_BYPASS_PAUSED: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OUTFLAGS = 2
FSBPIO_OUTFL_FILTER_ATTACH_BLOCKED: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OUTFLAGS = 4
FSBPIO_OUTFL_COMPATIBLE_STORAGE_DRIVER: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OUTFLAGS = 8
class FS_BPIO_OUTPUT(Structure):
    Operation: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OPERATIONS
    OutFlags: win32more.Windows.Win32.System.Ioctl.FS_BPIO_OUTFLAGS
    Reserved1: UInt64
    Reserved2: UInt64
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Enable: win32more.Windows.Win32.System.Ioctl.FS_BPIO_RESULTS
        Query: win32more.Windows.Win32.System.Ioctl.FS_BPIO_RESULTS
        VolumeStackResume: win32more.Windows.Win32.System.Ioctl.FS_BPIO_RESULTS
        StreamResume: win32more.Windows.Win32.System.Ioctl.FS_BPIO_RESULTS
        GetInfo: win32more.Windows.Win32.System.Ioctl.FS_BPIO_INFO
class FS_BPIO_RESULTS(Structure):
    OpStatus: UInt32
    FailingDriverNameLen: UInt16
    FailingDriverName: Char * 32
    FailureReasonLen: UInt16
    FailureReason: Char * 128
class GETVERSIONINPARAMS(Structure):
    bVersion: Byte
    bRevision: Byte
    bReserved: Byte
    bIDEDeviceMap: Byte
    fCapabilities: UInt32
    dwReserved: UInt32 * 4
    _pack_ = 1
class GET_CHANGER_PARAMETERS(Structure):
    Size: UInt32
    NumberTransportElements: UInt16
    NumberStorageElements: UInt16
    NumberCleanerSlots: UInt16
    NumberIEElements: UInt16
    NumberDataTransferElements: UInt16
    NumberOfDoors: UInt16
    FirstSlotNumber: UInt16
    FirstDriveNumber: UInt16
    FirstTransportNumber: UInt16
    FirstIEPortNumber: UInt16
    FirstCleanerSlotAddress: UInt16
    MagazineSize: UInt16
    DriveCleanTimeout: UInt32
    Features0: win32more.Windows.Win32.System.Ioctl.CHANGER_FEATURES
    Features1: win32more.Windows.Win32.System.Ioctl.GET_CHANGER_PARAMETERS_FEATURES1
    MoveFromTransport: Byte
    MoveFromSlot: Byte
    MoveFromIePort: Byte
    MoveFromDrive: Byte
    ExchangeFromTransport: Byte
    ExchangeFromSlot: Byte
    ExchangeFromIePort: Byte
    ExchangeFromDrive: Byte
    LockUnlockCapabilities: Byte
    PositionCapabilities: Byte
    Reserved1: Byte * 2
    Reserved2: UInt32 * 2
GET_CHANGER_PARAMETERS_FEATURES1 = UInt32
CHANGER_CLEANER_AUTODISMOUNT: win32more.Windows.Win32.System.Ioctl.GET_CHANGER_PARAMETERS_FEATURES1 = 2147483652
CHANGER_CLEANER_OPS_NOT_SUPPORTED: win32more.Windows.Win32.System.Ioctl.GET_CHANGER_PARAMETERS_FEATURES1 = 2147483712
CHANGER_IEPORT_USER_CONTROL_CLOSE: win32more.Windows.Win32.System.Ioctl.GET_CHANGER_PARAMETERS_FEATURES1 = 2147483904
CHANGER_IEPORT_USER_CONTROL_OPEN: win32more.Windows.Win32.System.Ioctl.GET_CHANGER_PARAMETERS_FEATURES1 = 2147483776
CHANGER_MOVE_EXTENDS_IEPORT: win32more.Windows.Win32.System.Ioctl.GET_CHANGER_PARAMETERS_FEATURES1 = 2147484160
CHANGER_MOVE_RETRACTS_IEPORT: win32more.Windows.Win32.System.Ioctl.GET_CHANGER_PARAMETERS_FEATURES1 = 2147484672
CHANGER_PREDISMOUNT_ALIGN_TO_DRIVE: win32more.Windows.Win32.System.Ioctl.GET_CHANGER_PARAMETERS_FEATURES1 = 2147483650
CHANGER_PREDISMOUNT_ALIGN_TO_SLOT: win32more.Windows.Win32.System.Ioctl.GET_CHANGER_PARAMETERS_FEATURES1 = 2147483649
CHANGER_RTN_MEDIA_TO_ORIGINAL_ADDR: win32more.Windows.Win32.System.Ioctl.GET_CHANGER_PARAMETERS_FEATURES1 = 2147483680
CHANGER_SLOTS_USE_TRAYS: win32more.Windows.Win32.System.Ioctl.GET_CHANGER_PARAMETERS_FEATURES1 = 2147483664
CHANGER_TRUE_EXCHANGE_CAPABLE: win32more.Windows.Win32.System.Ioctl.GET_CHANGER_PARAMETERS_FEATURES1 = 2147483656
class GET_DEVICE_INTERNAL_STATUS_DATA_REQUEST(Structure):
    Version: UInt32
    Size: UInt32
    RequestDataType: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_REQUEST_TYPE
    RequestDataSet: win32more.Windows.Win32.System.Ioctl.DEVICE_INTERNAL_STATUS_DATA_SET
class GET_DISK_ATTRIBUTES(Structure):
    Version: UInt32
    Reserved1: UInt32
    Attributes: UInt64
class GET_FILTER_FILE_IDENTIFIER_INPUT(Structure):
    AltitudeLength: UInt16
    Altitude: Char * 1
class GET_FILTER_FILE_IDENTIFIER_OUTPUT(Structure):
    FilterFileIdentifierLength: UInt16
    FilterFileIdentifier: Byte * 1
class GET_LENGTH_INFORMATION(Structure):
    Length: Int64
class GET_MEDIA_TYPES(Structure):
    DeviceType: UInt32
    MediaInfoCount: UInt32
    MediaInfo: win32more.Windows.Win32.System.Ioctl.DEVICE_MEDIA_INFO * 1
GPT_ATTRIBUTES = UInt64
GPT_ATTRIBUTE_PLATFORM_REQUIRED: win32more.Windows.Win32.System.Ioctl.GPT_ATTRIBUTES = 1
GPT_BASIC_DATA_ATTRIBUTE_NO_DRIVE_LETTER: win32more.Windows.Win32.System.Ioctl.GPT_ATTRIBUTES = 9223372036854775808
GPT_BASIC_DATA_ATTRIBUTE_HIDDEN: win32more.Windows.Win32.System.Ioctl.GPT_ATTRIBUTES = 4611686018427387904
GPT_BASIC_DATA_ATTRIBUTE_SHADOW_COPY: win32more.Windows.Win32.System.Ioctl.GPT_ATTRIBUTES = 2305843009213693952
GPT_BASIC_DATA_ATTRIBUTE_READ_ONLY: win32more.Windows.Win32.System.Ioctl.GPT_ATTRIBUTES = 1152921504606846976
class GP_LOG_PAGE_DESCRIPTOR(Structure):
    LogAddress: UInt16
    LogSectors: UInt16
    _pack_ = 1
class HISTOGRAM_BUCKET(Structure):
    Reads: UInt32
    Writes: UInt32
class IDEREGS(Structure):
    bFeaturesReg: Byte
    bSectorCountReg: Byte
    bSectorNumberReg: Byte
    bCylLowReg: Byte
    bCylHighReg: Byte
    bDriveHeadReg: Byte
    bCommandReg: Byte
    bReserved: Byte
class IO_IRP_EXT_TRACK_OFFSET_HEADER(Structure):
    Validation: UInt16
    Flags: UInt16
    TrackedOffsetCallback: win32more.Windows.Win32.System.Ioctl.PIO_IRP_EXT_PROCESS_TRACKED_OFFSET_CALLBACK
LMR_QUERY_INFO_CLASS = Int32
LMRQuerySessionInfo: win32more.Windows.Win32.System.Ioctl.LMR_QUERY_INFO_CLASS = 1
class LMR_QUERY_INFO_PARAM(Structure):
    Operation: win32more.Windows.Win32.System.Ioctl.LMR_QUERY_INFO_CLASS
class LMR_QUERY_SESSION_INFO(Structure):
    SessionId: UInt64
class LOOKUP_STREAM_FROM_CLUSTER_ENTRY(Structure):
    OffsetToNext: UInt32
    Flags: UInt32
    Reserved: Int64
    Cluster: Int64
    FileName: Char * 1
class LOOKUP_STREAM_FROM_CLUSTER_INPUT(Structure):
    Flags: UInt32
    NumberOfClusters: UInt32
    Cluster: Int64 * 1
class LOOKUP_STREAM_FROM_CLUSTER_OUTPUT(Structure):
    Offset: UInt32
    NumberOfMatches: UInt32
    BufferSizeRequired: UInt32
class MARK_HANDLE_INFO(Structure):
    Anonymous: _Anonymous_e__Union
    VolumeHandle: win32more.Windows.Win32.Foundation.HANDLE
    HandleInfo: UInt32
    class _Anonymous_e__Union(Union):
        UsnSourceInfo: UInt32
        CopyNumber: UInt32
if ARCH in 'X64,ARM64':
    class MARK_HANDLE_INFO32(Structure):
        Anonymous: _Anonymous_e__Union
        VolumeHandle: UInt32
        HandleInfo: UInt32
        class _Anonymous_e__Union(Union):
            UsnSourceInfo: UInt32
            CopyNumber: UInt32
MEDIA_TYPE = Int32
Unknown: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 0
F5_1Pt2_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 1
F3_1Pt44_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 2
F3_2Pt88_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 3
F3_20Pt8_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 4
F3_720_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 5
F5_360_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 6
F5_320_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 7
F5_320_1024: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 8
F5_180_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 9
F5_160_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 10
RemovableMedia: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 11
FixedMedia: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 12
F3_120M_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 13
F3_640_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 14
F5_640_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 15
F5_720_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 16
F3_1Pt2_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 17
F3_1Pt23_1024: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 18
F5_1Pt23_1024: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 19
F3_128Mb_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 20
F3_230Mb_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 21
F8_256_128: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 22
F3_200Mb_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 23
F3_240M_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 24
F3_32M_512: win32more.Windows.Win32.System.Ioctl.MEDIA_TYPE = 25
class MFT_ENUM_DATA_V0(Structure):
    StartFileReferenceNumber: UInt64
    LowUsn: Int64
    HighUsn: Int64
class MFT_ENUM_DATA_V1(Structure):
    StartFileReferenceNumber: UInt64
    LowUsn: Int64
    HighUsn: Int64
    MinMajorVersion: UInt16
    MaxMajorVersion: UInt16
class MOVE_FILE_DATA(Structure):
    FileHandle: win32more.Windows.Win32.Foundation.HANDLE
    StartingVcn: Int64
    StartingLcn: Int64
    ClusterCount: UInt32
if ARCH in 'X64,ARM64':
    class MOVE_FILE_DATA32(Structure):
        FileHandle: UInt32
        StartingVcn: Int64
        StartingLcn: Int64
        ClusterCount: UInt32
class MOVE_FILE_RECORD_DATA(Structure):
    FileHandle: win32more.Windows.Win32.Foundation.HANDLE
    SourceFileRecord: Int64
    TargetFileRecord: Int64
class NTFS_EXTENDED_VOLUME_DATA(Structure):
    ByteCount: UInt32
    MajorVersion: UInt16
    MinorVersion: UInt16
    BytesPerPhysicalSector: UInt32
    LfsMajorVersion: UInt16
    LfsMinorVersion: UInt16
    MaxDeviceTrimExtentCount: UInt32
    MaxDeviceTrimByteCount: UInt32
    MaxVolumeTrimExtentCount: UInt32
    MaxVolumeTrimByteCount: UInt32
class NTFS_FILE_RECORD_INPUT_BUFFER(Structure):
    FileReferenceNumber: Int64
class NTFS_FILE_RECORD_OUTPUT_BUFFER(Structure):
    FileReferenceNumber: Int64
    FileRecordLength: UInt32
    FileRecordBuffer: Byte * 1
class NTFS_STATISTICS(Structure):
    LogFileFullExceptions: UInt32
    OtherExceptions: UInt32
    MftReads: UInt32
    MftReadBytes: UInt32
    MftWrites: UInt32
    MftWriteBytes: UInt32
    MftWritesUserLevel: _MftWritesUserLevel_e__Struct
    MftWritesFlushForLogFileFull: UInt16
    MftWritesLazyWriter: UInt16
    MftWritesUserRequest: UInt16
    Mft2Writes: UInt32
    Mft2WriteBytes: UInt32
    Mft2WritesUserLevel: _Mft2WritesUserLevel_e__Struct
    Mft2WritesFlushForLogFileFull: UInt16
    Mft2WritesLazyWriter: UInt16
    Mft2WritesUserRequest: UInt16
    RootIndexReads: UInt32
    RootIndexReadBytes: UInt32
    RootIndexWrites: UInt32
    RootIndexWriteBytes: UInt32
    BitmapReads: UInt32
    BitmapReadBytes: UInt32
    BitmapWrites: UInt32
    BitmapWriteBytes: UInt32
    BitmapWritesFlushForLogFileFull: UInt16
    BitmapWritesLazyWriter: UInt16
    BitmapWritesUserRequest: UInt16
    BitmapWritesUserLevel: _BitmapWritesUserLevel_e__Struct
    MftBitmapReads: UInt32
    MftBitmapReadBytes: UInt32
    MftBitmapWrites: UInt32
    MftBitmapWriteBytes: UInt32
    MftBitmapWritesFlushForLogFileFull: UInt16
    MftBitmapWritesLazyWriter: UInt16
    MftBitmapWritesUserRequest: UInt16
    MftBitmapWritesUserLevel: _MftBitmapWritesUserLevel_e__Struct
    UserIndexReads: UInt32
    UserIndexReadBytes: UInt32
    UserIndexWrites: UInt32
    UserIndexWriteBytes: UInt32
    LogFileReads: UInt32
    LogFileReadBytes: UInt32
    LogFileWrites: UInt32
    LogFileWriteBytes: UInt32
    Allocate: _Allocate_e__Struct
    DiskResourcesExhausted: UInt32
    class _MftWritesUserLevel_e__Struct(Structure):
        Write: UInt16
        Create: UInt16
        SetInfo: UInt16
        Flush: UInt16
    class _Mft2WritesUserLevel_e__Struct(Structure):
        Write: UInt16
        Create: UInt16
        SetInfo: UInt16
        Flush: UInt16
    class _BitmapWritesUserLevel_e__Struct(Structure):
        Write: UInt16
        Create: UInt16
        SetInfo: UInt16
    class _MftBitmapWritesUserLevel_e__Struct(Structure):
        Write: UInt16
        Create: UInt16
        SetInfo: UInt16
        Flush: UInt16
    class _Allocate_e__Struct(Structure):
        Calls: UInt32
        Clusters: UInt32
        Hints: UInt32
        RunsReturned: UInt32
        HintsHonored: UInt32
        HintsClusters: UInt32
        Cache: UInt32
        CacheClusters: UInt32
        CacheMiss: UInt32
        CacheMissClusters: UInt32
class NTFS_STATISTICS_EX(Structure):
    LogFileFullExceptions: UInt32
    OtherExceptions: UInt32
    MftReads: UInt64
    MftReadBytes: UInt64
    MftWrites: UInt64
    MftWriteBytes: UInt64
    MftWritesUserLevel: _MftWritesUserLevel_e__Struct
    MftWritesFlushForLogFileFull: UInt32
    MftWritesLazyWriter: UInt32
    MftWritesUserRequest: UInt32
    Mft2Writes: UInt64
    Mft2WriteBytes: UInt64
    Mft2WritesUserLevel: _Mft2WritesUserLevel_e__Struct
    Mft2WritesFlushForLogFileFull: UInt32
    Mft2WritesLazyWriter: UInt32
    Mft2WritesUserRequest: UInt32
    RootIndexReads: UInt64
    RootIndexReadBytes: UInt64
    RootIndexWrites: UInt64
    RootIndexWriteBytes: UInt64
    BitmapReads: UInt64
    BitmapReadBytes: UInt64
    BitmapWrites: UInt64
    BitmapWriteBytes: UInt64
    BitmapWritesFlushForLogFileFull: UInt32
    BitmapWritesLazyWriter: UInt32
    BitmapWritesUserRequest: UInt32
    BitmapWritesUserLevel: _BitmapWritesUserLevel_e__Struct
    MftBitmapReads: UInt64
    MftBitmapReadBytes: UInt64
    MftBitmapWrites: UInt64
    MftBitmapWriteBytes: UInt64
    MftBitmapWritesFlushForLogFileFull: UInt32
    MftBitmapWritesLazyWriter: UInt32
    MftBitmapWritesUserRequest: UInt32
    MftBitmapWritesUserLevel: _MftBitmapWritesUserLevel_e__Struct
    UserIndexReads: UInt64
    UserIndexReadBytes: UInt64
    UserIndexWrites: UInt64
    UserIndexWriteBytes: UInt64
    LogFileReads: UInt64
    LogFileReadBytes: UInt64
    LogFileWrites: UInt64
    LogFileWriteBytes: UInt64
    Allocate: _Allocate_e__Struct
    DiskResourcesExhausted: UInt32
    VolumeTrimCount: UInt64
    VolumeTrimTime: UInt64
    VolumeTrimByteCount: UInt64
    FileLevelTrimCount: UInt64
    FileLevelTrimTime: UInt64
    FileLevelTrimByteCount: UInt64
    VolumeTrimSkippedCount: UInt64
    VolumeTrimSkippedByteCount: UInt64
    NtfsFillStatInfoFromMftRecordCalledCount: UInt64
    NtfsFillStatInfoFromMftRecordBailedBecauseOfAttributeListCount: UInt64
    NtfsFillStatInfoFromMftRecordBailedBecauseOfNonResReparsePointCount: UInt64
    class _MftWritesUserLevel_e__Struct(Structure):
        Write: UInt32
        Create: UInt32
        SetInfo: UInt32
        Flush: UInt32
    class _Mft2WritesUserLevel_e__Struct(Structure):
        Write: UInt32
        Create: UInt32
        SetInfo: UInt32
        Flush: UInt32
    class _BitmapWritesUserLevel_e__Struct(Structure):
        Write: UInt32
        Create: UInt32
        SetInfo: UInt32
        Flush: UInt32
    class _MftBitmapWritesUserLevel_e__Struct(Structure):
        Write: UInt32
        Create: UInt32
        SetInfo: UInt32
        Flush: UInt32
    class _Allocate_e__Struct(Structure):
        Calls: UInt32
        RunsReturned: UInt32
        Hints: UInt32
        HintsHonored: UInt32
        Cache: UInt32
        CacheMiss: UInt32
        Clusters: UInt64
        HintsClusters: UInt64
        CacheClusters: UInt64
        CacheMissClusters: UInt64
class NTFS_VOLUME_DATA_BUFFER(Structure):
    VolumeSerialNumber: Int64
    NumberSectors: Int64
    TotalClusters: Int64
    FreeClusters: Int64
    TotalReserved: Int64
    BytesPerSector: UInt32
    BytesPerCluster: UInt32
    BytesPerFileRecordSegment: UInt32
    ClustersPerFileRecordSegment: UInt32
    MftValidDataLength: Int64
    MftStartLcn: Int64
    Mft2StartLcn: Int64
    MftZoneStart: Int64
    MftZoneEnd: Int64
class PARTITION_INFORMATION(Structure):
    StartingOffset: Int64
    PartitionLength: Int64
    HiddenSectors: UInt32
    PartitionNumber: UInt32
    PartitionType: Byte
    BootIndicator: win32more.Windows.Win32.Foundation.BOOLEAN
    RecognizedPartition: win32more.Windows.Win32.Foundation.BOOLEAN
    RewritePartition: win32more.Windows.Win32.Foundation.BOOLEAN
class PARTITION_INFORMATION_EX(Structure):
    PartitionStyle: win32more.Windows.Win32.System.Ioctl.PARTITION_STYLE
    StartingOffset: Int64
    PartitionLength: Int64
    PartitionNumber: UInt32
    RewritePartition: win32more.Windows.Win32.Foundation.BOOLEAN
    IsServicePartition: win32more.Windows.Win32.Foundation.BOOLEAN
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Mbr: win32more.Windows.Win32.System.Ioctl.PARTITION_INFORMATION_MBR
        Gpt: win32more.Windows.Win32.System.Ioctl.PARTITION_INFORMATION_GPT
class PARTITION_INFORMATION_GPT(Structure):
    PartitionType: Guid
    PartitionId: Guid
    Attributes: win32more.Windows.Win32.System.Ioctl.GPT_ATTRIBUTES
    Name: Char * 36
class PARTITION_INFORMATION_MBR(Structure):
    PartitionType: Byte
    BootIndicator: win32more.Windows.Win32.Foundation.BOOLEAN
    RecognizedPartition: win32more.Windows.Win32.Foundation.BOOLEAN
    HiddenSectors: UInt32
    PartitionId: Guid
PARTITION_STYLE = Int32
PARTITION_STYLE_MBR: win32more.Windows.Win32.System.Ioctl.PARTITION_STYLE = 0
PARTITION_STYLE_GPT: win32more.Windows.Win32.System.Ioctl.PARTITION_STYLE = 1
PARTITION_STYLE_RAW: win32more.Windows.Win32.System.Ioctl.PARTITION_STYLE = 2
class PATHNAME_BUFFER(Structure):
    PathNameLength: UInt32
    Name: Char * 1
class PERF_BIN(Structure):
    NumberOfBins: UInt32
    TypeOfBin: UInt32
    BinsRanges: win32more.Windows.Win32.System.Ioctl.BIN_RANGE * 1
class PERSISTENT_RESERVE_COMMAND(Structure):
    Version: UInt32
    Size: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        PR_IN: _PR_IN_e__Struct
        PR_OUT: _PR_OUT_e__Struct
        class _PR_IN_e__Struct(Structure):
            ServiceAction: Annotated[Byte, 5]
            Reserved1: Annotated[Byte, 3]
            AllocationLength: UInt16
        class _PR_OUT_e__Struct(Structure):
            ServiceAction: Annotated[Byte, 5]
            Reserved1: Annotated[Byte, 3]
            Type: Annotated[Byte, 4]
            Scope: Annotated[Byte, 4]
            ParameterList: Byte * 1
class PHYSICAL_ELEMENT_STATUS(Structure):
    Version: UInt32
    Size: UInt32
    DescriptorCount: UInt32
    ReturnedDescriptorCount: UInt32
    ElementIdentifierBeingDepoped: UInt32
    Reserved: UInt32
    Descriptors: win32more.Windows.Win32.System.Ioctl.PHYSICAL_ELEMENT_STATUS_DESCRIPTOR * 1
class PHYSICAL_ELEMENT_STATUS_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    ElementIdentifier: UInt32
    PhysicalElementType: Byte
    PhysicalElementHealth: Byte
    Reserved1: Byte * 2
    AssociatedCapacity: UInt64
    Reserved2: UInt32 * 4
class PHYSICAL_ELEMENT_STATUS_REQUEST(Structure):
    Version: UInt32
    Size: UInt32
    StartingElement: UInt32
    Filter: Byte
    ReportType: Byte
    Reserved: Byte * 2
@winfunctype_pointer
def PIO_IRP_EXT_PROCESS_TRACKED_OFFSET_CALLBACK(SourceContext: POINTER(win32more.Windows.Win32.System.Ioctl.IO_IRP_EXT_TRACK_OFFSET_HEADER), TargetContext: POINTER(win32more.Windows.Win32.System.Ioctl.IO_IRP_EXT_TRACK_OFFSET_HEADER), RelativeOffset: Int64) -> Void: ...
class PLEX_READ_DATA_REQUEST(Structure):
    ByteOffset: Int64
    ByteLength: UInt32
    PlexNumber: UInt32
class PREVENT_MEDIA_REMOVAL(Structure):
    PreventMediaRemoval: win32more.Windows.Win32.Foundation.BOOLEAN
class QUERY_BAD_RANGES_INPUT(Structure):
    Flags: UInt32
    NumRanges: UInt32
    Ranges: win32more.Windows.Win32.System.Ioctl.QUERY_BAD_RANGES_INPUT_RANGE * 1
class QUERY_BAD_RANGES_INPUT_RANGE(Structure):
    StartOffset: UInt64
    LengthInBytes: UInt64
class QUERY_BAD_RANGES_OUTPUT(Structure):
    Flags: UInt32
    NumBadRanges: UInt32
    NextOffsetToLookUp: UInt64
    BadRanges: win32more.Windows.Win32.System.Ioctl.QUERY_BAD_RANGES_OUTPUT_RANGE * 1
class QUERY_BAD_RANGES_OUTPUT_RANGE(Structure):
    Flags: UInt32
    Reserved: UInt32
    StartOffset: UInt64
    LengthInBytes: UInt64
QUERY_FILE_LAYOUT_FILTER_TYPE = Int32
QUERY_FILE_LAYOUT_FILTER_TYPE_NONE: win32more.Windows.Win32.System.Ioctl.QUERY_FILE_LAYOUT_FILTER_TYPE = 0
QUERY_FILE_LAYOUT_FILTER_TYPE_CLUSTERS: win32more.Windows.Win32.System.Ioctl.QUERY_FILE_LAYOUT_FILTER_TYPE = 1
QUERY_FILE_LAYOUT_FILTER_TYPE_FILEID: win32more.Windows.Win32.System.Ioctl.QUERY_FILE_LAYOUT_FILTER_TYPE = 2
QUERY_FILE_LAYOUT_FILTER_TYPE_STORAGE_RESERVE_ID: win32more.Windows.Win32.System.Ioctl.QUERY_FILE_LAYOUT_FILTER_TYPE = 3
QUERY_FILE_LAYOUT_NUM_FILTER_TYPES: win32more.Windows.Win32.System.Ioctl.QUERY_FILE_LAYOUT_FILTER_TYPE = 4
class QUERY_FILE_LAYOUT_INPUT(Structure):
    Anonymous: _Anonymous_e__Union
    Flags: UInt32
    FilterType: win32more.Windows.Win32.System.Ioctl.QUERY_FILE_LAYOUT_FILTER_TYPE
    Reserved: UInt32
    Filter: _Filter_e__Union
    class _Anonymous_e__Union(Union):
        FilterEntryCount: UInt32
        NumberOfPairs: UInt32
    class _Filter_e__Union(Union):
        ClusterRanges: win32more.Windows.Win32.System.Ioctl.CLUSTER_RANGE * 1
        FileReferenceRanges: win32more.Windows.Win32.System.Ioctl.FILE_REFERENCE_RANGE * 1
        StorageReserveIds: win32more.Windows.Win32.System.Ioctl.STORAGE_RESERVE_ID * 1
class QUERY_FILE_LAYOUT_OUTPUT(Structure):
    FileEntryCount: UInt32
    FirstFileOffset: UInt32
    Flags: UInt32
    Reserved: UInt32
class READ_ELEMENT_ADDRESS_INFO(Structure):
    NumberOfElements: UInt32
    ElementStatus: win32more.Windows.Win32.System.Ioctl.CHANGER_ELEMENT_STATUS * 1
class READ_FILE_USN_DATA(Structure):
    MinMajorVersion: UInt16
    MaxMajorVersion: UInt16
class READ_USN_JOURNAL_DATA_V0(Structure):
    StartUsn: Int64
    ReasonMask: UInt32
    ReturnOnlyOnClose: UInt32
    Timeout: UInt64
    BytesToWaitFor: UInt64
    UsnJournalID: UInt64
class READ_USN_JOURNAL_DATA_V1(Structure):
    StartUsn: Int64
    ReasonMask: UInt32
    ReturnOnlyOnClose: UInt32
    Timeout: UInt64
    BytesToWaitFor: UInt64
    UsnJournalID: UInt64
    MinMajorVersion: UInt16
    MaxMajorVersion: UInt16
class REASSIGN_BLOCKS(Structure):
    Reserved: UInt16
    Count: UInt16
    BlockNumber: UInt32 * 1
class REASSIGN_BLOCKS_EX(Structure):
    Reserved: UInt16
    Count: UInt16
    BlockNumber: Int64 * 1
    _pack_ = 1
REFS_SMR_VOLUME_GC_ACTION = Int32
SmrGcActionStart: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_ACTION = 1
SmrGcActionStartFullSpeed: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_ACTION = 2
SmrGcActionPause: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_ACTION = 3
SmrGcActionStop: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_ACTION = 4
REFS_SMR_VOLUME_GC_METHOD = Int32
SmrGcMethodCompaction: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_METHOD = 1
SmrGcMethodCompression: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_METHOD = 2
SmrGcMethodRotation: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_METHOD = 3
class REFS_SMR_VOLUME_GC_PARAMETERS(Structure):
    Version: UInt32
    Flags: UInt32
    Action: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_ACTION
    Method: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_METHOD
    IoGranularity: UInt32
    CompressionFormat: UInt32
    Unused: UInt64 * 8
REFS_SMR_VOLUME_GC_STATE = Int32
SmrGcStateInactive: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_STATE = 0
SmrGcStatePaused: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_STATE = 1
SmrGcStateActive: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_STATE = 2
SmrGcStateActiveFullSpeed: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_STATE = 3
class REFS_SMR_VOLUME_INFO_OUTPUT(Structure):
    Version: UInt32
    Flags: UInt32
    SizeOfRandomlyWritableTier: Int64
    FreeSpaceInRandomlyWritableTier: Int64
    SizeofSMRTier: Int64
    FreeSpaceInSMRTier: Int64
    UsableFreeSpaceInSMRTier: Int64
    VolumeGcState: win32more.Windows.Win32.System.Ioctl.REFS_SMR_VOLUME_GC_STATE
    VolumeGcLastStatus: UInt32
    CurrentGcBandFillPercentage: UInt32
    Unused: UInt64 * 6
class REFS_VOLUME_DATA_BUFFER(Structure):
    ByteCount: UInt32
    MajorVersion: UInt32
    MinorVersion: UInt32
    BytesPerPhysicalSector: UInt32
    VolumeSerialNumber: Int64
    NumberSectors: Int64
    TotalClusters: Int64
    FreeClusters: Int64
    TotalReserved: Int64
    BytesPerSector: UInt32
    BytesPerCluster: UInt32
    MaximumSizeOfResidentFile: Int64
    FastTierDataFillRatio: UInt16
    SlowTierDataFillRatio: UInt16
    DestagesFastTierToSlowTierRate: UInt32
    MetadataChecksumType: UInt16
    Reserved0: Byte * 6
    Reserved: Int64 * 8
class REMOVE_ELEMENT_AND_TRUNCATE_REQUEST(Structure):
    Version: UInt32
    Size: UInt32
    RequestCapacity: UInt64
    ElementIdentifier: UInt32
    Reserved: UInt32
class REPAIR_COPIES_INPUT(Structure):
    Size: UInt32
    Flags: UInt32
    FileOffset: Int64
    Length: UInt32
    SourceCopy: UInt32
    NumberOfRepairCopies: UInt32
    RepairCopies: UInt32 * 1
class REPAIR_COPIES_OUTPUT(Structure):
    Size: UInt32
    Status: UInt32
    ResumeFileOffset: Int64
class REQUEST_OPLOCK_INPUT_BUFFER(Structure):
    StructureVersion: UInt16
    StructureLength: UInt16
    RequestedOplockLevel: UInt32
    Flags: UInt32
class REQUEST_OPLOCK_OUTPUT_BUFFER(Structure):
    StructureVersion: UInt16
    StructureLength: UInt16
    OriginalOplockLevel: UInt32
    NewOplockLevel: UInt32
    Flags: UInt32
    AccessMode: UInt32
    ShareMode: UInt16
class REQUEST_RAW_ENCRYPTED_DATA(Structure):
    FileOffset: Int64
    Length: UInt32
class RETRIEVAL_POINTERS_AND_REFCOUNT_BUFFER(Structure):
    ExtentCount: UInt32
    StartingVcn: Int64
    Extents: _Anonymous_e__Struct * 1
    class _Anonymous_e__Struct(Structure):
        NextVcn: Int64
        Lcn: Int64
        ReferenceCount: UInt32
class RETRIEVAL_POINTERS_BUFFER(Structure):
    ExtentCount: UInt32
    StartingVcn: Int64
    Extents: _Anonymous_e__Struct * 1
    class _Anonymous_e__Struct(Structure):
        NextVcn: Int64
        Lcn: Int64
class RETRIEVAL_POINTER_BASE(Structure):
    FileAreaOffset: Int64
class RETRIEVAL_POINTER_COUNT(Structure):
    ExtentCount: UInt32
class SCM_BUS_DEDICATED_MEMORY_DEVICES_INFO(Structure):
    Version: UInt32
    Size: UInt32
    DeviceCount: UInt32
    Devices: win32more.Windows.Win32.System.Ioctl.SCM_BUS_DEDICATED_MEMORY_DEVICE_INFO * 1
class SCM_BUS_DEDICATED_MEMORY_DEVICE_INFO(Structure):
    DeviceGuid: Guid
    DeviceNumber: UInt32
    Flags: _Flags_e__Struct
    DeviceSize: UInt64
    class _Flags_e__Struct(Structure):
        ForcedByRegistry: Annotated[UInt32, 1]
        Initialized: Annotated[UInt32, 1]
        Reserved: Annotated[UInt32, 30]
class SCM_BUS_DEDICATED_MEMORY_STATE(Structure):
    ActivateState: win32more.Windows.Win32.Foundation.BOOLEAN
SCM_BUS_FIRMWARE_ACTIVATION_STATE = Int32
ScmBusFirmwareActivationState_Idle: win32more.Windows.Win32.System.Ioctl.SCM_BUS_FIRMWARE_ACTIVATION_STATE = 0
ScmBusFirmwareActivationState_Armed: win32more.Windows.Win32.System.Ioctl.SCM_BUS_FIRMWARE_ACTIVATION_STATE = 1
ScmBusFirmwareActivationState_Busy: win32more.Windows.Win32.System.Ioctl.SCM_BUS_FIRMWARE_ACTIVATION_STATE = 2
SCM_BUS_PROPERTY_ID = Int32
ScmBusProperty_RuntimeFwActivationInfo: win32more.Windows.Win32.System.Ioctl.SCM_BUS_PROPERTY_ID = 0
ScmBusProperty_DedicatedMemoryInfo: win32more.Windows.Win32.System.Ioctl.SCM_BUS_PROPERTY_ID = 1
ScmBusProperty_DedicatedMemoryState: win32more.Windows.Win32.System.Ioctl.SCM_BUS_PROPERTY_ID = 2
ScmBusProperty_Max: win32more.Windows.Win32.System.Ioctl.SCM_BUS_PROPERTY_ID = 3
class SCM_BUS_PROPERTY_QUERY(Structure):
    Version: UInt32
    Size: UInt32
    PropertyId: win32more.Windows.Win32.System.Ioctl.SCM_BUS_PROPERTY_ID
    QueryType: win32more.Windows.Win32.System.Ioctl.SCM_BUS_QUERY_TYPE
    AdditionalParameters: Byte * 1
class SCM_BUS_PROPERTY_SET(Structure):
    Version: UInt32
    Size: UInt32
    PropertyId: win32more.Windows.Win32.System.Ioctl.SCM_BUS_PROPERTY_ID
    SetType: win32more.Windows.Win32.System.Ioctl.SCM_BUS_SET_TYPE
    AdditionalParameters: Byte * 1
SCM_BUS_QUERY_TYPE = Int32
ScmBusQuery_Descriptor: win32more.Windows.Win32.System.Ioctl.SCM_BUS_QUERY_TYPE = 0
ScmBusQuery_IsSupported: win32more.Windows.Win32.System.Ioctl.SCM_BUS_QUERY_TYPE = 1
ScmBusQuery_Max: win32more.Windows.Win32.System.Ioctl.SCM_BUS_QUERY_TYPE = 2
class SCM_BUS_RUNTIME_FW_ACTIVATION_INFO(Structure):
    Version: UInt32
    Size: UInt32
    RuntimeFwActivationSupported: win32more.Windows.Win32.Foundation.BOOLEAN
    FirmwareActivationState: win32more.Windows.Win32.System.Ioctl.SCM_BUS_FIRMWARE_ACTIVATION_STATE
    FirmwareActivationCapability: _FirmwareActivationCapability_e__Struct
    EstimatedFirmwareActivationTimeInUSecs: UInt64
    EstimatedProcessorAccessQuiesceTimeInUSecs: UInt64
    EstimatedIOAccessQuiesceTimeInUSecs: UInt64
    PlatformSupportedMaxIOAccessQuiesceTimeInUSecs: UInt64
    class _FirmwareActivationCapability_e__Struct(Structure):
        FwManagedIoQuiesceFwActivationSupported: Annotated[UInt32, 1]
        OsManagedIoQuiesceFwActivationSupported: Annotated[UInt32, 1]
        WarmResetBasedFwActivationSupported: Annotated[UInt32, 1]
        Reserved: Annotated[UInt32, 29]
SCM_BUS_SET_TYPE = Int32
ScmBusSet_Descriptor: win32more.Windows.Win32.System.Ioctl.SCM_BUS_SET_TYPE = 0
ScmBusSet_IsSupported: win32more.Windows.Win32.System.Ioctl.SCM_BUS_SET_TYPE = 1
ScmBusSet_Max: win32more.Windows.Win32.System.Ioctl.SCM_BUS_SET_TYPE = 2
class SCM_INTERLEAVED_PD_INFO(Structure):
    DeviceHandle: UInt32
    DeviceGuid: Guid
class SCM_LD_INTERLEAVE_SET_INFO(Structure):
    Version: UInt32
    Size: UInt32
    InterleaveSetSize: UInt32
    InterleaveSet: win32more.Windows.Win32.System.Ioctl.SCM_INTERLEAVED_PD_INFO * 1
class SCM_LOGICAL_DEVICES(Structure):
    Version: UInt32
    Size: UInt32
    DeviceCount: UInt32
    Devices: win32more.Windows.Win32.System.Ioctl.SCM_LOGICAL_DEVICE_INSTANCE * 1
class SCM_LOGICAL_DEVICE_INSTANCE(Structure):
    Version: UInt32
    Size: UInt32
    DeviceGuid: Guid
    SymbolicLink: Char * 256
class SCM_PD_DESCRIPTOR_HEADER(Structure):
    Version: UInt32
    Size: UInt32
class SCM_PD_DEVICE_HANDLE(Structure):
    Version: UInt32
    Size: UInt32
    DeviceGuid: Guid
    DeviceHandle: UInt32
class SCM_PD_DEVICE_INFO(Structure):
    Version: UInt32
    Size: UInt32
    DeviceGuid: Guid
    UnsafeShutdownCount: UInt32
    PersistentMemorySizeInBytes: UInt64
    VolatileMemorySizeInBytes: UInt64
    TotalMemorySizeInBytes: UInt64
    SlotNumber: UInt32
    DeviceHandle: UInt32
    PhysicalId: UInt16
    NumberOfFormatInterfaceCodes: Byte
    FormatInterfaceCodes: UInt16 * 8
    VendorId: UInt32
    ProductId: UInt32
    SubsystemDeviceId: UInt32
    SubsystemVendorId: UInt32
    ManufacturingLocation: Byte
    ManufacturingWeek: Byte
    ManufacturingYear: Byte
    SerialNumber4Byte: UInt32
    SerialNumberLengthInChars: UInt32
    SerialNumber: win32more.Windows.Win32.Foundation.CHAR * 1
class SCM_PD_DEVICE_SPECIFIC_INFO(Structure):
    Version: UInt32
    Size: UInt32
    NumberOfProperties: UInt32
    DeviceSpecificProperties: win32more.Windows.Win32.System.Ioctl.SCM_PD_DEVICE_SPECIFIC_PROPERTY * 1
class SCM_PD_DEVICE_SPECIFIC_PROPERTY(Structure):
    Name: Char * 128
    Value: Int64
class SCM_PD_FIRMWARE_ACTIVATE(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    Slot: Byte
SCM_PD_FIRMWARE_ACTIVATION_STATE = Int32
ScmPdFirmwareActivationState_Idle: win32more.Windows.Win32.System.Ioctl.SCM_PD_FIRMWARE_ACTIVATION_STATE = 0
ScmPdFirmwareActivationState_Armed: win32more.Windows.Win32.System.Ioctl.SCM_PD_FIRMWARE_ACTIVATION_STATE = 1
ScmPdFirmwareActivationState_Busy: win32more.Windows.Win32.System.Ioctl.SCM_PD_FIRMWARE_ACTIVATION_STATE = 2
class SCM_PD_FIRMWARE_DOWNLOAD(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    Slot: Byte
    Reserved: Byte * 3
    Offset: UInt64
    FirmwareImageSizeInBytes: UInt32
    FirmwareImage: Byte * 1
class SCM_PD_FIRMWARE_INFO(Structure):
    Version: UInt32
    Size: UInt32
    ActiveSlot: Byte
    NextActiveSlot: Byte
    SlotCount: Byte
    Slots: win32more.Windows.Win32.System.Ioctl.SCM_PD_FIRMWARE_SLOT_INFO * 1
class SCM_PD_FIRMWARE_SLOT_INFO(Structure):
    Version: UInt32
    Size: UInt32
    SlotNumber: Byte
    ReadOnly: Annotated[Byte, 1]
    Reserved0: Annotated[Byte, 7]
    Reserved1: Byte * 6
    Revision: Byte * 32
class SCM_PD_FRU_ID_STRING(Structure):
    Version: UInt32
    Size: UInt32
    IdentifierSize: UInt32
    Identifier: Byte * 1
class SCM_PD_HEALTH_NOTIFICATION_DATA(Structure):
    DeviceGuid: Guid
SCM_PD_HEALTH_STATUS = Int32
ScmPhysicalDeviceHealth_Unknown: win32more.Windows.Win32.System.Ioctl.SCM_PD_HEALTH_STATUS = 0
ScmPhysicalDeviceHealth_Unhealthy: win32more.Windows.Win32.System.Ioctl.SCM_PD_HEALTH_STATUS = 1
ScmPhysicalDeviceHealth_Warning: win32more.Windows.Win32.System.Ioctl.SCM_PD_HEALTH_STATUS = 2
ScmPhysicalDeviceHealth_Healthy: win32more.Windows.Win32.System.Ioctl.SCM_PD_HEALTH_STATUS = 3
ScmPhysicalDeviceHealth_Max: win32more.Windows.Win32.System.Ioctl.SCM_PD_HEALTH_STATUS = 4
SCM_PD_LAST_FW_ACTIVATION_STATUS = Int32
ScmPdLastFwActivationStatus_None: win32more.Windows.Win32.System.Ioctl.SCM_PD_LAST_FW_ACTIVATION_STATUS = 0
ScmPdLastFwActivationStatus_Success: win32more.Windows.Win32.System.Ioctl.SCM_PD_LAST_FW_ACTIVATION_STATUS = 1
ScmPdLastFwActivationStatus_FwNotFound: win32more.Windows.Win32.System.Ioctl.SCM_PD_LAST_FW_ACTIVATION_STATUS = 2
ScmPdLastFwActivationStatus_ColdRebootRequired: win32more.Windows.Win32.System.Ioctl.SCM_PD_LAST_FW_ACTIVATION_STATUS = 3
ScmPdLastFwActivaitonStatus_ActivationInProgress: win32more.Windows.Win32.System.Ioctl.SCM_PD_LAST_FW_ACTIVATION_STATUS = 4
ScmPdLastFwActivaitonStatus_Retry: win32more.Windows.Win32.System.Ioctl.SCM_PD_LAST_FW_ACTIVATION_STATUS = 5
ScmPdLastFwActivaitonStatus_FwUnsupported: win32more.Windows.Win32.System.Ioctl.SCM_PD_LAST_FW_ACTIVATION_STATUS = 6
ScmPdLastFwActivaitonStatus_UnknownError: win32more.Windows.Win32.System.Ioctl.SCM_PD_LAST_FW_ACTIVATION_STATUS = 7
class SCM_PD_LOCATION_STRING(Structure):
    Version: UInt32
    Size: UInt32
    Location: Char * 1
class SCM_PD_MANAGEMENT_STATUS(Structure):
    Version: UInt32
    Size: UInt32
    Health: win32more.Windows.Win32.System.Ioctl.SCM_PD_HEALTH_STATUS
    NumberOfOperationalStatus: UInt32
    NumberOfAdditionalReasons: UInt32
    OperationalStatus: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS * 16
    AdditionalReasons: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON * 1
SCM_PD_MEDIA_REINITIALIZATION_STATUS = Int32
ScmPhysicalDeviceReinit_Success: win32more.Windows.Win32.System.Ioctl.SCM_PD_MEDIA_REINITIALIZATION_STATUS = 0
ScmPhysicalDeviceReinit_RebootNeeded: win32more.Windows.Win32.System.Ioctl.SCM_PD_MEDIA_REINITIALIZATION_STATUS = 1
ScmPhysicalDeviceReinit_ColdBootNeeded: win32more.Windows.Win32.System.Ioctl.SCM_PD_MEDIA_REINITIALIZATION_STATUS = 2
ScmPhysicalDeviceReinit_Max: win32more.Windows.Win32.System.Ioctl.SCM_PD_MEDIA_REINITIALIZATION_STATUS = 3
SCM_PD_OPERATIONAL_STATUS = Int32
ScmPhysicalDeviceOpStatus_Unknown: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS = 0
ScmPhysicalDeviceOpStatus_Ok: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS = 1
ScmPhysicalDeviceOpStatus_PredictingFailure: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS = 2
ScmPhysicalDeviceOpStatus_InService: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS = 3
ScmPhysicalDeviceOpStatus_HardwareError: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS = 4
ScmPhysicalDeviceOpStatus_NotUsable: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS = 5
ScmPhysicalDeviceOpStatus_TransientError: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS = 6
ScmPhysicalDeviceOpStatus_Missing: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS = 7
ScmPhysicalDeviceOpStatus_Max: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS = 8
SCM_PD_OPERATIONAL_STATUS_REASON = Int32
ScmPhysicalDeviceOpReason_Unknown: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 0
ScmPhysicalDeviceOpReason_Media: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 1
ScmPhysicalDeviceOpReason_ThresholdExceeded: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 2
ScmPhysicalDeviceOpReason_LostData: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 3
ScmPhysicalDeviceOpReason_EnergySource: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 4
ScmPhysicalDeviceOpReason_Configuration: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 5
ScmPhysicalDeviceOpReason_DeviceController: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 6
ScmPhysicalDeviceOpReason_MediaController: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 7
ScmPhysicalDeviceOpReason_Component: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 8
ScmPhysicalDeviceOpReason_BackgroundOperation: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 9
ScmPhysicalDeviceOpReason_InvalidFirmware: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 10
ScmPhysicalDeviceOpReason_HealthCheck: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 11
ScmPhysicalDeviceOpReason_LostDataPersistence: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 12
ScmPhysicalDeviceOpReason_DisabledByPlatform: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 13
ScmPhysicalDeviceOpReason_PermanentError: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 14
ScmPhysicalDeviceOpReason_LostWritePersistence: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 15
ScmPhysicalDeviceOpReason_FatalError: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 16
ScmPhysicalDeviceOpReason_DataPersistenceLossImminent: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 17
ScmPhysicalDeviceOpReason_WritePersistenceLossImminent: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 18
ScmPhysicalDeviceOpReason_MediaRemainingSpareBlock: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 19
ScmPhysicalDeviceOpReason_PerformanceDegradation: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 20
ScmPhysicalDeviceOpReason_ExcessiveTemperature: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 21
ScmPhysicalDeviceOpReason_InternalFailure: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 22
ScmPhysicalDeviceOpReason_Max: win32more.Windows.Win32.System.Ioctl.SCM_PD_OPERATIONAL_STATUS_REASON = 23
class SCM_PD_PASSTHROUGH_INPUT(Structure):
    Version: UInt32
    Size: UInt32
    ProtocolGuid: Guid
    DataSize: UInt32
    Data: Byte * 1
class SCM_PD_PASSTHROUGH_INVDIMM_INPUT(Structure):
    Opcode: UInt32
    OpcodeParametersLength: UInt32
    OpcodeParameters: Byte * 1
class SCM_PD_PASSTHROUGH_INVDIMM_OUTPUT(Structure):
    GeneralStatus: UInt16
    ExtendedStatus: UInt16
    OutputDataLength: UInt32
    OutputData: Byte * 1
class SCM_PD_PASSTHROUGH_OUTPUT(Structure):
    Version: UInt32
    Size: UInt32
    ProtocolGuid: Guid
    DataSize: UInt32
    Data: Byte * 1
SCM_PD_PROPERTY_ID = Int32
ScmPhysicalDeviceProperty_DeviceInfo: win32more.Windows.Win32.System.Ioctl.SCM_PD_PROPERTY_ID = 0
ScmPhysicalDeviceProperty_ManagementStatus: win32more.Windows.Win32.System.Ioctl.SCM_PD_PROPERTY_ID = 1
ScmPhysicalDeviceProperty_FirmwareInfo: win32more.Windows.Win32.System.Ioctl.SCM_PD_PROPERTY_ID = 2
ScmPhysicalDeviceProperty_LocationString: win32more.Windows.Win32.System.Ioctl.SCM_PD_PROPERTY_ID = 3
ScmPhysicalDeviceProperty_DeviceSpecificInfo: win32more.Windows.Win32.System.Ioctl.SCM_PD_PROPERTY_ID = 4
ScmPhysicalDeviceProperty_DeviceHandle: win32more.Windows.Win32.System.Ioctl.SCM_PD_PROPERTY_ID = 5
ScmPhysicalDeviceProperty_FruIdString: win32more.Windows.Win32.System.Ioctl.SCM_PD_PROPERTY_ID = 6
ScmPhysicalDeviceProperty_RuntimeFwActivationInfo: win32more.Windows.Win32.System.Ioctl.SCM_PD_PROPERTY_ID = 7
ScmPhysicalDeviceProperty_RuntimeFwActivationArmState: win32more.Windows.Win32.System.Ioctl.SCM_PD_PROPERTY_ID = 8
ScmPhysicalDeviceProperty_Max: win32more.Windows.Win32.System.Ioctl.SCM_PD_PROPERTY_ID = 9
class SCM_PD_PROPERTY_QUERY(Structure):
    Version: UInt32
    Size: UInt32
    PropertyId: win32more.Windows.Win32.System.Ioctl.SCM_PD_PROPERTY_ID
    QueryType: win32more.Windows.Win32.System.Ioctl.SCM_PD_QUERY_TYPE
    AdditionalParameters: Byte * 1
class SCM_PD_PROPERTY_SET(Structure):
    Version: UInt32
    Size: UInt32
    PropertyId: win32more.Windows.Win32.System.Ioctl.SCM_PD_PROPERTY_ID
    SetType: win32more.Windows.Win32.System.Ioctl.SCM_PD_SET_TYPE
    AdditionalParameters: Byte * 1
SCM_PD_QUERY_TYPE = Int32
ScmPhysicalDeviceQuery_Descriptor: win32more.Windows.Win32.System.Ioctl.SCM_PD_QUERY_TYPE = 0
ScmPhysicalDeviceQuery_IsSupported: win32more.Windows.Win32.System.Ioctl.SCM_PD_QUERY_TYPE = 1
ScmPhysicalDeviceQuery_Max: win32more.Windows.Win32.System.Ioctl.SCM_PD_QUERY_TYPE = 2
class SCM_PD_REINITIALIZE_MEDIA_INPUT(Structure):
    Version: UInt32
    Size: UInt32
    Options: _Options_e__Struct
    class _Options_e__Struct(Structure):
        Overwrite: Annotated[UInt32, 1]
class SCM_PD_REINITIALIZE_MEDIA_OUTPUT(Structure):
    Version: UInt32
    Size: UInt32
    Status: win32more.Windows.Win32.System.Ioctl.SCM_PD_MEDIA_REINITIALIZATION_STATUS
class SCM_PD_RUNTIME_FW_ACTIVATION_ARM_STATE(Structure):
    ArmState: win32more.Windows.Win32.Foundation.BOOLEAN
class SCM_PD_RUNTIME_FW_ACTIVATION_INFO(Structure):
    Version: UInt32
    Size: UInt32
    LastFirmwareActivationStatus: win32more.Windows.Win32.System.Ioctl.SCM_PD_LAST_FW_ACTIVATION_STATUS
    FirmwareActivationState: win32more.Windows.Win32.System.Ioctl.SCM_PD_FIRMWARE_ACTIVATION_STATE
SCM_PD_SET_TYPE = Int32
ScmPhysicalDeviceSet_Descriptor: win32more.Windows.Win32.System.Ioctl.SCM_PD_SET_TYPE = 0
ScmPhysicalDeviceSet_IsSupported: win32more.Windows.Win32.System.Ioctl.SCM_PD_SET_TYPE = 1
ScmPhysicalDeviceSet_Max: win32more.Windows.Win32.System.Ioctl.SCM_PD_SET_TYPE = 2
class SCM_PHYSICAL_DEVICES(Structure):
    Version: UInt32
    Size: UInt32
    DeviceCount: UInt32
    Devices: win32more.Windows.Win32.System.Ioctl.SCM_PHYSICAL_DEVICE_INSTANCE * 1
class SCM_PHYSICAL_DEVICE_INSTANCE(Structure):
    Version: UInt32
    Size: UInt32
    NfitHandle: UInt32
    SymbolicLink: Char * 256
class SCM_REGION(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    NfitHandle: UInt32
    LogicalDeviceGuid: Guid
    AddressRangeType: Guid
    AssociatedId: UInt32
    Length: UInt64
    StartingDPA: UInt64
    BaseSPA: UInt64
    SPAOffset: UInt64
    RegionOffset: UInt64
class SCM_REGIONS(Structure):
    Version: UInt32
    Size: UInt32
    RegionCount: UInt32
    Regions: win32more.Windows.Win32.System.Ioctl.SCM_REGION * 1
SCM_REGION_FLAG = Int32
ScmRegionFlagNone: win32more.Windows.Win32.System.Ioctl.SCM_REGION_FLAG = 0
ScmRegionFlagLabel: win32more.Windows.Win32.System.Ioctl.SCM_REGION_FLAG = 1
class SD_CHANGE_MACHINE_SID_INPUT(Structure):
    CurrentMachineSIDOffset: UInt16
    CurrentMachineSIDLength: UInt16
    NewMachineSIDOffset: UInt16
    NewMachineSIDLength: UInt16
class SD_CHANGE_MACHINE_SID_OUTPUT(Structure):
    NumSDChangedSuccess: UInt64
    NumSDChangedFail: UInt64
    NumSDUnused: UInt64
    NumSDTotal: UInt64
    NumMftSDChangedSuccess: UInt64
    NumMftSDChangedFail: UInt64
    NumMftSDTotal: UInt64
class SD_ENUM_SDS_ENTRY(Structure):
    Hash: UInt32
    SecurityId: UInt32
    Offset: UInt64
    Length: UInt32
    Descriptor: Byte * 1
class SD_ENUM_SDS_INPUT(Structure):
    StartingOffset: UInt64
    MaxSDEntriesToReturn: UInt64
class SD_ENUM_SDS_OUTPUT(Structure):
    NextOffset: UInt64
    NumSDEntriesReturned: UInt64
    NumSDBytesReturned: UInt64
    SDEntry: win32more.Windows.Win32.System.Ioctl.SD_ENUM_SDS_ENTRY * 1
class SD_GLOBAL_CHANGE_INPUT(Structure):
    Flags: UInt32
    ChangeType: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        SdChange: win32more.Windows.Win32.System.Ioctl.SD_CHANGE_MACHINE_SID_INPUT
        SdQueryStats: win32more.Windows.Win32.System.Ioctl.SD_QUERY_STATS_INPUT
        SdEnumSds: win32more.Windows.Win32.System.Ioctl.SD_ENUM_SDS_INPUT
class SD_GLOBAL_CHANGE_OUTPUT(Structure):
    Flags: UInt32
    ChangeType: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        SdChange: win32more.Windows.Win32.System.Ioctl.SD_CHANGE_MACHINE_SID_OUTPUT
        SdQueryStats: win32more.Windows.Win32.System.Ioctl.SD_QUERY_STATS_OUTPUT
        SdEnumSds: win32more.Windows.Win32.System.Ioctl.SD_ENUM_SDS_OUTPUT
class SD_QUERY_STATS_INPUT(Structure):
    Reserved: UInt32
class SD_QUERY_STATS_OUTPUT(Structure):
    SdsStreamSize: UInt64
    SdsAllocationSize: UInt64
    SiiStreamSize: UInt64
    SiiAllocationSize: UInt64
    SdhStreamSize: UInt64
    SdhAllocationSize: UInt64
    NumSDTotal: UInt64
    NumSDUnused: UInt64
class SENDCMDINPARAMS(Structure):
    cBufferSize: UInt32
    irDriveRegs: win32more.Windows.Win32.System.Ioctl.IDEREGS
    bDriveNumber: Byte
    bReserved: Byte * 3
    dwReserved: UInt32 * 4
    bBuffer: Byte * 1
    _pack_ = 1
class SENDCMDOUTPARAMS(Structure):
    cBufferSize: UInt32
    DriverStatus: win32more.Windows.Win32.System.Ioctl.DRIVERSTATUS
    bBuffer: Byte * 1
    _pack_ = 1
class SET_DAX_ALLOC_ALIGNMENT_HINT_INPUT(Structure):
    Flags: UInt32
    AlignmentShift: UInt32
    FileOffsetToAlign: UInt64
    FallbackAlignmentShift: UInt32
class SET_DISK_ATTRIBUTES(Structure):
    Version: UInt32
    Persist: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved1: Byte * 3
    Attributes: UInt64
    AttributesMask: UInt64
    Reserved2: UInt32 * 4
class SET_PARTITION_INFORMATION(Structure):
    PartitionType: Byte
class SET_PARTITION_INFORMATION_EX(Structure):
    PartitionStyle: win32more.Windows.Win32.System.Ioctl.PARTITION_STYLE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Mbr: win32more.Windows.Win32.System.Ioctl.SET_PARTITION_INFORMATION
        Gpt: win32more.Windows.Win32.System.Ioctl.PARTITION_INFORMATION_GPT
class SET_PURGE_FAILURE_MODE_INPUT(Structure):
    Flags: UInt32
class SHRINK_VOLUME_INFORMATION(Structure):
    ShrinkRequestType: win32more.Windows.Win32.System.Ioctl.SHRINK_VOLUME_REQUEST_TYPES
    Flags: UInt64
    NewNumberOfSectors: Int64
SHRINK_VOLUME_REQUEST_TYPES = Int32
ShrinkPrepare: win32more.Windows.Win32.System.Ioctl.SHRINK_VOLUME_REQUEST_TYPES = 1
ShrinkCommit: win32more.Windows.Win32.System.Ioctl.SHRINK_VOLUME_REQUEST_TYPES = 2
ShrinkAbort: win32more.Windows.Win32.System.Ioctl.SHRINK_VOLUME_REQUEST_TYPES = 3
class SI_COPYFILE(Structure):
    SourceFileNameLength: UInt32
    DestinationFileNameLength: UInt32
    Flags: UInt32
    FileNameBuffer: Char * 1
class SMB_SHARE_FLUSH_AND_PURGE_INPUT(Structure):
    Version: UInt16
class SMB_SHARE_FLUSH_AND_PURGE_OUTPUT(Structure):
    cEntriesPurged: UInt32
class STARTING_LCN_INPUT_BUFFER(Structure):
    StartingLcn: Int64
class STARTING_LCN_INPUT_BUFFER_EX(Structure):
    StartingLcn: Int64
    Flags: UInt32
class STARTING_VCN_INPUT_BUFFER(Structure):
    StartingVcn: Int64
class STORAGE_ACCESS_ALIGNMENT_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    BytesPerCacheLine: UInt32
    BytesOffsetForCacheAlignment: UInt32
    BytesPerLogicalSector: UInt32
    BytesPerPhysicalSector: UInt32
    BytesOffsetForSectorAlignment: UInt32
class STORAGE_ADAPTER_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    MaximumTransferLength: UInt32
    MaximumPhysicalPages: UInt32
    AlignmentMask: UInt32
    AdapterUsesPio: win32more.Windows.Win32.Foundation.BOOLEAN
    AdapterScansDown: win32more.Windows.Win32.Foundation.BOOLEAN
    CommandQueueing: win32more.Windows.Win32.Foundation.BOOLEAN
    AcceleratedTransfer: win32more.Windows.Win32.Foundation.BOOLEAN
    BusType: Byte
    BusMajorVersion: UInt16
    BusMinorVersion: UInt16
    SrbType: Byte
    AddressType: Byte
class STORAGE_ADAPTER_SERIAL_NUMBER(Structure):
    Version: UInt32
    Size: UInt32
    SerialNumber: Char * 128
class STORAGE_ALLOCATE_BC_STREAM_INPUT(Structure):
    Version: UInt32
    RequestsPerPeriod: UInt32
    Period: UInt32
    RetryFailures: win32more.Windows.Win32.Foundation.BOOLEAN
    Discardable: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved1: win32more.Windows.Win32.Foundation.BOOLEAN * 2
    AccessType: UInt32
    AccessMode: UInt32
class STORAGE_ALLOCATE_BC_STREAM_OUTPUT(Structure):
    RequestSize: UInt64
    NumOutStandingRequests: UInt32
STORAGE_ASSOCIATION_TYPE = Int32
StorageIdAssocDevice: win32more.Windows.Win32.System.Ioctl.STORAGE_ASSOCIATION_TYPE = 0
StorageIdAssocPort: win32more.Windows.Win32.System.Ioctl.STORAGE_ASSOCIATION_TYPE = 1
StorageIdAssocTarget: win32more.Windows.Win32.System.Ioctl.STORAGE_ASSOCIATION_TYPE = 2
class STORAGE_ATTRIBUTE_MGMT(Structure):
    Version: UInt32
    Size: UInt32
    Action: win32more.Windows.Win32.System.Ioctl.STORAGE_ATTRIBUTE_MGMT_ACTION
    Attribute: UInt32
STORAGE_ATTRIBUTE_MGMT_ACTION = Int32
StorAttributeMgmt_ClearAttribute: win32more.Windows.Win32.System.Ioctl.STORAGE_ATTRIBUTE_MGMT_ACTION = 0
StorAttributeMgmt_SetAttribute: win32more.Windows.Win32.System.Ioctl.STORAGE_ATTRIBUTE_MGMT_ACTION = 1
StorAttributeMgmt_ResetAttribute: win32more.Windows.Win32.System.Ioctl.STORAGE_ATTRIBUTE_MGMT_ACTION = 2
class STORAGE_BREAK_RESERVATION_REQUEST(Structure):
    Length: UInt32
    _unused: Byte
    PathId: Byte
    TargetId: Byte
    Lun: Byte
class STORAGE_BUS_RESET_REQUEST(Structure):
    PathId: Byte
STORAGE_COMPONENT_HEALTH_STATUS = Int32
HealthStatusUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_COMPONENT_HEALTH_STATUS = 0
HealthStatusNormal: win32more.Windows.Win32.System.Ioctl.STORAGE_COMPONENT_HEALTH_STATUS = 1
HealthStatusThrottled: win32more.Windows.Win32.System.Ioctl.STORAGE_COMPONENT_HEALTH_STATUS = 2
HealthStatusWarning: win32more.Windows.Win32.System.Ioctl.STORAGE_COMPONENT_HEALTH_STATUS = 3
HealthStatusDisabled: win32more.Windows.Win32.System.Ioctl.STORAGE_COMPONENT_HEALTH_STATUS = 4
HealthStatusFailed: win32more.Windows.Win32.System.Ioctl.STORAGE_COMPONENT_HEALTH_STATUS = 5
class STORAGE_COUNTER(Structure):
    Type: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE
    Value: _Value_e__Union
    class _Value_e__Union(Union):
        ManufactureDate: _ManufactureDate_e__Struct
        AsUlonglong: UInt64
        class _ManufactureDate_e__Struct(Structure):
            Week: UInt32
            Year: UInt32
class STORAGE_COUNTERS(Structure):
    Version: UInt32
    Size: UInt32
    NumberOfCounters: UInt32
    Counters: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER * 1
STORAGE_COUNTER_TYPE = Int32
StorageCounterTypeUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 0
StorageCounterTypeTemperatureCelsius: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 1
StorageCounterTypeTemperatureCelsiusMax: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 2
StorageCounterTypeReadErrorsTotal: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 3
StorageCounterTypeReadErrorsCorrected: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 4
StorageCounterTypeReadErrorsUncorrected: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 5
StorageCounterTypeWriteErrorsTotal: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 6
StorageCounterTypeWriteErrorsCorrected: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 7
StorageCounterTypeWriteErrorsUncorrected: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 8
StorageCounterTypeManufactureDate: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 9
StorageCounterTypeStartStopCycleCount: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 10
StorageCounterTypeStartStopCycleCountMax: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 11
StorageCounterTypeLoadUnloadCycleCount: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 12
StorageCounterTypeLoadUnloadCycleCountMax: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 13
StorageCounterTypeWearPercentage: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 14
StorageCounterTypeWearPercentageWarning: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 15
StorageCounterTypeWearPercentageMax: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 16
StorageCounterTypePowerOnHours: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 17
StorageCounterTypeReadLatency100NSMax: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 18
StorageCounterTypeWriteLatency100NSMax: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 19
StorageCounterTypeFlushLatency100NSMax: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 20
StorageCounterTypeMax: win32more.Windows.Win32.System.Ioctl.STORAGE_COUNTER_TYPE = 21
STORAGE_CRYPTO_ALGORITHM_ID = Int32
StorageCryptoAlgorithmUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_ALGORITHM_ID = 0
StorageCryptoAlgorithmXTSAES: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_ALGORITHM_ID = 1
StorageCryptoAlgorithmBitlockerAESCBC: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_ALGORITHM_ID = 2
StorageCryptoAlgorithmAESECB: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_ALGORITHM_ID = 3
StorageCryptoAlgorithmESSIVAESCBC: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_ALGORITHM_ID = 4
StorageCryptoAlgorithmMax: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_ALGORITHM_ID = 5
class STORAGE_CRYPTO_CAPABILITY(Structure):
    Version: UInt32
    Size: UInt32
    CryptoCapabilityIndex: UInt32
    AlgorithmId: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_ALGORITHM_ID
    KeySize: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_KEY_SIZE
    DataUnitSizeBitmask: UInt32
class STORAGE_CRYPTO_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    NumKeysSupported: UInt32
    NumCryptoCapabilities: UInt32
    CryptoCapabilities: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_CAPABILITY * 1
STORAGE_CRYPTO_KEY_SIZE = Int32
StorageCryptoKeySizeUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_KEY_SIZE = 0
StorageCryptoKeySize128Bits: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_KEY_SIZE = 1
StorageCryptoKeySize192Bits: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_KEY_SIZE = 2
StorageCryptoKeySize256Bits: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_KEY_SIZE = 3
StorageCryptoKeySize512Bits: win32more.Windows.Win32.System.Ioctl.STORAGE_CRYPTO_KEY_SIZE = 4
class STORAGE_DESCRIPTOR_HEADER(Structure):
    Version: UInt32
    Size: UInt32
class STORAGE_DEVICE_ATTRIBUTES_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    Attributes: UInt64
class STORAGE_DEVICE_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    DeviceType: Byte
    DeviceTypeModifier: Byte
    RemovableMedia: win32more.Windows.Win32.Foundation.BOOLEAN
    CommandQueueing: win32more.Windows.Win32.Foundation.BOOLEAN
    VendorIdOffset: UInt32
    ProductIdOffset: UInt32
    ProductRevisionOffset: UInt32
    SerialNumberOffset: UInt32
    BusType: win32more.Windows.Win32.Storage.FileSystem.STORAGE_BUS_TYPE
    RawPropertiesLength: UInt32
    RawDeviceProperties: Byte * 1
class STORAGE_DEVICE_FAULT_DOMAIN_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    NumberOfFaultDomains: UInt32
    FaultDomainIds: Guid * 1
STORAGE_DEVICE_FORM_FACTOR = Int32
FormFactorUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_FORM_FACTOR = 0
FormFactor3_5: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_FORM_FACTOR = 1
FormFactor2_5: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_FORM_FACTOR = 2
FormFactor1_8: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_FORM_FACTOR = 3
FormFactor1_8Less: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_FORM_FACTOR = 4
FormFactorEmbedded: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_FORM_FACTOR = 5
FormFactorMemoryCard: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_FORM_FACTOR = 6
FormFactormSata: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_FORM_FACTOR = 7
FormFactorM_2: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_FORM_FACTOR = 8
FormFactorPCIeBoard: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_FORM_FACTOR = 9
FormFactorDimm: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_FORM_FACTOR = 10
class STORAGE_DEVICE_ID_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    NumberOfIdentifiers: UInt32
    Identifiers: Byte * 1
class STORAGE_DEVICE_IO_CAPABILITY_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    LunMaxIoCount: UInt32
    AdapterMaxIoCount: UInt32
class STORAGE_DEVICE_LED_STATE_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    State: UInt64
class STORAGE_DEVICE_LOCATION_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    Location: win32more.Windows.Win32.System.Ioctl.DEVICE_LOCATION
    StringOffset: UInt32
class STORAGE_DEVICE_MANAGEMENT_STATUS(Structure):
    Version: UInt32
    Size: UInt32
    Health: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_HEALTH_STATUS
    NumberOfOperationalStatus: UInt32
    NumberOfAdditionalReasons: UInt32
    OperationalStatus: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_OPERATIONAL_STATUS * 16
    AdditionalReasons: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_REASON * 1
class STORAGE_DEVICE_NUMA_PROPERTY(Structure):
    Version: UInt32
    Size: UInt32
    NumaNode: UInt32
class STORAGE_DEVICE_NUMBER(Structure):
    DeviceType: UInt32
    DeviceNumber: UInt32
    PartitionNumber: UInt32
class STORAGE_DEVICE_NUMBERS(Structure):
    Version: UInt32
    Size: UInt32
    NumberOfDevices: UInt32
    Devices: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_NUMBER * 1
class STORAGE_DEVICE_NUMBER_EX(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    DeviceType: UInt32
    DeviceNumber: UInt32
    DeviceGuid: Guid
    PartitionNumber: UInt32
class STORAGE_DEVICE_POWER_CAP(Structure):
    Version: UInt32
    Size: UInt32
    Units: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_POWER_CAP_UNITS
    MaxPower: UInt64
STORAGE_DEVICE_POWER_CAP_UNITS = Int32
StorageDevicePowerCapUnitsPercent: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_POWER_CAP_UNITS = 0
StorageDevicePowerCapUnitsMilliwatts: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_POWER_CAP_UNITS = 1
class STORAGE_DEVICE_RESILIENCY_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    NameOffset: UInt32
    NumberOfLogicalCopies: UInt32
    NumberOfPhysicalCopies: UInt32
    PhysicalDiskRedundancy: UInt32
    NumberOfColumns: UInt32
    Interleave: UInt32
class STORAGE_DEVICE_SELF_ENCRYPTION_PROPERTY(Structure):
    Version: UInt32
    Size: UInt32
    SupportsSelfEncryption: win32more.Windows.Win32.Foundation.BOOLEAN
class STORAGE_DEVICE_SELF_ENCRYPTION_PROPERTY_V2(Structure):
    Version: UInt32
    Size: UInt32
    SupportsSelfEncryption: win32more.Windows.Win32.Foundation.BOOLEAN
    EncryptionType: win32more.Windows.Win32.System.Ioctl.STORAGE_ENCRYPTION_TYPE
class STORAGE_DEVICE_TIERING_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    TotalNumberOfTiers: UInt32
    NumberOfTiersReturned: UInt32
    Tiers: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER * 1
class STORAGE_DEVICE_UNSAFE_SHUTDOWN_COUNT(Structure):
    Version: UInt32
    Size: UInt32
    UnsafeShutdownCount: UInt32
class STORAGE_DIAGNOSTIC_DATA(Structure):
    Version: UInt32
    Size: UInt32
    ProviderId: Guid
    BufferSize: UInt32
    Reserved: UInt32
    DiagnosticDataBuffer: Byte * 1
STORAGE_DIAGNOSTIC_LEVEL = Int32
StorageDiagnosticLevelDefault: win32more.Windows.Win32.System.Ioctl.STORAGE_DIAGNOSTIC_LEVEL = 0
StorageDiagnosticLevelMax: win32more.Windows.Win32.System.Ioctl.STORAGE_DIAGNOSTIC_LEVEL = 1
class STORAGE_DIAGNOSTIC_REQUEST(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    TargetType: win32more.Windows.Win32.System.Ioctl.STORAGE_DIAGNOSTIC_TARGET_TYPE
    Level: win32more.Windows.Win32.System.Ioctl.STORAGE_DIAGNOSTIC_LEVEL
STORAGE_DIAGNOSTIC_TARGET_TYPE = Int32
StorageDiagnosticTargetTypeUndefined: win32more.Windows.Win32.System.Ioctl.STORAGE_DIAGNOSTIC_TARGET_TYPE = 0
StorageDiagnosticTargetTypePort: win32more.Windows.Win32.System.Ioctl.STORAGE_DIAGNOSTIC_TARGET_TYPE = 1
StorageDiagnosticTargetTypeMiniport: win32more.Windows.Win32.System.Ioctl.STORAGE_DIAGNOSTIC_TARGET_TYPE = 2
StorageDiagnosticTargetTypeHbaFirmware: win32more.Windows.Win32.System.Ioctl.STORAGE_DIAGNOSTIC_TARGET_TYPE = 3
StorageDiagnosticTargetTypeMax: win32more.Windows.Win32.System.Ioctl.STORAGE_DIAGNOSTIC_TARGET_TYPE = 4
STORAGE_DISK_HEALTH_STATUS = Int32
DiskHealthUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_HEALTH_STATUS = 0
DiskHealthUnhealthy: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_HEALTH_STATUS = 1
DiskHealthWarning: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_HEALTH_STATUS = 2
DiskHealthHealthy: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_HEALTH_STATUS = 3
DiskHealthMax: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_HEALTH_STATUS = 4
STORAGE_DISK_OPERATIONAL_STATUS = Int32
DiskOpStatusNone: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_OPERATIONAL_STATUS = 0
DiskOpStatusUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_OPERATIONAL_STATUS = 1
DiskOpStatusOk: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_OPERATIONAL_STATUS = 2
DiskOpStatusPredictingFailure: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_OPERATIONAL_STATUS = 3
DiskOpStatusInService: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_OPERATIONAL_STATUS = 4
DiskOpStatusHardwareError: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_OPERATIONAL_STATUS = 5
DiskOpStatusNotUsable: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_OPERATIONAL_STATUS = 6
DiskOpStatusTransientError: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_OPERATIONAL_STATUS = 7
DiskOpStatusMissing: win32more.Windows.Win32.System.Ioctl.STORAGE_DISK_OPERATIONAL_STATUS = 8
STORAGE_ENCRYPTION_TYPE = Int32
StorageEncryptionTypeUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_ENCRYPTION_TYPE = 0
StorageEncryptionTypeEDrive: win32more.Windows.Win32.System.Ioctl.STORAGE_ENCRYPTION_TYPE = 1
StorageEncryptionTypeTcgOpal: win32more.Windows.Win32.System.Ioctl.STORAGE_ENCRYPTION_TYPE = 2
class STORAGE_EVENT_NOTIFICATION(Structure):
    Version: UInt32
    Size: UInt32
    Events: UInt64
class STORAGE_FAILURE_PREDICTION_CONFIG(Structure):
    Version: UInt32
    Size: UInt32
    Set: win32more.Windows.Win32.Foundation.BOOLEAN
    Enabled: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved: UInt16
class STORAGE_FRU_ID_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    IdentifierSize: UInt32
    Identifier: Byte * 1
class STORAGE_GET_BC_PROPERTIES_OUTPUT(Structure):
    MaximumRequestsPerPeriod: UInt32
    MinimumPeriod: UInt32
    MaximumRequestSize: UInt64
    EstimatedTimePerRequest: UInt32
    NumOutStandingRequests: UInt32
    RequestSize: UInt64
class STORAGE_HOTPLUG_INFO(Structure):
    Size: UInt32
    MediaRemovable: win32more.Windows.Win32.Foundation.BOOLEAN
    MediaHotplug: win32more.Windows.Win32.Foundation.BOOLEAN
    DeviceHotplug: win32more.Windows.Win32.Foundation.BOOLEAN
    WriteCacheEnableOverride: win32more.Windows.Win32.Foundation.BOOLEAN
class STORAGE_HW_ENDURANCE_DATA_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    EnduranceInfo: win32more.Windows.Win32.System.Ioctl.STORAGE_HW_ENDURANCE_INFO
class STORAGE_HW_ENDURANCE_INFO(Structure):
    ValidFields: UInt32
    GroupId: UInt32
    Flags: _Flags_e__Struct
    LifePercentage: UInt32
    BytesReadCount: Byte * 16
    ByteWriteCount: Byte * 16
    class _Flags_e__Struct(Structure):
        Shared: Annotated[UInt32, 1]
        Reserved: Annotated[UInt32, 31]
class STORAGE_HW_FIRMWARE_ACTIVATE(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    Slot: Byte
    Reserved0: Byte * 3
class STORAGE_HW_FIRMWARE_DOWNLOAD(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    Slot: Byte
    Reserved: Byte * 3
    Offset: UInt64
    BufferSize: UInt64
    ImageBuffer: Byte * 1
class STORAGE_HW_FIRMWARE_DOWNLOAD_V2(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    Slot: Byte
    Reserved: Byte * 3
    Offset: UInt64
    BufferSize: UInt64
    ImageSize: UInt32
    Reserved2: UInt32
    ImageBuffer: Byte * 1
class STORAGE_HW_FIRMWARE_INFO(Structure):
    Version: UInt32
    Size: UInt32
    SupportUpgrade: Annotated[Byte, 1]
    Reserved0: Annotated[Byte, 7]
    SlotCount: Byte
    ActiveSlot: Byte
    PendingActivateSlot: Byte
    FirmwareShared: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved: Byte * 3
    ImagePayloadAlignment: UInt32
    ImagePayloadMaxSize: UInt32
    Slot: win32more.Windows.Win32.System.Ioctl.STORAGE_HW_FIRMWARE_SLOT_INFO * 1
class STORAGE_HW_FIRMWARE_INFO_QUERY(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt32
    Reserved: UInt32
class STORAGE_HW_FIRMWARE_SLOT_INFO(Structure):
    Version: UInt32
    Size: UInt32
    SlotNumber: Byte
    ReadOnly: Annotated[Byte, 1]
    Reserved0: Annotated[Byte, 7]
    Reserved1: Byte * 6
    Revision: Byte * 16
class STORAGE_IDENTIFIER(Structure):
    CodeSet: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_CODE_SET
    Type: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_TYPE
    IdentifierSize: UInt16
    NextOffset: UInt16
    Association: win32more.Windows.Win32.System.Ioctl.STORAGE_ASSOCIATION_TYPE
    Identifier: Byte * 1
STORAGE_IDENTIFIER_CODE_SET = Int32
StorageIdCodeSetReserved: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_CODE_SET = 0
StorageIdCodeSetBinary: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_CODE_SET = 1
StorageIdCodeSetAscii: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_CODE_SET = 2
StorageIdCodeSetUtf8: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_CODE_SET = 3
STORAGE_IDENTIFIER_TYPE = Int32
StorageIdTypeVendorSpecific: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_TYPE = 0
StorageIdTypeVendorId: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_TYPE = 1
StorageIdTypeEUI64: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_TYPE = 2
StorageIdTypeFCPHName: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_TYPE = 3
StorageIdTypePortRelative: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_TYPE = 4
StorageIdTypeTargetPortGroup: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_TYPE = 5
StorageIdTypeLogicalUnitGroup: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_TYPE = 6
StorageIdTypeMD5LogicalUnitIdentifier: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_TYPE = 7
StorageIdTypeScsiNameString: win32more.Windows.Win32.System.Ioctl.STORAGE_IDENTIFIER_TYPE = 8
class STORAGE_IDLE_POWER(Structure):
    Version: UInt32
    Size: UInt32
    WakeCapableHint: Annotated[UInt32, 1]
    D3ColdSupported: Annotated[UInt32, 1]
    Reserved: Annotated[UInt32, 30]
    D3IdleTimeout: UInt32
class STORAGE_IDLE_POWERUP_REASON(Structure):
    Version: UInt32
    Size: UInt32
    PowerupReason: win32more.Windows.Win32.System.Ioctl.STORAGE_POWERUP_REASON_TYPE
STORAGE_ID_NAA_FORMAT = Int32
StorageIdNAAFormatIEEEExtended: win32more.Windows.Win32.System.Ioctl.STORAGE_ID_NAA_FORMAT = 2
StorageIdNAAFormatIEEERegistered: win32more.Windows.Win32.System.Ioctl.STORAGE_ID_NAA_FORMAT = 3
StorageIdNAAFormatIEEEERegisteredExtended: win32more.Windows.Win32.System.Ioctl.STORAGE_ID_NAA_FORMAT = 5
class STORAGE_LB_PROVISIONING_MAP_RESOURCES(Structure):
    Size: UInt32
    Version: UInt32
    AvailableMappingResourcesValid: Annotated[Byte, 1]
    UsedMappingResourcesValid: Annotated[Byte, 1]
    Reserved0: Annotated[Byte, 6]
    Reserved1: Byte * 3
    AvailableMappingResourcesScope: Annotated[Byte, 2]
    UsedMappingResourcesScope: Annotated[Byte, 2]
    Reserved2: Annotated[Byte, 4]
    Reserved3: Byte * 3
    AvailableMappingResources: UInt64
    UsedMappingResources: UInt64
class STORAGE_MEDIA_SERIAL_NUMBER_DATA(Structure):
    Reserved: UInt16
    SerialNumberLength: UInt16
    SerialNumber: Byte * 1
STORAGE_MEDIA_TYPE = Int32
DDS_4mm: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 32
MiniQic: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 33
Travan: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 34
QIC: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 35
MP_8mm: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 36
AME_8mm: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 37
AIT1_8mm: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 38
DLT: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 39
NCTP: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 40
IBM_3480: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 41
IBM_3490E: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 42
IBM_Magstar_3590: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 43
IBM_Magstar_MP: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 44
STK_DATA_D3: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 45
SONY_DTF: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 46
DV_6mm: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 47
DMI: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 48
SONY_D2: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 49
CLEANER_CARTRIDGE: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 50
CD_ROM: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 51
CD_R: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 52
CD_RW: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 53
DVD_ROM: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 54
DVD_R: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 55
DVD_RW: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 56
MO_3_RW: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 57
MO_5_WO: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 58
MO_5_RW: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 59
MO_5_LIMDOW: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 60
PC_5_WO: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 61
PC_5_RW: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 62
PD_5_RW: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 63
ABL_5_WO: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 64
PINNACLE_APEX_5_RW: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 65
SONY_12_WO: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 66
PHILIPS_12_WO: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 67
HITACHI_12_WO: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 68
CYGNET_12_WO: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 69
KODAK_14_WO: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 70
MO_NFR_525: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 71
NIKON_12_RW: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 72
IOMEGA_ZIP: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 73
IOMEGA_JAZ: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 74
SYQUEST_EZ135: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 75
SYQUEST_EZFLYER: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 76
SYQUEST_SYJET: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 77
AVATAR_F2: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 78
MP2_8mm: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 79
DST_S: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 80
DST_M: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 81
DST_L: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 82
VXATape_1: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 83
VXATape_2: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 84
STK_9840: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 85
LTO_Ultrium: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 86
LTO_Accelis: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 87
DVD_RAM: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 88
AIT_8mm: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 89
ADR_1: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 90
ADR_2: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 91
STK_9940: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 92
SAIT: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 93
VXATape: win32more.Windows.Win32.System.Ioctl.STORAGE_MEDIA_TYPE = 94
class STORAGE_MEDIUM_PRODUCT_TYPE_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    MediumProductType: UInt32
class STORAGE_MINIPORT_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    Portdriver: win32more.Windows.Win32.System.Ioctl.STORAGE_PORT_CODE_SET
    LUNResetSupported: win32more.Windows.Win32.Foundation.BOOLEAN
    TargetResetSupported: win32more.Windows.Win32.Foundation.BOOLEAN
    IoTimeoutValue: UInt16
    ExtraIoInfoSupported: win32more.Windows.Win32.Foundation.BOOLEAN
    Flags: _Flags_e__Union
    Reserved0: Byte * 2
    Reserved1: UInt32
    class _Flags_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        AsBYTE: Byte
        class _Anonymous_e__Struct(Structure):
            LogicalPoFxForDisk: Annotated[Byte, 1]
            Reserved: Annotated[Byte, 7]
class STORAGE_OFFLOAD_READ_OUTPUT(Structure):
    OffloadReadFlags: UInt32
    Reserved: UInt32
    LengthProtected: UInt64
    TokenLength: UInt32
    Token: win32more.Windows.Win32.System.Ioctl.STORAGE_OFFLOAD_TOKEN
class STORAGE_OFFLOAD_TOKEN(Structure):
    TokenType: Byte * 4
    Reserved: Byte * 2
    TokenIdLength: Byte * 2
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        StorageOffloadZeroDataToken: _StorageOffloadZeroDataToken_e__Struct
        Token: Byte * 504
        class _StorageOffloadZeroDataToken_e__Struct(Structure):
            Reserved2: Byte * 504
class STORAGE_OFFLOAD_WRITE_OUTPUT(Structure):
    OffloadWriteFlags: UInt32
    Reserved: UInt32
    LengthCopied: UInt64
class STORAGE_OPERATIONAL_REASON(Structure):
    Version: UInt32
    Size: UInt32
    Reason: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON
    RawBytes: _RawBytes_e__Union
    class _RawBytes_e__Union(Union):
        ScsiSenseKey: _ScsiSenseKey_e__Struct
        NVDIMM_N: _NVDIMM_N_e__Struct
        AsUlong: UInt32
        class _ScsiSenseKey_e__Struct(Structure):
            SenseKey: Byte
            ASC: Byte
            ASCQ: Byte
            Reserved: Byte
        class _NVDIMM_N_e__Struct(Structure):
            CriticalHealth: Byte
            ModuleHealth: Byte * 2
            ErrorThresholdStatus: Byte
STORAGE_OPERATIONAL_STATUS_REASON = Int32
DiskOpReasonUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 0
DiskOpReasonScsiSenseCode: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 1
DiskOpReasonMedia: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 2
DiskOpReasonIo: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 3
DiskOpReasonThresholdExceeded: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 4
DiskOpReasonLostData: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 5
DiskOpReasonEnergySource: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 6
DiskOpReasonConfiguration: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 7
DiskOpReasonDeviceController: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 8
DiskOpReasonMediaController: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 9
DiskOpReasonComponent: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 10
DiskOpReasonNVDIMM_N: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 11
DiskOpReasonBackgroundOperation: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 12
DiskOpReasonInvalidFirmware: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 13
DiskOpReasonHealthCheck: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 14
DiskOpReasonLostDataPersistence: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 15
DiskOpReasonDisabledByPlatform: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 16
DiskOpReasonLostWritePersistence: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 17
DiskOpReasonDataPersistenceLossImminent: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 18
DiskOpReasonWritePersistenceLossImminent: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 19
DiskOpReasonMax: win32more.Windows.Win32.System.Ioctl.STORAGE_OPERATIONAL_STATUS_REASON = 20
class STORAGE_PHYSICAL_ADAPTER_DATA(Structure):
    AdapterId: UInt32
    HealthStatus: win32more.Windows.Win32.System.Ioctl.STORAGE_COMPONENT_HEALTH_STATUS
    CommandProtocol: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE
    SpecVersion: win32more.Windows.Win32.System.Ioctl.STORAGE_SPEC_VERSION
    Vendor: Byte * 8
    Model: Byte * 40
    FirmwareRevision: Byte * 16
    PhysicalLocation: Byte * 32
    ExpanderConnected: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved0: Byte * 3
    Reserved1: UInt32 * 3
class STORAGE_PHYSICAL_DEVICE_DATA(Structure):
    DeviceId: UInt32
    Role: UInt32
    HealthStatus: win32more.Windows.Win32.System.Ioctl.STORAGE_COMPONENT_HEALTH_STATUS
    CommandProtocol: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE
    SpecVersion: win32more.Windows.Win32.System.Ioctl.STORAGE_SPEC_VERSION
    FormFactor: win32more.Windows.Win32.System.Ioctl.STORAGE_DEVICE_FORM_FACTOR
    Vendor: Byte * 8
    Model: Byte * 40
    FirmwareRevision: Byte * 16
    Capacity: UInt64
    PhysicalLocation: Byte * 32
    Reserved: UInt32 * 2
class STORAGE_PHYSICAL_NODE_DATA(Structure):
    NodeId: UInt32
    AdapterCount: UInt32
    AdapterDataLength: UInt32
    AdapterDataOffset: UInt32
    DeviceCount: UInt32
    DeviceDataLength: UInt32
    DeviceDataOffset: UInt32
    Reserved: UInt32 * 3
class STORAGE_PHYSICAL_TOPOLOGY_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    NodeCount: UInt32
    Reserved: UInt32
    Node: win32more.Windows.Win32.System.Ioctl.STORAGE_PHYSICAL_NODE_DATA * 1
STORAGE_PORT_CODE_SET = Int32
StoragePortCodeSetReserved: win32more.Windows.Win32.System.Ioctl.STORAGE_PORT_CODE_SET = 0
StoragePortCodeSetStorport: win32more.Windows.Win32.System.Ioctl.STORAGE_PORT_CODE_SET = 1
StoragePortCodeSetSCSIport: win32more.Windows.Win32.System.Ioctl.STORAGE_PORT_CODE_SET = 2
StoragePortCodeSetSpaceport: win32more.Windows.Win32.System.Ioctl.STORAGE_PORT_CODE_SET = 3
StoragePortCodeSetATAport: win32more.Windows.Win32.System.Ioctl.STORAGE_PORT_CODE_SET = 4
StoragePortCodeSetUSBport: win32more.Windows.Win32.System.Ioctl.STORAGE_PORT_CODE_SET = 5
StoragePortCodeSetSBP2port: win32more.Windows.Win32.System.Ioctl.STORAGE_PORT_CODE_SET = 6
StoragePortCodeSetSDport: win32more.Windows.Win32.System.Ioctl.STORAGE_PORT_CODE_SET = 7
STORAGE_POWERUP_REASON_TYPE = Int32
StoragePowerupUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_POWERUP_REASON_TYPE = 0
StoragePowerupIO: win32more.Windows.Win32.System.Ioctl.STORAGE_POWERUP_REASON_TYPE = 1
StoragePowerupDeviceAttention: win32more.Windows.Win32.System.Ioctl.STORAGE_POWERUP_REASON_TYPE = 2
class STORAGE_PREDICT_FAILURE(Structure):
    PredictFailure: UInt32
    VendorSpecific: Byte * 512
class STORAGE_PRIORITY_HINT_SUPPORT(Structure):
    SupportFlags: UInt32
STORAGE_PROPERTY_ID = Int32
StorageDeviceProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 0
StorageAdapterProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 1
StorageDeviceIdProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 2
StorageDeviceUniqueIdProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 3
StorageDeviceWriteCacheProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 4
StorageMiniportProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 5
StorageAccessAlignmentProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 6
StorageDeviceSeekPenaltyProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 7
StorageDeviceTrimProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 8
StorageDeviceWriteAggregationProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 9
StorageDeviceDeviceTelemetryProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 10
StorageDeviceLBProvisioningProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 11
StorageDevicePowerProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 12
StorageDeviceCopyOffloadProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 13
StorageDeviceResiliencyProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 14
StorageDeviceMediumProductType: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 15
StorageAdapterRpmbProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 16
StorageAdapterCryptoProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 17
StorageDeviceIoCapabilityProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 48
StorageAdapterProtocolSpecificProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 49
StorageDeviceProtocolSpecificProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 50
StorageAdapterTemperatureProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 51
StorageDeviceTemperatureProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 52
StorageAdapterPhysicalTopologyProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 53
StorageDevicePhysicalTopologyProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 54
StorageDeviceAttributesProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 55
StorageDeviceManagementStatus: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 56
StorageAdapterSerialNumberProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 57
StorageDeviceLocationProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 58
StorageDeviceNumaProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 59
StorageDeviceZonedDeviceProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 60
StorageDeviceUnsafeShutdownCount: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 61
StorageDeviceEnduranceProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 62
StorageDeviceLedStateProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 63
StorageDeviceSelfEncryptionProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 64
StorageFruIdProperty: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID = 65
class STORAGE_PROPERTY_QUERY(Structure):
    PropertyId: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID
    QueryType: win32more.Windows.Win32.System.Ioctl.STORAGE_QUERY_TYPE
    AdditionalParameters: Byte * 1
class STORAGE_PROPERTY_SET(Structure):
    PropertyId: win32more.Windows.Win32.System.Ioctl.STORAGE_PROPERTY_ID
    SetType: win32more.Windows.Win32.System.Ioctl.STORAGE_SET_TYPE
    AdditionalParameters: Byte * 1
STORAGE_PROTOCOL_ATA_DATA_TYPE = Int32
AtaDataTypeUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_ATA_DATA_TYPE = 0
AtaDataTypeIdentify: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_ATA_DATA_TYPE = 1
AtaDataTypeLogPage: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_ATA_DATA_TYPE = 2
class STORAGE_PROTOCOL_COMMAND(Structure):
    Version: UInt32
    Length: UInt32
    ProtocolType: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE
    Flags: UInt32
    ReturnStatus: UInt32
    ErrorCode: UInt32
    CommandLength: UInt32
    ErrorInfoLength: UInt32
    DataToDeviceTransferLength: UInt32
    DataFromDeviceTransferLength: UInt32
    TimeOutValue: UInt32
    ErrorInfoOffset: UInt32
    DataToDeviceBufferOffset: UInt32
    DataFromDeviceBufferOffset: UInt32
    CommandSpecific: UInt32
    Reserved0: UInt32
    FixedProtocolReturnData: UInt32
    Reserved1: UInt32 * 3
    Command: Byte * 1
class STORAGE_PROTOCOL_DATA_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    ProtocolSpecificData: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_SPECIFIC_DATA
class STORAGE_PROTOCOL_DATA_DESCRIPTOR_EXT(Structure):
    Version: UInt32
    Size: UInt32
    ProtocolSpecificData: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_SPECIFIC_DATA_EXT
class STORAGE_PROTOCOL_DATA_SUBVALUE_GET_LOG_PAGE(Union):
    Anonymous: _Anonymous_e__Struct
    AsUlong: UInt32
    class _Anonymous_e__Struct(Structure):
        RetainAsynEvent: Annotated[UInt32, 1]
        LogSpecificField: Annotated[UInt32, 4]
        Reserved: Annotated[UInt32, 27]
STORAGE_PROTOCOL_NVME_DATA_TYPE = Int32
NVMeDataTypeUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_NVME_DATA_TYPE = 0
NVMeDataTypeIdentify: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_NVME_DATA_TYPE = 1
NVMeDataTypeLogPage: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_NVME_DATA_TYPE = 2
NVMeDataTypeFeature: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_NVME_DATA_TYPE = 3
class STORAGE_PROTOCOL_SPECIFIC_DATA(Structure):
    ProtocolType: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE
    DataType: UInt32
    ProtocolDataRequestValue: UInt32
    ProtocolDataRequestSubValue: UInt32
    ProtocolDataOffset: UInt32
    ProtocolDataLength: UInt32
    FixedProtocolReturnData: UInt32
    ProtocolDataRequestSubValue2: UInt32
    ProtocolDataRequestSubValue3: UInt32
    ProtocolDataRequestSubValue4: UInt32
class STORAGE_PROTOCOL_SPECIFIC_DATA_EXT(Structure):
    ProtocolType: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE
    DataType: UInt32
    ProtocolDataValue: UInt32
    ProtocolDataSubValue: UInt32
    ProtocolDataOffset: UInt32
    ProtocolDataLength: UInt32
    FixedProtocolReturnData: UInt32
    ProtocolDataSubValue2: UInt32
    ProtocolDataSubValue3: UInt32
    ProtocolDataSubValue4: UInt32
    ProtocolDataSubValue5: UInt32
    Reserved: UInt32 * 5
STORAGE_PROTOCOL_TYPE = Int32
ProtocolTypeUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE = 0
ProtocolTypeScsi: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE = 1
ProtocolTypeAta: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE = 2
ProtocolTypeNvme: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE = 3
ProtocolTypeSd: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE = 4
ProtocolTypeUfs: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE = 5
ProtocolTypeProprietary: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE = 126
ProtocolTypeMaxReserved: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_TYPE = 127
STORAGE_PROTOCOL_UFS_DATA_TYPE = Int32
UfsDataTypeUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_UFS_DATA_TYPE = 0
UfsDataTypeQueryDescriptor: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_UFS_DATA_TYPE = 1
UfsDataTypeQueryAttribute: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_UFS_DATA_TYPE = 2
UfsDataTypeQueryFlag: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_UFS_DATA_TYPE = 3
UfsDataTypeQueryDmeAttribute: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_UFS_DATA_TYPE = 4
UfsDataTypeQueryDmePeerAttribute: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_UFS_DATA_TYPE = 5
UfsDataTypeMax: win32more.Windows.Win32.System.Ioctl.STORAGE_PROTOCOL_UFS_DATA_TYPE = 6
class STORAGE_QUERY_DEPENDENT_VOLUME_LEV1_ENTRY(Structure):
    EntryLength: UInt32
    DependencyTypeFlags: UInt32
    ProviderSpecificFlags: UInt32
    VirtualStorageType: win32more.Windows.Win32.Storage.Vhd.VIRTUAL_STORAGE_TYPE
class STORAGE_QUERY_DEPENDENT_VOLUME_LEV2_ENTRY(Structure):
    EntryLength: UInt32
    DependencyTypeFlags: UInt32
    ProviderSpecificFlags: UInt32
    VirtualStorageType: win32more.Windows.Win32.Storage.Vhd.VIRTUAL_STORAGE_TYPE
    AncestorLevel: UInt32
    HostVolumeNameOffset: UInt32
    HostVolumeNameSize: UInt32
    DependentVolumeNameOffset: UInt32
    DependentVolumeNameSize: UInt32
    RelativePathOffset: UInt32
    RelativePathSize: UInt32
    DependentDeviceNameOffset: UInt32
    DependentDeviceNameSize: UInt32
class STORAGE_QUERY_DEPENDENT_VOLUME_REQUEST(Structure):
    RequestLevel: UInt32
    RequestFlags: UInt32
class STORAGE_QUERY_DEPENDENT_VOLUME_RESPONSE(Structure):
    ResponseLevel: UInt32
    NumberEntries: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Lev1Depends: win32more.Windows.Win32.System.Ioctl.STORAGE_QUERY_DEPENDENT_VOLUME_LEV1_ENTRY * 1
        Lev2Depends: win32more.Windows.Win32.System.Ioctl.STORAGE_QUERY_DEPENDENT_VOLUME_LEV2_ENTRY * 1
STORAGE_QUERY_TYPE = Int32
PropertyStandardQuery: win32more.Windows.Win32.System.Ioctl.STORAGE_QUERY_TYPE = 0
PropertyExistsQuery: win32more.Windows.Win32.System.Ioctl.STORAGE_QUERY_TYPE = 1
PropertyMaskQuery: win32more.Windows.Win32.System.Ioctl.STORAGE_QUERY_TYPE = 2
PropertyQueryMaxDefined: win32more.Windows.Win32.System.Ioctl.STORAGE_QUERY_TYPE = 3
class STORAGE_READ_CAPACITY(Structure):
    Version: UInt32
    Size: UInt32
    BlockLength: UInt32
    NumberOfBlocks: Int64
    DiskLength: Int64
class STORAGE_REINITIALIZE_MEDIA(Structure):
    Version: UInt32
    Size: UInt32
    TimeoutInSeconds: UInt32
    SanitizeOption: _SanitizeOption_e__Struct
    class _SanitizeOption_e__Struct(Structure):
        SanitizeMethod: Annotated[UInt32, 4]
        DisallowUnrestrictedSanitizeExit: Annotated[UInt32, 1]
        Reserved: Annotated[UInt32, 27]
STORAGE_RESERVE_ID = Int32
StorageReserveIdNone: win32more.Windows.Win32.System.Ioctl.STORAGE_RESERVE_ID = 0
StorageReserveIdHard: win32more.Windows.Win32.System.Ioctl.STORAGE_RESERVE_ID = 1
StorageReserveIdSoft: win32more.Windows.Win32.System.Ioctl.STORAGE_RESERVE_ID = 2
StorageReserveIdUpdateScratch: win32more.Windows.Win32.System.Ioctl.STORAGE_RESERVE_ID = 3
StorageReserveIdMax: win32more.Windows.Win32.System.Ioctl.STORAGE_RESERVE_ID = 4
STORAGE_RPMB_COMMAND_TYPE = Int32
StorRpmbProgramAuthKey: win32more.Windows.Win32.System.Ioctl.STORAGE_RPMB_COMMAND_TYPE = 1
StorRpmbQueryWriteCounter: win32more.Windows.Win32.System.Ioctl.STORAGE_RPMB_COMMAND_TYPE = 2
StorRpmbAuthenticatedWrite: win32more.Windows.Win32.System.Ioctl.STORAGE_RPMB_COMMAND_TYPE = 3
StorRpmbAuthenticatedRead: win32more.Windows.Win32.System.Ioctl.STORAGE_RPMB_COMMAND_TYPE = 4
StorRpmbReadResultRequest: win32more.Windows.Win32.System.Ioctl.STORAGE_RPMB_COMMAND_TYPE = 5
StorRpmbAuthenticatedDeviceConfigWrite: win32more.Windows.Win32.System.Ioctl.STORAGE_RPMB_COMMAND_TYPE = 6
StorRpmbAuthenticatedDeviceConfigRead: win32more.Windows.Win32.System.Ioctl.STORAGE_RPMB_COMMAND_TYPE = 7
class STORAGE_RPMB_DATA_FRAME(Structure):
    Stuff: Byte * 196
    KeyOrMAC: Byte * 32
    Data: Byte * 256
    Nonce: Byte * 16
    WriteCounter: Byte * 4
    Address: Byte * 2
    BlockCount: Byte * 2
    OperationResult: Byte * 2
    RequestOrResponseType: Byte * 2
class STORAGE_RPMB_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    SizeInBytes: UInt32
    MaxReliableWriteSizeInBytes: UInt32
    FrameFormat: win32more.Windows.Win32.System.Ioctl.STORAGE_RPMB_FRAME_TYPE
STORAGE_RPMB_FRAME_TYPE = Int32
StorageRpmbFrameTypeUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_RPMB_FRAME_TYPE = 0
StorageRpmbFrameTypeStandard: win32more.Windows.Win32.System.Ioctl.STORAGE_RPMB_FRAME_TYPE = 1
StorageRpmbFrameTypeMax: win32more.Windows.Win32.System.Ioctl.STORAGE_RPMB_FRAME_TYPE = 2
STORAGE_SANITIZE_METHOD = Int32
StorageSanitizeMethodDefault: win32more.Windows.Win32.System.Ioctl.STORAGE_SANITIZE_METHOD = 0
StorageSanitizeMethodBlockErase: win32more.Windows.Win32.System.Ioctl.STORAGE_SANITIZE_METHOD = 1
StorageSanitizeMethodCryptoErase: win32more.Windows.Win32.System.Ioctl.STORAGE_SANITIZE_METHOD = 2
STORAGE_SET_TYPE = Int32
PropertyStandardSet: win32more.Windows.Win32.System.Ioctl.STORAGE_SET_TYPE = 0
PropertyExistsSet: win32more.Windows.Win32.System.Ioctl.STORAGE_SET_TYPE = 1
PropertySetMaxDefined: win32more.Windows.Win32.System.Ioctl.STORAGE_SET_TYPE = 2
class STORAGE_SPEC_VERSION(Union):
    Anonymous: _Anonymous_e__Struct
    AsUlong: UInt32
    class _Anonymous_e__Struct(Structure):
        MinorVersion: _MinorVersion_e__Union
        MajorVersion: UInt16
        class _MinorVersion_e__Union(Union):
            Anonymous: _Anonymous_e__Struct
            AsUshort: UInt16
            class _Anonymous_e__Struct(Structure):
                SubMinor: Byte
                Minor: Byte
class STORAGE_TEMPERATURE_DATA_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    CriticalTemperature: Int16
    WarningTemperature: Int16
    InfoCount: UInt16
    Reserved0: Byte * 2
    Reserved1: UInt32 * 2
    TemperatureInfo: win32more.Windows.Win32.System.Ioctl.STORAGE_TEMPERATURE_INFO * 1
class STORAGE_TEMPERATURE_INFO(Structure):
    Index: UInt16
    Temperature: Int16
    OverThreshold: Int16
    UnderThreshold: Int16
    OverThresholdChangable: win32more.Windows.Win32.Foundation.BOOLEAN
    UnderThresholdChangable: win32more.Windows.Win32.Foundation.BOOLEAN
    EventGenerated: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved0: Byte
    Reserved1: UInt32
class STORAGE_TEMPERATURE_THRESHOLD(Structure):
    Version: UInt32
    Size: UInt32
    Flags: UInt16
    Index: UInt16
    Threshold: Int16
    OverThreshold: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved: Byte
class STORAGE_TIER(Structure):
    Id: Guid
    Name: Char * 256
    Description: Char * 256
    Flags: UInt64
    ProvisionedCapacity: UInt64
    MediaType: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER_MEDIA_TYPE
    Class: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER_CLASS
STORAGE_TIER_CLASS = Int32
StorageTierClassUnspecified: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER_CLASS = 0
StorageTierClassCapacity: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER_CLASS = 1
StorageTierClassPerformance: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER_CLASS = 2
StorageTierClassMax: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER_CLASS = 3
STORAGE_TIER_MEDIA_TYPE = Int32
StorageTierMediaTypeUnspecified: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER_MEDIA_TYPE = 0
StorageTierMediaTypeDisk: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER_MEDIA_TYPE = 1
StorageTierMediaTypeSsd: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER_MEDIA_TYPE = 2
StorageTierMediaTypeScm: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER_MEDIA_TYPE = 4
StorageTierMediaTypeMax: win32more.Windows.Win32.System.Ioctl.STORAGE_TIER_MEDIA_TYPE = 5
class STORAGE_TIER_REGION(Structure):
    TierId: Guid
    Offset: UInt64
    Length: UInt64
class STORAGE_WRITE_CACHE_PROPERTY(Structure):
    Version: UInt32
    Size: UInt32
    WriteCacheType: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_TYPE
    WriteCacheEnabled: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_ENABLE
    WriteCacheChangeable: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_CHANGE
    WriteThroughSupported: win32more.Windows.Win32.System.Ioctl.WRITE_THROUGH
    FlushCacheSupported: win32more.Windows.Win32.Foundation.BOOLEAN
    UserDefinedPowerProtection: win32more.Windows.Win32.Foundation.BOOLEAN
    NVCacheEnabled: win32more.Windows.Win32.Foundation.BOOLEAN
class STORAGE_ZONED_DEVICE_DESCRIPTOR(Structure):
    Version: UInt32
    Size: UInt32
    DeviceType: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONED_DEVICE_TYPES
    ZoneCount: UInt32
    ZoneAttributes: _ZoneAttributes_e__Union
    ZoneGroupCount: UInt32
    ZoneGroup: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_GROUP * 1
    class _ZoneAttributes_e__Union(Union):
        SequentialRequiredZone: _SequentialRequiredZone_e__Struct
        SequentialPreferredZone: _SequentialPreferredZone_e__Struct
        class _SequentialRequiredZone_e__Struct(Structure):
            MaxOpenZoneCount: UInt32
            UnrestrictedRead: win32more.Windows.Win32.Foundation.BOOLEAN
            Reserved: Byte * 3
        class _SequentialPreferredZone_e__Struct(Structure):
            OptimalOpenZoneCount: UInt32
            Reserved: UInt32
STORAGE_ZONED_DEVICE_TYPES = Int32
ZonedDeviceTypeUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONED_DEVICE_TYPES = 0
ZonedDeviceTypeHostManaged: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONED_DEVICE_TYPES = 1
ZonedDeviceTypeHostAware: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONED_DEVICE_TYPES = 2
ZonedDeviceTypeDeviceManaged: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONED_DEVICE_TYPES = 3
STORAGE_ZONES_ATTRIBUTES = Int32
ZonesAttributeTypeAndLengthMayDifferent: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONES_ATTRIBUTES = 0
ZonesAttributeTypeSameLengthSame: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONES_ATTRIBUTES = 1
ZonesAttributeTypeSameLastZoneLengthDifferent: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONES_ATTRIBUTES = 2
ZonesAttributeTypeMayDifferentLengthSame: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONES_ATTRIBUTES = 3
STORAGE_ZONE_CONDITION = Int32
ZoneConditionConventional: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_CONDITION = 0
ZoneConditionEmpty: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_CONDITION = 1
ZoneConditionImplicitlyOpened: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_CONDITION = 2
ZoneConditionExplicitlyOpened: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_CONDITION = 3
ZoneConditionClosed: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_CONDITION = 4
ZoneConditionReadOnly: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_CONDITION = 13
ZoneConditionFull: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_CONDITION = 14
ZoneConditionOffline: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_CONDITION = 15
class STORAGE_ZONE_DESCRIPTOR(Structure):
    Size: UInt32
    ZoneType: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_TYPES
    ZoneCondition: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_CONDITION
    ResetWritePointerRecommend: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved0: Byte * 3
    ZoneSize: UInt64
    WritePointerOffset: UInt64
class STORAGE_ZONE_GROUP(Structure):
    ZoneCount: UInt32
    ZoneType: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_TYPES
    ZoneSize: UInt64
STORAGE_ZONE_TYPES = Int32
ZoneTypeUnknown: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_TYPES = 0
ZoneTypeConventional: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_TYPES = 1
ZoneTypeSequentialWriteRequired: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_TYPES = 2
ZoneTypeSequentialWritePreferred: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_TYPES = 3
ZoneTypeMax: win32more.Windows.Win32.System.Ioctl.STORAGE_ZONE_TYPES = 4
class STREAMS_ASSOCIATE_ID_INPUT_BUFFER(Structure):
    Flags: UInt32
    StreamId: UInt32
class STREAMS_QUERY_ID_OUTPUT_BUFFER(Structure):
    StreamId: UInt32
class STREAMS_QUERY_PARAMETERS_OUTPUT_BUFFER(Structure):
    OptimalWriteSize: UInt32
    StreamGranularitySize: UInt32
    StreamIdMin: UInt32
    StreamIdMax: UInt32
class STREAM_EXTENT_ENTRY(Structure):
    Flags: UInt32
    ExtentInformation: _ExtentInformation_e__Union
    class _ExtentInformation_e__Union(Union):
        RetrievalPointers: win32more.Windows.Win32.System.Ioctl.RETRIEVAL_POINTERS_BUFFER
class STREAM_INFORMATION_ENTRY(Structure):
    Version: UInt32
    Flags: UInt32
    StreamInformation: _StreamInformation
    class _StreamInformation(Union):
        DesiredStorageClass: _DesiredStorageClass
        DataStream: _DataStream
        Reparse: _Reparse
        Ea: _Ea
        class _DesiredStorageClass(Structure):
            Class: win32more.Windows.Win32.System.Ioctl.FILE_STORAGE_TIER_CLASS
            Flags: UInt32
        class _DataStream(Structure):
            Length: UInt16
            Flags: UInt16
            Reserved: UInt32
            Vdl: UInt64
        class _Reparse(Structure):
            Length: UInt16
            Flags: UInt16
            ReparseDataSize: UInt32
            ReparseDataOffset: UInt32
        class _Ea(Structure):
            Length: UInt16
            Flags: UInt16
            EaSize: UInt32
            EaInformationOffset: UInt32
class STREAM_LAYOUT_ENTRY(Structure):
    Version: UInt32
    NextStreamOffset: UInt32
    Flags: UInt32
    ExtentInformationOffset: UInt32
    AllocationSize: Int64
    EndOfFile: Int64
    StreamInformationOffset: UInt32
    AttributeTypeCode: UInt32
    AttributeFlags: UInt32
    StreamIdentifierLength: UInt32
    StreamIdentifier: Char * 1
class TAPE_GET_STATISTICS(Structure):
    Operation: UInt32
class TAPE_STATISTICS(Structure):
    Version: UInt32
    Flags: UInt32
    RecoveredWrites: Int64
    UnrecoveredWrites: Int64
    RecoveredReads: Int64
    UnrecoveredReads: Int64
    CompressionRatioReads: Byte
    CompressionRatioWrites: Byte
class TXFS_CREATE_MINIVERSION_INFO(Structure):
    StructureVersion: UInt16
    StructureLength: UInt16
    BaseVersion: UInt32
    MiniVersion: UInt16
class TXFS_GET_METADATA_INFO_OUT(Structure):
    TxfFileId: _TxfFileId_e__Struct
    LockingTransaction: Guid
    LastLsn: UInt64
    TransactionState: UInt32
    class _TxfFileId_e__Struct(Structure):
        LowPart: Int64
        HighPart: Int64
class TXFS_GET_TRANSACTED_VERSION(Structure):
    ThisBaseVersion: UInt32
    LatestVersion: UInt32
    ThisMiniVersion: UInt16
    FirstMiniVersion: UInt16
    LatestMiniVersion: UInt16
class TXFS_LIST_TRANSACTIONS(Structure):
    NumberOfTransactions: UInt64
    BufferSizeRequired: UInt64
class TXFS_LIST_TRANSACTIONS_ENTRY(Structure):
    TransactionId: Guid
    TransactionState: UInt32
    Reserved1: UInt32
    Reserved2: UInt32
    Reserved3: Int64
class TXFS_LIST_TRANSACTION_LOCKED_FILES(Structure):
    KtmTransaction: Guid
    NumberOfFiles: UInt64
    BufferSizeRequired: UInt64
    Offset: UInt64
class TXFS_LIST_TRANSACTION_LOCKED_FILES_ENTRY(Structure):
    Offset: UInt64
    NameFlags: UInt32
    FileId: Int64
    Reserved1: UInt32
    Reserved2: UInt32
    Reserved3: Int64
    FileName: Char * 1
class TXFS_MODIFY_RM(Structure):
    Flags: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS
    LogContainerCountMax: UInt32
    LogContainerCountMin: UInt32
    LogContainerCount: UInt32
    LogGrowthIncrement: UInt32
    LogAutoShrinkPercentage: UInt32
    Reserved: UInt64
    LoggingMode: UInt16
class TXFS_QUERY_RM_INFORMATION(Structure):
    BytesRequired: UInt32
    TailLsn: UInt64
    CurrentLsn: UInt64
    ArchiveTailLsn: UInt64
    LogContainerSize: UInt64
    HighestVirtualClock: Int64
    LogContainerCount: UInt32
    LogContainerCountMax: UInt32
    LogContainerCountMin: UInt32
    LogGrowthIncrement: UInt32
    LogAutoShrinkPercentage: UInt32
    Flags: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS
    LoggingMode: UInt16
    Reserved: UInt16
    RmState: UInt32
    LogCapacity: UInt64
    LogFree: UInt64
    TopsSize: UInt64
    TopsUsed: UInt64
    TransactionCount: UInt64
    OnePCCount: UInt64
    TwoPCCount: UInt64
    NumberLogFileFull: UInt64
    OldestTransactionAge: UInt64
    RMName: Guid
    TmLogPathOffset: UInt32
class TXFS_READ_BACKUP_INFORMATION_OUT(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        BufferLength: UInt32
        Buffer: Byte * 1
TXFS_RMF_LAGS = UInt32
TXFS_RM_FLAG_LOGGING_MODE: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 1
TXFS_RM_FLAG_RENAME_RM: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 2
TXFS_RM_FLAG_LOG_CONTAINER_COUNT_MAX: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 4
TXFS_RM_FLAG_LOG_CONTAINER_COUNT_MIN: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 8
TXFS_RM_FLAG_LOG_GROWTH_INCREMENT_NUM_CONTAINERS: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 16
TXFS_RM_FLAG_LOG_GROWTH_INCREMENT_PERCENT: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 32
TXFS_RM_FLAG_LOG_AUTO_SHRINK_PERCENTAGE: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 64
TXFS_RM_FLAG_LOG_NO_CONTAINER_COUNT_MAX: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 128
TXFS_RM_FLAG_LOG_NO_CONTAINER_COUNT_MIN: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 256
TXFS_RM_FLAG_GROW_LOG: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 1024
TXFS_RM_FLAG_SHRINK_LOG: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 2048
TXFS_RM_FLAG_ENFORCE_MINIMUM_SIZE: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 4096
TXFS_RM_FLAG_PRESERVE_CHANGES: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 8192
TXFS_RM_FLAG_RESET_RM_AT_NEXT_START: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 16384
TXFS_RM_FLAG_DO_NOT_RESET_RM_AT_NEXT_START: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 32768
TXFS_RM_FLAG_PREFER_CONSISTENCY: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 65536
TXFS_RM_FLAG_PREFER_AVAILABILITY: win32more.Windows.Win32.System.Ioctl.TXFS_RMF_LAGS = 131072
class TXFS_ROLLFORWARD_REDO_INFORMATION(Structure):
    LastVirtualClock: Int64
    LastRedoLsn: UInt64
    HighestRecoveryLsn: UInt64
    Flags: UInt32
class TXFS_SAVEPOINT_INFORMATION(Structure):
    KtmTransaction: win32more.Windows.Win32.Foundation.HANDLE
    ActionCode: UInt32
    SavepointId: UInt32
class TXFS_START_RM_INFORMATION(Structure):
    Flags: UInt32
    LogContainerSize: UInt64
    LogContainerCountMin: UInt32
    LogContainerCountMax: UInt32
    LogGrowthIncrement: UInt32
    LogAutoShrinkPercentage: UInt32
    TmLogPathOffset: UInt32
    TmLogPathLength: UInt16
    LoggingMode: UInt16
    LogPathLength: UInt16
    Reserved: UInt16
    LogPath: Char * 1
class TXFS_TRANSACTION_ACTIVE_INFO(Structure):
    TransactionsActiveAtSnapshot: win32more.Windows.Win32.Foundation.BOOLEAN
class TXFS_WRITE_BACKUP_INFORMATION(Structure):
    Buffer: Byte * 1
USN_DELETE_FLAGS = UInt32
USN_DELETE_FLAG_DELETE: win32more.Windows.Win32.System.Ioctl.USN_DELETE_FLAGS = 1
USN_DELETE_FLAG_NOTIFY: win32more.Windows.Win32.System.Ioctl.USN_DELETE_FLAGS = 2
class USN_JOURNAL_DATA_V0(Structure):
    UsnJournalID: UInt64
    FirstUsn: Int64
    NextUsn: Int64
    LowestValidUsn: Int64
    MaxUsn: Int64
    MaximumSize: UInt64
    AllocationDelta: UInt64
class USN_JOURNAL_DATA_V1(Structure):
    UsnJournalID: UInt64
    FirstUsn: Int64
    NextUsn: Int64
    LowestValidUsn: Int64
    MaxUsn: Int64
    MaximumSize: UInt64
    AllocationDelta: UInt64
    MinSupportedMajorVersion: UInt16
    MaxSupportedMajorVersion: UInt16
class USN_JOURNAL_DATA_V2(Structure):
    UsnJournalID: UInt64
    FirstUsn: Int64
    NextUsn: Int64
    LowestValidUsn: Int64
    MaxUsn: Int64
    MaximumSize: UInt64
    AllocationDelta: UInt64
    MinSupportedMajorVersion: UInt16
    MaxSupportedMajorVersion: UInt16
    Flags: UInt32
    RangeTrackChunkSize: UInt64
    RangeTrackFileSizeThreshold: Int64
class USN_RANGE_TRACK_OUTPUT(Structure):
    Usn: Int64
class USN_RECORD_COMMON_HEADER(Structure):
    RecordLength: UInt32
    MajorVersion: UInt16
    MinorVersion: UInt16
class USN_RECORD_EXTENT(Structure):
    Offset: Int64
    Length: Int64
class USN_RECORD_UNION(Union):
    Header: win32more.Windows.Win32.System.Ioctl.USN_RECORD_COMMON_HEADER
    V2: win32more.Windows.Win32.System.Ioctl.USN_RECORD_V2
    V3: win32more.Windows.Win32.System.Ioctl.USN_RECORD_V3
    V4: win32more.Windows.Win32.System.Ioctl.USN_RECORD_V4
class USN_RECORD_V2(Structure):
    RecordLength: UInt32
    MajorVersion: UInt16
    MinorVersion: UInt16
    FileReferenceNumber: UInt64
    ParentFileReferenceNumber: UInt64
    Usn: Int64
    TimeStamp: Int64
    Reason: UInt32
    SourceInfo: UInt32
    SecurityId: UInt32
    FileAttributes: UInt32
    FileNameLength: UInt16
    FileNameOffset: UInt16
    FileName: Char * 1
class USN_RECORD_V3(Structure):
    RecordLength: UInt32
    MajorVersion: UInt16
    MinorVersion: UInt16
    FileReferenceNumber: win32more.Windows.Win32.Storage.FileSystem.FILE_ID_128
    ParentFileReferenceNumber: win32more.Windows.Win32.Storage.FileSystem.FILE_ID_128
    Usn: Int64
    TimeStamp: Int64
    Reason: UInt32
    SourceInfo: UInt32
    SecurityId: UInt32
    FileAttributes: UInt32
    FileNameLength: UInt16
    FileNameOffset: UInt16
    FileName: Char * 1
class USN_RECORD_V4(Structure):
    Header: win32more.Windows.Win32.System.Ioctl.USN_RECORD_COMMON_HEADER
    FileReferenceNumber: win32more.Windows.Win32.Storage.FileSystem.FILE_ID_128
    ParentFileReferenceNumber: win32more.Windows.Win32.Storage.FileSystem.FILE_ID_128
    Usn: Int64
    Reason: UInt32
    SourceInfo: win32more.Windows.Win32.System.Ioctl.USN_SOURCE_INFO_ID
    RemainingExtents: UInt32
    NumberOfExtents: UInt16
    ExtentSize: UInt16
    Extents: win32more.Windows.Win32.System.Ioctl.USN_RECORD_EXTENT * 1
USN_SOURCE_INFO_ID = UInt32
USN_SOURCE_AUXILIARY_DATA: win32more.Windows.Win32.System.Ioctl.USN_SOURCE_INFO_ID = 2
USN_SOURCE_DATA_MANAGEMENT: win32more.Windows.Win32.System.Ioctl.USN_SOURCE_INFO_ID = 1
USN_SOURCE_REPLICATION_MANAGEMENT: win32more.Windows.Win32.System.Ioctl.USN_SOURCE_INFO_ID = 4
USN_SOURCE_CLIENT_REPLICATION_MANAGEMENT: win32more.Windows.Win32.System.Ioctl.USN_SOURCE_INFO_ID = 8
class USN_TRACK_MODIFIED_RANGES(Structure):
    Flags: UInt32
    Unused: UInt32
    ChunkSize: UInt64
    FileSizeThreshold: Int64
class VERIFY_INFORMATION(Structure):
    StartingOffset: Int64
    Length: UInt32
class VIRTUALIZATION_INSTANCE_INFO_INPUT(Structure):
    NumberOfWorkerThreads: UInt32
    Flags: UInt32
class VIRTUALIZATION_INSTANCE_INFO_INPUT_EX(Structure):
    HeaderSize: UInt16
    Flags: UInt32
    NotificationInfoSize: UInt32
    NotificationInfoOffset: UInt16
    ProviderMajorVersion: UInt16
class VIRTUALIZATION_INSTANCE_INFO_OUTPUT(Structure):
    VirtualizationInstanceID: Guid
VIRTUAL_STORAGE_BEHAVIOR_CODE = Int32
VirtualStorageBehaviorUndefined: win32more.Windows.Win32.System.Ioctl.VIRTUAL_STORAGE_BEHAVIOR_CODE = 0
VirtualStorageBehaviorCacheWriteThrough: win32more.Windows.Win32.System.Ioctl.VIRTUAL_STORAGE_BEHAVIOR_CODE = 1
VirtualStorageBehaviorCacheWriteBack: win32more.Windows.Win32.System.Ioctl.VIRTUAL_STORAGE_BEHAVIOR_CODE = 2
VirtualStorageBehaviorStopIoProcessing: win32more.Windows.Win32.System.Ioctl.VIRTUAL_STORAGE_BEHAVIOR_CODE = 3
VirtualStorageBehaviorRestartIoProcessing: win32more.Windows.Win32.System.Ioctl.VIRTUAL_STORAGE_BEHAVIOR_CODE = 4
class VIRTUAL_STORAGE_SET_BEHAVIOR_INPUT(Structure):
    Size: UInt32
    BehaviorCode: win32more.Windows.Win32.System.Ioctl.VIRTUAL_STORAGE_BEHAVIOR_CODE
class VOLUME_BITMAP_BUFFER(Structure):
    StartingLcn: Int64
    BitmapSize: Int64
    Buffer: Byte * 1
class VOLUME_DISK_EXTENTS(Structure):
    NumberOfDiskExtents: UInt32
    Extents: win32more.Windows.Win32.System.Ioctl.DISK_EXTENT * 1
class VOLUME_GET_GPT_ATTRIBUTES_INFORMATION(Structure):
    GptAttributes: UInt64
class WIM_PROVIDER_ADD_OVERLAY_INPUT(Structure):
    WimType: UInt32
    WimIndex: UInt32
    WimFileNameOffset: UInt32
    WimFileNameLength: UInt32
class WIM_PROVIDER_EXTERNAL_INFO(Structure):
    Version: UInt32
    Flags: UInt32
    DataSourceId: Int64
    ResourceHash: Byte * 20
class WIM_PROVIDER_OVERLAY_ENTRY(Structure):
    NextEntryOffset: UInt32
    DataSourceId: Int64
    WimGuid: Guid
    WimFileNameOffset: UInt32
    WimType: UInt32
    WimIndex: UInt32
    Flags: UInt32
class WIM_PROVIDER_REMOVE_OVERLAY_INPUT(Structure):
    DataSourceId: Int64
class WIM_PROVIDER_SUSPEND_OVERLAY_INPUT(Structure):
    DataSourceId: Int64
class WIM_PROVIDER_UPDATE_OVERLAY_INPUT(Structure):
    DataSourceId: Int64
    WimFileNameOffset: UInt32
    WimFileNameLength: UInt32
class WOF_EXTERNAL_FILE_ID(Structure):
    FileId: win32more.Windows.Win32.Storage.FileSystem.FILE_ID_128
class WOF_EXTERNAL_INFO(Structure):
    Version: UInt32
    Provider: UInt32
class WOF_VERSION_INFO(Structure):
    WofVersion: UInt32
WRITE_CACHE_CHANGE = Int32
WriteCacheChangeUnknown: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_CHANGE = 0
WriteCacheNotChangeable: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_CHANGE = 1
WriteCacheChangeable: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_CHANGE = 2
WRITE_CACHE_ENABLE = Int32
WriteCacheEnableUnknown: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_ENABLE = 0
WriteCacheDisabled: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_ENABLE = 1
WriteCacheEnabled: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_ENABLE = 2
WRITE_CACHE_TYPE = Int32
WriteCacheTypeUnknown: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_TYPE = 0
WriteCacheTypeNone: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_TYPE = 1
WriteCacheTypeWriteBack: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_TYPE = 2
WriteCacheTypeWriteThrough: win32more.Windows.Win32.System.Ioctl.WRITE_CACHE_TYPE = 3
WRITE_THROUGH = Int32
WriteThroughUnknown: win32more.Windows.Win32.System.Ioctl.WRITE_THROUGH = 0
WriteThroughNotSupported: win32more.Windows.Win32.System.Ioctl.WRITE_THROUGH = 1
WriteThroughSupported: win32more.Windows.Win32.System.Ioctl.WRITE_THROUGH = 2
class WRITE_USN_REASON_INPUT(Structure):
    Flags: UInt32
    UsnReasonToWrite: UInt32


make_ready(__name__)
